@@ -1,32 +1,32 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_switch_pmz.hpp
- * @brief		IUTEST_PMZ ؂ւ` t@C
+ * @brief		IUTEST_PMZ 切り替え定義 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_switch_pmz_HPP_3913D1E7_E6FD_49b9_BB4C_795939FEB5C5_
-#define INCG_IRIS_iutest_switch_pmz_HPP_3913D1E7_E6FD_49b9_BB4C_795939FEB5C5_
+#ifndef INCG_IRIS_IUTEST_SWITCH_PMZ_HPP_3913D1E7_E6FD_49B9_BB4C_795939FEB5C5_
+#define INCG_IRIS_IUTEST_SWITCH_PMZ_HPP_3913D1E7_E6FD_49B9_BB4C_795939FEB5C5_
 
 #if !defined(IUTEST_USE_GTEST)
 
 //======================================================================
 // define
 
-#else
+#else	// !defined(IUTEST_USE_GTEST)
 
 //======================================================================
 // undef
-#ifdef INCG_IRIS_iutest_HPP_
+#ifdef INCG_IRIS_IUTEST_HPP_
 
 #undef IUTEST_HAS_PARAM_METHOD_TEST
 
@@ -38,6 +38,6 @@
 #  define IUTEST_HAS_PARAM_METHOD_TEST	0
 #endif
 
-#endif
+#endif	// !defined(IUTEST_USE_GTEST)
 
-#endif
+#endif	// INCG_IRIS_IUTEST_SWITCH_PMZ_HPP_3913D1E7_E6FD_49B9_BB4C_795939FEB5C5_
