@@ -1,32 +1,32 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_switch_skip.hpp
- * @brief		IUTEST_SKIP ؂ւ` t@C
+ * @brief		IUTEST_SKIP 切り替え定義 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_switch_skip_HPP_3CFB2B8D_9C8D_4b4f_9843_2FE38126BB31_
-#define INCG_IRIS_iutest_switch_skip_HPP_3CFB2B8D_9C8D_4b4f_9843_2FE38126BB31_
+#ifndef INCG_IRIS_IUTEST_SWITCH_SKIP_HPP_3CFB2B8D_9C8D_4B4F_9843_2FE38126BB31_
+#define INCG_IRIS_IUTEST_SWITCH_SKIP_HPP_3CFB2B8D_9C8D_4B4F_9843_2FE38126BB31_
 
 #if !defined(IUTEST_USE_GTEST)
 
 //======================================================================
 // define
 
-#else
+#else	// !defined(IUTEST_USE_GTEST)
 
 //======================================================================
 // undef
-#ifdef INCG_IRIS_iutest_HPP_
+#ifdef INCG_IRIS_IUTEST_HPP_
 
 #undef IUTEST_SKIP
 
@@ -35,9 +35,9 @@
 //======================================================================
 // define
 #define IUTEST_SKIP()			GTEST_AMBIGUOUS_ELSE_BLOCKER_	\
-								if( ::testing::internal::AlwaysTrue() ) return
+								if( ::testing::internal::AlwaysTrue() ) return GTEST_MESSAGE_("Skipped. ", ::testing::TestPartResult::kSuccess)
 
 
-#endif
+#endif	// !defined(IUTEST_USE_GTEST)
 
-#endif
+#endif	// INCG_IRIS_IUTEST_SWITCH_SKIP_HPP_3CFB2B8D_9C8D_4B4F_9843_2FE38126BB31_
