@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_exception.hpp
- * @brief		iris unit test exception ` t@C
+ * @brief		iris unit test exception
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_exception_HPP_B73B2E25_97C8_4dfc_BC32_5E53039A1A64_
-#define INCG_IRIS_iutest_exception_HPP_B73B2E25_97C8_4dfc_BC32_5E53039A1A64_
+#ifndef INCG_IRIS_IUTEST_EXCEPTION_HPP_B73B2E25_97C8_4DFC_BC32_5E53039A1A64_
+#define INCG_IRIS_IUTEST_EXCEPTION_HPP_B73B2E25_97C8_4DFC_BC32_5E53039A1A64_
 
 //======================================================================
 // include
@@ -31,9 +31,9 @@ namespace detail
 {
 
 /**
- * @brief	C++ObZ[W̃tH[}bg
- * @param [in]	description	= 
- * @return	bZ[W
+ * @brief	C++例外メッセージのフォーマット
+ * @param [in]	description	= 説明
+ * @return	メッセージ
 */
 inline ::std::string FormatCxxException(const char* description)
 {
@@ -60,7 +60,7 @@ namespace detail
 {
 
 /**
- * @brief	SEH O
+ * @brief	SEH 例外
 */
 class seh_exception : public ::std::exception
 {
@@ -72,7 +72,7 @@ public:
 	{
 		IUTEST_UNUSED_VAR(ep);
 		iuStringStream::type strm;
-#if IUTEST_HAS_STRINGSTREAM
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
 		strm << "SEH exception with code 0x" << ::std::setbase(16) << code << ::std::setbase(10);
 #else
 		strm << "SEH exception with code " << code;
@@ -82,7 +82,7 @@ public:
 	static int should_process_through_break_and_cppexceptions(DWORD code)
 	{
 		bool should_handle = true;
-		// break point  C++ O̓nhOȂ
+		// break point と C++ 例外はハンドリングしない
 		if( code == EXCEPTION_BREAKPOINT )
 			should_handle = false;
 		if( code == kCxxExceptionCode )
@@ -90,7 +90,7 @@ public:
 		return should_handle ? EXCEPTION_EXECUTE_HANDLER : EXCEPTION_CONTINUE_SEARCH;
 	}
 public:
-	static const int kCxxExceptionCode = 0xe06d7363;	//!< c++ exception R[h
+	static const DWORD kCxxExceptionCode = 0xe06d7363;	//!< c++ exception コード
 };
 
 }	// end of namespace detail
@@ -100,4 +100,4 @@ public:
 
 #endif
 
-#endif
+#endif	// INCG_IRIS_IUTEST_EXCEPTION_HPP_B73B2E25_97C8_4DFC_BC32_5E53039A1A64_
