@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_file.hpp
- * @brief		iris unit test t@CNX t@C
+ * @brief		iris unit test ファイルクラス ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_file_HPP_77D2C2B9_F504_4bb5_BA56_D97A2EB37DC6_
-#define INCG_IRIS_iutest_file_HPP_77D2C2B9_F504_4bb5_BA56_D97A2EB37DC6_
+#ifndef INCG_IRIS_IUTEST_FILE_HPP_77D2C2B9_F504_4BB5_BA56_D97A2EB37DC6_
+#define INCG_IRIS_IUTEST_FILE_HPP_77D2C2B9_F504_4BB5_BA56_D97A2EB37DC6_
 
 //======================================================================
 // include
@@ -35,7 +35,7 @@ namespace detail
 {
 
 /**
- * @brief	t@CNXC^[tFCX
+ * @brief	ファイル処理クラスインターフェイス
 */
 class IFileSystem
 {
@@ -66,14 +66,20 @@ public:
 	static IFile*	New(void)
 	{
 		IFileSystem* fs = GetInstance();
-		if( fs == NULL ) return NULL;
+		if( fs == NULL )
+		{
+			return NULL;
+		}
 		IFile* p = fs->Create();
 		return p;
 	}
 	static void		Free(IFile* ptr)
 	{
 		IFileSystem* fs = GetInstance();
-		if( fs == NULL ) return;
+		if( fs == NULL )
+		{
+			return;
+		}
 		fs->Delete(ptr);
 	}
 
@@ -92,42 +98,42 @@ namespace iutest
 {
 
 /**
- * @brief	t@CNXC^[tFCX
+ * @brief	ファイルクラスインターフェイス
 */
 class IFile : public detail::IOutStream
 {
 public:
 	enum OpenFlag
 	{
-		OpenRead		= 0x00000001,	//!< ǂݍ
-		OpenWrite		= 0x00000002,	//!< 
-		OpenReadWrite	= 0x00000003	//!< ǂݏ
+		OpenRead		= 0x00000001,	//!< 読み込み
+		OpenWrite		= 0x00000002,	//!< 書き込み
+		OpenReadWrite	= 0x00000003	//!< 読み書き
 	};
 public:
 	virtual ~IFile(void) {}
 public:
-	//! J
+	//! 開く
 	virtual	bool	Open(const char* filename, int mode) = 0;
-	//! 
+	//! 閉じる
 	virtual	void	Close(void)	= 0;
 };
 
 /**
- * @brief	t@CNXC^[tFCX
+ * @brief	ファイル処理クラスインターフェイス
 */
 template<typename FILE>
 class FileSystem : public detail::IFileSystem
 {
 private:
-	virtual IFile*	Create(void)		{ return new FILE; }
-	virtual void	Delete(IFile* ptr)	{ detail::Delete<FILE>(static_cast<FILE*>(ptr)); }
+	virtual IFile*	Create(void) IUTEST_CXX_OVERRIDE		{ return new FILE; }
+	virtual void	Delete(IFile* ptr) IUTEST_CXX_OVERRIDE	{ detail::Delete<FILE>(static_cast<FILE*>(ptr)); }
 };
 
 
 #if IUTEST_HAS_FOPEN
 
 /**
- * @brief	Wt@CNX
+ * @brief	標準ファイルクラス
 */
 class StdioFile : public IFile
 {
@@ -137,12 +143,12 @@ public:
 	virtual ~StdioFile(void) { Close(); }
 public:
 	/**
-	 * @brief	J
-	 * @param [in]	filename	= t@CpX
-	 * @param [in]	mode		= [h
-	 * @return	
+	 * @brief	開く
+	 * @param [in]	filename	= ファイルパス
+	 * @param [in]	mode		= モード
+	 * @return	成否
 	*/
-	virtual	bool	Open(const char* filename, int mode)
+	virtual	bool Open(const char* filename, int mode) IUTEST_CXX_OVERRIDE
 	{
 		Close();
 IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()
@@ -157,14 +163,16 @@ IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()
 		case IFile::OpenReadWrite:
 			m_fp = fopen(filename, "ab");
 			break;
+		default:
+			break;
 		}
 IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()
 		return m_fp != NULL;
 	}
 	/**
-	 * @brief	
+	 * @brief	閉じる
 	*/
-	virtual	void	Close(void)
+	virtual	void Close(void) IUTEST_CXX_OVERRIDE
 	{
 		if( m_fp != NULL )
 		{
@@ -173,19 +181,68 @@ IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()
 		}
 	}
 	/**
-	 * @brief	
-	 * @param [in]	buf		= ݃obt@
-	 * @param [in]	size	= obt@TCY
-	 * @param [in]	cnt		= ݉
+	 * @brief	書き込み
+	 * @param [in]	buf		= 書き込みバッファ
+	 * @param [in]	size	= バッファサイズ
+	 * @param [in]	cnt		= 書き込み回数
 	*/
-	virtual void	Write(const void* buf, size_t size, size_t cnt)
+	virtual bool Write(const void* buf, size_t size, size_t cnt) IUTEST_CXX_OVERRIDE
 	{
-		fwrite(buf, size, cnt, m_fp);
+		if( fwrite(buf, size, cnt, m_fp) < cnt )
+		{
+			return false;
+		}
+		return true;
 	}
 };
 
 #endif
 
+#if IUTEST_HAS_STRINGSTREAM
+
+class StringStreamFile : public IFile
+{
+public:
+	/**
+	 * @brief	開く
+	 * @param [in]	filename	= unused
+	 * @param [in]	mode		= unused
+	 * @return	成否
+	*/
+	virtual	bool Open(const char* , int ) IUTEST_CXX_OVERRIDE
+	{
+		ss.clear();
+		return true;
+	}
+
+	/**
+	 * @brief	閉じる
+	*/
+	virtual	void Close(void) IUTEST_CXX_OVERRIDE
+	{
+	}
+
+	/**
+	 * @brief	書き込み
+	 * @param [in]	buf		= 書き込みバッファ
+	 * @param [in]	size	= バッファサイズ
+	 * @param [in]	cnt		= 書き込み回数
+	*/
+	virtual bool Write(const void* buf, size_t size, size_t cnt) IUTEST_CXX_OVERRIDE
+	{
+		for( size_t i=0; i < cnt; ++i )
+		{
+			ss.write(static_cast<const char*>(buf), size);
+		}
+		return true;
+	}
+
+protected:
+	::std::stringstream ss;
+};
+
+#endif
+
 }	// end of namespace iutest
 
-#endif
+#endif	// INCG_IRIS_IUTEST_FILE_HPP_77D2C2B9_F504_4BB5_BA56_D97A2EB37DC6_
