@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_genparams.hpp
- * @brief		iris unit test parameter generator ` t@C
+ * @brief		iris unit test parameter generator
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_genparams_HPP_7845F59A_825C_426a_B451_573245408998_
-#define INCG_IRIS_iutest_genparams_HPP_7845F59A_825C_426a_B451_573245408998_
+#ifndef INCG_IRIS_IUTEST_GENPARAMS_HPP_7845F59A_825C_426A_B451_573245408998_
+#define INCG_IRIS_IUTEST_GENPARAMS_HPP_7845F59A_825C_426A_B451_573245408998_
 
 //======================================================================
 // include
@@ -27,50 +27,69 @@ namespace iutest {
 namespace detail
 {
 
+//======================================================================
+// declare
+#if IUTEST_HAS_CONCAT
+template<typename G1, typename G2>class iuConcatParamHolder;
+#endif
+
 //======================================================================
 // class
 /**
- * @brief	p[^C^[tFCX
+ * @brief	パラメータ生成器インターフェイス
 */
 template<typename T>
 class iuIParamGenerator
 {
 	typedef iuIParamGenerator<T>	_Myt;
+public:
+	typedef T	type;
 public:
 	typedef _Myt*	(*Generator)(void);
 public:
 	virtual	~iuIParamGenerator(void) {}
 public:
-	virtual	void	Begin(void) = 0;	//!< p[^Xg̐擪Ɉړ
-	virtual T		GetCurrent(void) const = 0;	// ݂̃p[^擾
-	virtual void	Next(void)	= 0;	//!< p[^擾ĎɈړ
-	virtual bool	IsEnd(void) const = 0;	//!< p[^Xg̏I[ɂ邩ǂ
+	virtual	void	Begin(void) = 0;			//!< パラメータリストの先頭に移動
+	virtual T		GetCurrent(void) const = 0;	//!< 現在のパラメータを取得
+	virtual void	Next(void)	= 0;			//!< パラメータを取得して次に移動
+	virtual bool	IsEnd(void) const = 0;		//!< パラメータリストの終端にいるかどうか
 };
 
 /**
- * @brief	p[^ێNX
+ * @brief	パラメータ生成器保持クラス
 */
 template<typename T>
 class iuParamGenerator : public iuIParamGenerator<T>
 {
 	typedef iuIParamGenerator<T>	_Interface;
-
+	typedef iuParamGenerator<T>		_Myt;
+public:
+	typedef T	type;
 public:
 	iuParamGenerator(_Interface* pInterface=NULL) : m_pInterface(pInterface) {}
 
 public:
-	virtual	void	Begin(void)	{ m_pInterface->Begin(); }	//!< p[^Xg̐擪Ɉړ
-	virtual T		GetCurrent(void) const { return m_pInterface->GetCurrent(); }	// ݂̃p[^擾
-	virtual void	Next(void)	{ m_pInterface->Next(); }	//!< p[^擾ĎɈړ
-	virtual bool	IsEnd(void) const { return m_pInterface->IsEnd(); }	//!< p[^Xg̏I[ɂ邩ǂ
+	operator iuIParamGenerator<T>* (void) const { return m_pInterface; }
+
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
+public:
+	virtual	void	Begin(void)	IUTEST_CXX_OVERRIDE { m_pInterface->Begin(); }
+	virtual T		GetCurrent(void) const IUTEST_CXX_OVERRIDE { return m_pInterface->GetCurrent(); }
+	virtual void	Next(void)	IUTEST_CXX_OVERRIDE { m_pInterface->Next(); }
+	virtual bool	IsEnd(void) const IUTEST_CXX_OVERRIDE { return m_pInterface->IsEnd(); }
 private:
 	_Interface*		m_pInterface;
 };
 
-
 /**
- * @brief	͈̓p[^
- * @tparam T	= p[^^
+ * @brief	範囲パラメータ生成器
+ * @tparam T	= パラメータ型
 */
 template<typename T>
 class iuRangeParamsGenerator : public iuIParamGenerator<T>
@@ -81,10 +100,10 @@ class iuRangeParamsGenerator : public iuIParamGenerator<T>
 	T	m_cur;
 public:
 	/**
-	 * @brief	RXgN^
-	 * @param [in]	begin	= Jnl
-	 * @param [in]	end		= Il
-	 * @param [in]	step	= l
+	 * @brief	コンストラクタ
+	 * @param [in]	begin	= 開始値
+	 * @param [in]	end		= 終了値
+	 * @param [in]	step	= 増値
 	*/
 	iuRangeParamsGenerator(T begin, T end, T step=1)
 		: m_begin(begin)
@@ -95,15 +114,15 @@ public:
 	}
 
 public:
-	virtual	void	Begin(void) { m_cur = m_begin; }
-	virtual T		GetCurrent(void) const	{ return m_cur; }
-	virtual void	Next(void)	{ m_cur += m_step; }
-	virtual bool	IsEnd(void) const	{ if( m_cur < m_end ) return false; return true; }
+	virtual	void	Begin(void) IUTEST_CXX_OVERRIDE{ m_cur = m_begin; }
+	virtual T		GetCurrent(void) const IUTEST_CXX_OVERRIDE { return m_cur; }
+	virtual void	Next(void) IUTEST_CXX_OVERRIDE { m_cur += m_step; }
+	virtual bool	IsEnd(void) const IUTEST_CXX_OVERRIDE { return !(m_cur < m_end); }
 };
 
 /**
- * @breif	^Ulp[^
- * @tparam T	= p[^^
+ * @breif	真偽値パラメータ生成器
+ * @tparam T	= パラメータ型
 */
 template<typename T>
 class iuBoolParamsGenerator : public iuIParamGenerator<T>
@@ -116,15 +135,15 @@ public:
 	{}
 
 public:
-	virtual	void	Begin(void) { m_cur = 0; m_n = 0; }
-	virtual T		GetCurrent(void) const	{ return m_cur; }
-	virtual void	Next(void)	{ ++m_n; m_cur = !m_cur; }
-	virtual bool	IsEnd(void) const	{ if( m_n < 2 ) return false; return true; }
+	virtual	void	Begin(void) IUTEST_CXX_OVERRIDE { m_cur = 0; m_n = 0; }
+	virtual T		GetCurrent(void) const IUTEST_CXX_OVERRIDE { return m_cur; }
+	virtual void	Next(void) IUTEST_CXX_OVERRIDE { ++m_n; m_cur = !m_cur; }
+	virtual bool	IsEnd(void) const IUTEST_CXX_OVERRIDE { return (m_n >= 2); }
 };
 
 /**
- * @brief	lzp[^
- * @tparam T	= p[^^
+ * @brief	値配列パラメータ生成器
+ * @tparam T	= パラメータ型
 */
 template<typename T>
 class iuValuesInParamsGenerator : public iuIParamGenerator<T>
@@ -138,30 +157,20 @@ public:
 	template<typename Container>
 	iuValuesInParamsGenerator(const Container& values)
 	{
-		for( typename Container::const_iterator it = values.begin(), end=values.end(); it != end; ++it )
-		{
-			m_values.push_back(static_cast<T>(*it));
-		}
+		m_values.insert(m_values.end(), values.begin(), values.end());
 	}
 #if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
 	template<typename TT, size_t SIZE>
 	iuValuesInParamsGenerator(const TT (&values)[SIZE])
 	{
-		const TT* begin = values;
-		for( const TT* end = values+SIZE; begin != end; ++begin )
-		{
-			m_values.push_back(static_cast<T>(*begin));
-		}
+		m_values.insert(m_values.end(), values, values + SIZE);
 	}
 #endif
 
 	template<typename Ite>
 	iuValuesInParamsGenerator(Ite begin, Ite end)
 	{
-		for( ; begin != end; ++begin )
-		{
-			m_values.push_back(static_cast<T>(*begin));
-		}
+		m_values.insert(m_values.end(), begin, end);
 	}
 
 #if IUTEST_HAS_INITIALIZER_LIST
@@ -172,17 +181,76 @@ public:
 #endif
 
 public:
-	virtual	void	Begin(void) { m_it = m_values.begin(); }
-	virtual T		GetCurrent(void) const	{ return *m_it; }
-	virtual void	Next(void)	{ ++m_it; }
-	virtual bool	IsEnd(void) const	{ return (m_it == m_values.end()); }
+	virtual	void	Begin(void) IUTEST_CXX_OVERRIDE{ m_it = m_values.begin(); }
+	virtual T		GetCurrent(void) const IUTEST_CXX_OVERRIDE { return *m_it; }
+	virtual void	Next(void) IUTEST_CXX_OVERRIDE { ++m_it; }
+	virtual bool	IsEnd(void) const IUTEST_CXX_OVERRIDE { return (m_it == m_values.end()); }
 };
 
+
+#if IUTEST_HAS_CONCAT
+/**
+ * @brief	パラメータ生成器加算保持クラス
+*/
+template<typename G1, typename G2>
+class iuConcatParamHolder
+{
+	typedef iuConcatParamHolder<G1, G2>	_Myt;
+public:
+	iuConcatParamHolder(const G1& g1, const G2& g2)
+		: m_g1(g1), m_g2(g2) {}
+
+public:
+	template<typename T>
+	operator iuIParamGenerator<T>* (void)
+	{
+		params_t<T> params;
+		params.append(m_g1);
+		params.append(m_g2);
+		return new iuValuesInParamsGenerator<T>(params.val);
+	}
+
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
+private:
+	template<typename T>
+	struct params_t
+	{
+		::std::vector<T> val;
+
+		void append(iuIParamGenerator<T>* gen)
+		{
+			for( gen->Begin(); !gen->IsEnd(); gen->Next() )
+			{
+				val.push_back(gen->GetCurrent());
+			}
+		}
+		template<typename U>
+		void append(iuParamGenerator<U>& gen)
+		{
+			for( gen.Begin(); !gen.IsEnd(); gen.Next() )
+			{
+				val.push_back(static_cast<T>(gen.GetCurrent()));
+			}
+		}
+	};
+private:
+	G1 m_g1;
+	G2 m_g2;
+};
+#endif
+
+
 #if IUTEST_HAS_VARIADIC_VALUES
 template<typename... Args>
 class iuValueArray
 {
 	typedef tuples::tuple<Args...>	_MyTuple;
+	typedef iuValueArray<Args...>	_Myt;
 
 	template<typename T>
 	struct make_array
@@ -211,11 +279,19 @@ public:
 	{}
 public:
 	template<typename T>
-	operator	iuIParamGenerator<T>* (void) const
+	operator iuIParamGenerator<T>* (void) const
 	{
 		make_array<T> ar(v);
 		return new iuValuesInParamsGenerator<T>(ar.val);
 	}
+
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
 private:
 	_MyTuple v;
 };
@@ -226,6 +302,7 @@ private:
 template<typename A1, typename A2>
 class iuValueArray2
 {
+	typedef iuValueArray2<A1, A2> _Myt;
 public:
 	iuValueArray2(A1 a1, A2 a2) : v1(a1), v2(a2)
 	{}
@@ -237,6 +314,12 @@ public:
 		};
 		return new iuValuesInParamsGenerator<T>(val);
 	}
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
 private:
 	A1	v1;	A2	v2;
 };
@@ -247,13 +330,17 @@ private:
 #define IIUT_DECL_VALUEARRAY_(n)						\
 	template< IUTEST_PP_ENUM_PARAMS(n, typename A) >	\
 	class IUTEST_PP_CAT(iuValueArray, n) {				\
-	public:												\
+		typedef IUTEST_PP_CAT(iuValueArray, n)< IUTEST_PP_ENUM_PARAMS(n, A) > _Myt;	\
+	public:																			\
 		IUTEST_PP_CAT(iuValueArray, n)( IUTEST_PP_ENUM_BINARY_PARAMS(n, A, a) )		\
 		: IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_VALUEARRAY_CONSTRUCT_, v, a) {}		\
 		template<typename T>operator iuIParamGenerator<T>* (void) const {			\
-			const T val[] = { IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_VALUEARRAY_STATICCAST_, T, v) };	\
+			const T val[] = { IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_VALUEARRAY_STATICCAST_, T, v) };		\
 			return new iuValuesInParamsGenerator<T>(val);							\
 		}																			\
+		template<typename Other> iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const {	\
+			return iuConcatParamHolder<_Myt, Other>(*this, g);						\
+		}																			\
 	private: IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_VALUEARRAY_VARIABLE_, A, v)		\
 	}
 
@@ -382,25 +469,25 @@ public:
 	{}
 
 public:
-	virtual	void	Begin(void)
+	virtual	void Begin(void) IUTEST_CXX_OVERRIDE
 	{
 		begin_foreach<0, count>(v);
 	}
-	virtual void	Next(void)
+	virtual void Next(void) IUTEST_CXX_OVERRIDE
 	{
 		if( IsEnd() ) return;
 		next_foreach<0, count>(v);
 	}
-	virtual bool	IsEnd(void) const
+	virtual bool IsEnd(void) const IUTEST_CXX_OVERRIDE
 	{
 		return is_end_foreach<0, count>(v);
 	}
-	virtual ParamType	GetCurrent(void) const
+	virtual ParamType GetCurrent(void) const IUTEST_CXX_OVERRIDE
 	{
 		return current_foreach<0, count, Args...>();
 	}
 
-	_MyTuple&	generators(void) { return v; }
+	_MyTuple& generators(void) { return v; }
 private:
 	_MyTuple v;
 };
@@ -429,7 +516,7 @@ public:
 
 public:
 	template<typename... Args>
-	operator iuIParamGenerator< tuples::tuple<Args...> >* () const 
+	operator iuIParamGenerator< tuples::tuple<Args...> >* (void) const 
 	{
 		typedef tuples::tuple<Args...> ArgTuple;
 		iuCartesianProductGenerator<Args...>* p = new iuCartesianProductGenerator<Args...>();
@@ -437,8 +524,15 @@ public:
 		return p;
 	}
 
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
 private:
-	void	operator = (const _Myt&);
+	void operator = (const _Myt&);
 private:
 	_MyTuple v;
 };
@@ -454,12 +548,12 @@ public:
 		: m_g1(g1), m_g2(g2)
 	{}
 public:
-	virtual	void	Begin(void)
+	virtual	void Begin(void) IUTEST_CXX_OVERRIDE
 	{
 		m_g1.Begin();
 		m_g2.Begin();
 	}
-	virtual void	Next(void)
+	virtual void Next(void) IUTEST_CXX_OVERRIDE
 	{
 		if( m_g2.IsEnd() ) return;
 		m_g2.Next();
@@ -469,7 +563,7 @@ public:
 			if( !m_g1.IsEnd() ) m_g2.Begin();
 		}
 	}
-	virtual bool	IsEnd(void) const
+	virtual bool IsEnd(void) const IUTEST_CXX_OVERRIDE
 	{
 		return m_g1.IsEnd() && m_g2.IsEnd();
 	}
@@ -494,7 +588,7 @@ public:
 	{}
 
 public:
-	virtual ParamType	GetCurrent(void) const
+	virtual ParamType GetCurrent(void) const IUTEST_CXX_OVERRIDE
 	{
 		return ParamType(this->m_g1.GetCurrent(), this->m_g2.GetCurrent());
 	}
@@ -518,7 +612,7 @@ public:
 	{}
 
 public:
-	virtual ParamType	GetCurrent(void) const
+	virtual ParamType	GetCurrent(void) const IUTEST_CXX_OVERRIDE
 	{
 		tuples::tuple<T2, T3> param(this->m_g2.GetCurrent());
 		return ParamType(this->m_g1.GetCurrent(), tuples::get<0>(param), tuples::get<1>(param) );
@@ -550,7 +644,7 @@ public:
 		: _Mybase(g0, IUTEST_PP_CAT(iuCartesianProductGenerator, IUTEST_PP_DEC(n))<							\
 		IUTEST_PP_ENUM_SHIFTED_PARAMS(IUTEST_PP_DEC(n), T)>					\
 		( IUTEST_PP_ENUM_SHIFTED_PARAMS(IUTEST_PP_DEC(n), g) ) ) {}			\
-		virtual ParamType	GetCurrent(void) const {						\
+		virtual ParamType	GetCurrent(void) const IUTEST_CXX_OVERRIDE {	\
 			tuples::tuple< IUTEST_PP_ENUM_SHIFTED_PARAMS(IUTEST_PP_DEC(n), T) >	\
 			params(this->m_g2.GetCurrent());								\
 			return ParamType(this->m_g1.GetCurrent(), IUTEST_PP_ENUM(IUTEST_PP_DEC(n)	\
@@ -592,6 +686,13 @@ public:
 		);
 	}
 
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
 private:
 	void	operator = (const _Myt&) {}
 private:
@@ -617,6 +718,9 @@ private:
 			return new IUTEST_PP_CAT(iuCartesianProductGenerator, n)< IUTEST_PP_ENUM_PARAMS(n, T) >(		\
 				IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_, T, m_g) );			\
 		}														\
+		template<typename Other> iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const {		\
+			return iuConcatParamHolder<_Myt, Other>(*this, g);	\
+		}														\
 	private: void operator = (const _Myt&) {}					\
 		IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_, const Generator, m_g)		\
 	}
@@ -653,8 +757,8 @@ protected:
 
 private:
 	struct PairInfo {
-		int raw1, raw2;	// ̃yA
-		int idx1, idx2;	// CfbNX̃yA
+		int raw1, raw2;	// 列のペア
+		int idx1, idx2;	// インデックスのペア
 	};
 protected:
 	template<typename T1>
@@ -685,7 +789,7 @@ protected:
 		typedef typename ::std::vector< ParamIndexes<N> >::iterator list_iterator;
 		list.clear();
 
-		// yA
+		// ペアを列挙
 		::std::vector<PairInfo> pair_list;
 		for( int i=0; i < N; ++i )
 		{
@@ -704,7 +808,7 @@ protected:
 			}
 		}
 
-		// Vbt
+		// シャッフル
 		iuRandom random;
 		unsigned int seed = TestEnv::get_random_seed();
 		if( seed != 0 )
@@ -722,7 +826,7 @@ protected:
 				find = FindFree(list, pair_info, list.begin());
 				if( find == list.end() )
 				{
-					// 󂫂̂ō
+					// 空きが無いので作る
 					ParamIndexes<N> params;
 					params.index[pair_info.raw1] = pair_info.idx1;
 					params.index[pair_info.raw2] = pair_info.idx2;
@@ -730,7 +834,7 @@ protected:
 				}
 				else
 				{
-					// ߂
+					// 埋める
 					ParamIndexes<N>& params = *find;
 					params.index[pair_info.raw1] = pair_info.idx1;
 					params.index[pair_info.raw2] = pair_info.idx2;
@@ -769,7 +873,10 @@ private:
 		{
 			ParamIndexes<N>& indexes = *it;
 			if( indexes.index[pair_info.raw1] == pair_info.idx1 
-				&& indexes.index[pair_info.raw2] == pair_info.idx2 ) return it;
+				&& indexes.index[pair_info.raw2] == pair_info.idx2 )
+			{
+				return it;
+			}
 		}
 		return list.end();
 	}
@@ -778,7 +885,7 @@ private:
 	static typename ::std::vector< ParamIndexes<N> >::iterator FindFree( ::std::vector< ParamIndexes<N> >& list, const PairInfo& pair_info
 		, typename ::std::vector< ParamIndexes<N> >::iterator start)
 	{
-		// ꂻȂƂT
+		// 入れそうなとこを探す
 		typedef typename ::std::vector< ParamIndexes<N> >::iterator iterator;
 		iterator find = list.end();
 		UInt32 max_overlap = static_cast<UInt32>(-1);
@@ -804,11 +911,14 @@ private:
 				IUTEST_UNUSED_VAR(max_overlap);
 				return it;
 #else
-				// ɓƂďdȂׂ
+				// 仮に入ったとして重複がないか調べる
 				UInt32 overlap = 0;
 				for( int i=0; i < N; ++i )
 				{
-					if( indexes.index[i] == -1 || i == free_raw ) continue;
+					if( indexes.index[i] == -1 || i == free_raw )
+					{
+						continue;
+					}
 					PairInfo tmp = { i, free_raw, indexes.index[i], free_idx };
 					iterator it2 = Find(list, tmp, list.begin());
 					while(it2 != end)
@@ -818,7 +928,10 @@ private:
 						it2 = Find(list, tmp, it2);
 					}
 				}
-				if( overlap == 0 ) return it;
+				if( overlap == 0 )
+				{
+					return it;
+				}
 				if( find == list.end()
 					|| (overlap < max_overlap) )
 				{
@@ -838,7 +951,9 @@ private:
 		{
 			ParamIndexes<N>& indexes = *it;
 			if( indexes.index[pair_info.raw1] == -1 && indexes.index[pair_info.raw2] == -1 )
+			{
 				return it;
+			}
 		}
 		return list.end();
 	}
@@ -943,7 +1058,7 @@ public:
 
 public:
 	template<typename... Args>
-	operator iuIParamGenerator< tuples::tuple<Args...> >* () const 
+	operator iuIParamGenerator< tuples::tuple<Args...> >* (void) const
 	{
 		typedef tuples::tuple<Args...> ArgTuple;
 		tuples::tuple< iuParamGenerator<Args>... > generators;
@@ -952,6 +1067,13 @@ public:
 		return iuPairwiseGenerator<Args...>::Create(generators);
 	}
 
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
 private:
 	void	operator = (const _Myt&);
 private:
@@ -978,26 +1100,32 @@ public:
 		return new iuPairwiseGenerator2<T1, T2>(g1, g2);
 	}
 public:
-	virtual	void	Begin(void)
+	virtual	void	Begin(void) IUTEST_CXX_OVERRIDE
 	{
 		m_g1.Begin();
 		m_g2.Begin();
 	}
-	virtual void	Next(void)
+	virtual void	Next(void) IUTEST_CXX_OVERRIDE
 	{
-		if( m_g2.IsEnd() ) return;
+		if( m_g2.IsEnd() ) 
+		{
+			return;
+		}
 		m_g2.Next();
 		if( m_g2.IsEnd() )
 		{
 			m_g1.Next();
-			if( !m_g1.IsEnd() ) m_g2.Begin();
+			if( !m_g1.IsEnd() )
+			{
+				m_g2.Begin();
+			}
 		}
 	}
-	virtual bool	IsEnd(void) const
+	virtual bool	IsEnd(void) const IUTEST_CXX_OVERRIDE
 	{
 		return m_g1.IsEnd() && m_g2.IsEnd();
 	}
-	virtual ParamType	GetCurrent(void) const
+	virtual ParamType	GetCurrent(void) const IUTEST_CXX_OVERRIDE
 	{
 		return ParamType(this->m_g1.GetCurrent(), this->m_g2.GetCurrent());
 	}
@@ -1121,6 +1249,13 @@ public:
 			);
 	}
 
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
 private:
 	void	operator = (const _Myt&) {}
 private:
@@ -1146,6 +1281,9 @@ private:
 			return IUTEST_PP_CAT(iuPairwiseGenerator, n)< IUTEST_PP_ENUM_PARAMS(n, T) >::Create(	\
 				IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_PAIRWISE_HOLDER_STATICCAST_, T, m_g) );			\
 		}														\
+		template<typename Other> iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const { \
+			return iuConcatParamHolder<_Myt, Other>(*this, g);	\
+		}														\
 	private: void operator = (const _Myt&) {}					\
 		IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_PAIRWISE_HOLDER_VARIABLE_, const Generator, m_g)		\
 	}
@@ -1171,31 +1309,40 @@ IIUT_DECL_PAIRWISE_HOLDER_(9);
 #if IUTEST_HAS_VALUESGEN
 
 /**
- * @breif	p[^
- * @tparam G	= p[^
+ * @breif	パラメータ生成器
+ * @tparam G	= パラメータ生成器
 */
 template<typename G>
 class iuValuesParamsGeneratorHolder
 {
+	typedef iuValuesParamsGeneratorHolder<G> _Myt;
 public:
 	iuValuesParamsGeneratorHolder(size_t num, const G& g)
 		: m_num(num), m_g(g)
 	{}
 public:
 	template<typename T>
-	operator iuIParamGenerator<T>* () const 
+	operator iuIParamGenerator<T>* (void) const
 	{
 		::std::vector<T> params(m_num);
 		::std::generate(params.begin(), params.end(), m_g);
 		return new iuValuesInParamsGenerator<T>( params );
 	}
+
+public:
+	template<typename Other>
+	iuConcatParamHolder<_Myt, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<_Myt, Other>(*this, g);
+	}
+
 private:
 	size_t m_num;
 	G m_g;
 };
 
 /**
- * @brief	WFl[^
+ * @brief	乱数ジェネレータ
 */
 template<typename T, typename F>
 class iuRandomFilterParamGenerator
@@ -1210,7 +1357,10 @@ public:
 		for(;;)
 		{
 			type val =  m_rnd.genrand();
-			if( (m_fn)(val) ) return val;
+			if( (m_fn)(val) )
+			{
+				return val;
+			}
 		}
 	}
 private:
@@ -1223,7 +1373,7 @@ private:
 #if IUTEST_HAS_RANDOMVALUES
 
 /**
- * @breif	p[^
+ * @breif	乱数パラメータ生成器
 */
 class iuRandomParamsHolder
 {
@@ -1232,7 +1382,7 @@ public:
 		: m_num(num), m_seed(seed) {}
 public:
 	template<typename T>
-	operator iuIParamGenerator<T>* () const 
+	operator iuIParamGenerator<T>* (void) const
 	{
 		unsigned int seed = m_seed;
 		if( seed == 0 )
@@ -1242,6 +1392,14 @@ public:
 		iuValuesParamsGeneratorHolder< iuTypedRandom<T> > gen( m_num, iuTypedRandom<T>(seed) );
 		return gen;
 	}
+
+public:
+	template<typename Other>
+	iuConcatParamHolder<iuRandomParamsHolder, Other> operator + (const Other& g) const
+	{
+		return iuConcatParamHolder<iuRandomParamsHolder, Other>(*this, g);
+	}
+
 private:
 	size_t m_num;
 	unsigned int m_seed;
@@ -1254,4 +1412,4 @@ private:
 
 #endif
 
-#endif
+#endif	// INCG_IRIS_IUTEST_GENPARAMS_HPP_7845F59A_825C_426A_B451_573245408998_
