@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_internal.hpp
- * @brief		iris unit test ` t@C
+ * @brief		iris unit test 内部定義 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_internal_HPP_A5BD9FBB_B57A_4c1d_B205_0ADB7798DBF9_
-#define INCG_IRIS_iutest_internal_HPP_A5BD9FBB_B57A_4c1d_B205_0ADB7798DBF9_
+#ifndef INCG_IRIS_IUTEST_INTERNAL_HPP_A5BD9FBB_B57A_4C1D_B205_0ADB7798DBF9_
+#define INCG_IRIS_IUTEST_INTERNAL_HPP_A5BD9FBB_B57A_4C1D_B205_0ADB7798DBF9_
 
 //======================================================================
 // include
@@ -24,82 +24,183 @@
 
 //======================================================================
 // define
-/**
- * @internal
- * @brief	eXg쐬}N
-*/
-#define IUTEST_TEST_CLASS_NAME_(testcase_, testname_)	iu_##testcase_##_x_##testname_##_Test
+#define IUTEST_TEST_CLASS_NAME_(testcase_, testname_)	IIUT_TEST_CLASS_NAME_I(IUTEST_TO_VARNAME_(testcase_), IUTEST_TO_VARNAME_(testname_))
+#define IIUT_TEST_CLASS_NAME_I(testcase_, testname_)	IIUT_TEST_CLASS_NAME_I_(testcase_, testname_)
+#define IIUT_TEST_CLASS_NAME_I_(testcase_, testname_)	iu_##testcase_##_x_##testname_##_Test
 
+#define IUTEST_TEST_INSTANCE_NAME_(testcase_, testname_)	IIUT_TEST_INSTANCE_NAME_I(IUTEST_TO_VARNAME_(testcase_), IUTEST_TO_VARNAME_(testname_))
+#define IIUT_TEST_INSTANCE_NAME_I(testcase_, testname_)		IIUT_TEST_INSTANCE_NAME_I_(testcase_, testname_)
+#define IIUT_TEST_INSTANCE_NAME_I_(testcase_, testname_)	s_##testcase_##_##testname_##_Instance
+
+#if IUTEST_HAS_TESTNAME_ALIAS
+
+#define IUTEST_TO_VARNAME_(name_)				IIUT_TO_VARNAME_I( (IIUT_ALIAS_TESTNAME_PP_##name_, name_, dummy_) )
+#define IIUT_TO_VARNAME_I(tuple_)				IUTEST_PP_EXPAND( IIUT_TO_VARNAME_I_ tuple_ )
+#define IIUT_TO_VARNAME_I_(dummy, name_, ...)	name_
+
+#define IUTEST_TO_NAME_(name_)					IIUT_TO_NAME_I( (IIUT_ALIAS_TESTNAME_PP_##name_, name_, name_, dummy_) )
+#define IIUT_TO_NAME_I(tuple_)					IUTEST_PP_EXPAND( IIUT_TO_NAME_I_ tuple_ )
+#define IIUT_TO_NAME_I_(dummy, dummy_2, name_, ...)	name_
+
+#define IUTEST_TO_NAME_STR_(name_)				IUTEST_PP_TOSTRING( IUTEST_TO_NAME_(name_) )
+
+#define IIUT_ALIAS_TESTNAME_PP_UNPAREN_(...)	__VA_ARGS__
+
+#if	defined(_MSC_VER)
+#  define IUTEST_ALIAS_TESTNAME_(name_)			name_
+#  define IUTEST_ALIAS_TESTNAME_F_(var_, name_)	UNPAREN_(dummy, var_, name_)
+#else
+#  define IUTEST_ALIAS_TESTNAME_(name_)			UNPAREN_(dummy, IUTEST_PP_CAT(iutest_japanese_var, __LINE__), name_)
+#  define IUTEST_ALIAS_TESTNAME_F_(var_, name_)	UNPAREN_(dummy, var_, name_)
+#endif
+
+#else
+
+#define IUTEST_TO_VARNAME_(name_)				name_
+#define IUTEST_TO_NAME_(name_)					name_
+#define IUTEST_TO_NAME_STR_(name_)				#name_
+
+#endif
+
+#if IUTEST_HAS_IF_EXISTS
+#  define IIUT_CHECK_TESTFIXTURE(testfixture_)		\
+	IUTEST_IF_EXISTS(testfixture_, IUTEST_IF_EXISTS(testfixture_::SetUp,				\
+		IUTEST_STATIC_ASSERT_MSG(														\
+			(!::iutest_type_traits::is_base_of< ::iutest::Test, testfixture_ >::value)	\
+			, #testfixture_ " is fixture class, mistake the IUTEST_F?");				\
+	) )
+#else
+#  define IIUT_CHECK_TESTFIXTURE(testfixture_)
+#endif
+
+#define IUTEST_TEST_STRICT_(testcase_, testname_, parent_class_, type_id_)	\
+	IIUT_CHECK_TESTFIXTURE(testcase_)										\
+	IUTEST_TEST_(testcase_, testname_, parent_class_, type_id_)
+
+#define IUTEST_TEST_F_(testfixture_, testname_)		IUTEST_TEST_(testfixture_, testname_, IUTEST_TO_VARNAME_(testfixture_)	\
+														, ::iutest::internal::GetTypeId< IUTEST_TO_VARNAME_(testfixture_) >())
+
+#define IUTEST_TEST_F_IGNORE_(testfixture_, testname_)	IUTEST_TEST_IGNORE_(testfixture_, testname_, IUTEST_TO_VARNAME_(testfixture_)	\
+															, ::iutest::internal::GetTypeId< IUTEST_TO_VARNAME_(testfixture_) >())
 /**
  * @internal
- * @brief	eXgNX`}N
+ * @brief	テストクラス定義マクロ
 */
 #define IUTEST_TEST_(testcase_, testname_, parent_class_, type_id_)							\
 	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public parent_class_ {			\
-		IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTEST_TEST_CLASS_NAME_(testcase_, testname_));	\
+	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTEST_TEST_CLASS_NAME_(testcase_, testname_));		\
 		public:	IUTEST_TEST_CLASS_NAME_(testcase_, testname_)(void) {}						\
 		protected: virtual void Body(void);													\
 	};																						\
 	::iutest::detail::TestInstance<IUTEST_TEST_CLASS_NAME_(testcase_, testname_)>			\
-	s_##testcase_##_##testname_( IUTEST_CONCAT_PACKAGE_(testcase_), #testname_				\
+	IUTEST_TEST_INSTANCE_NAME_(testcase_, testname_)(										\
+		IUTEST_CONCAT_PACKAGE_(IUTEST_TO_NAME_(testcase_)), IUTEST_TO_NAME_STR_(testname_)	\
 		, type_id_, parent_class_::SetUpTestCase, parent_class_::TearDownTestCase);			\
 	void IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::Body(void)
 
+/**
+ * @internal
+ * @brief	テストクラス定義マクロ
+ *			関数の中はコンパイルできなくてもよい
+*/
+#define IUTEST_TEST_IGNORE_(testcase_, testname_, parent_class_, type_id_)					\
+	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public parent_class_ {			\
+	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(	IUTEST_TEST_CLASS_NAME_(testcase_, testname_));		\
+		public:	IUTEST_TEST_CLASS_NAME_(testcase_, testname_)(void) {}						\
+		protected: virtual void Body(void) { IUTEST_SKIP() << "ignored test..."; }			\
+		template<typename T>void Body(void);												\
+	};																						\
+	::iutest::detail::TestInstance<IUTEST_TEST_CLASS_NAME_(testcase_, testname_)>			\
+	IUTEST_TEST_INSTANCE_NAME_(testcase_, testname_)(										\
+		IUTEST_CONCAT_PACKAGE_(IUTEST_TO_NAME_(testcase_)), IUTEST_TO_NAME_STR_(testname_)	\
+		, type_id_, parent_class_::SetUpTestCase, parent_class_::TearDownTestCase);			\
+	template<typename T>void IUTEST_TEST_CLASS_NAME_(testcase_, testname_ )::Body(void)
 
 #ifndef IUTEST_NO_VARIADIC_MACROS
 
-#define IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)	IUTEST_PP_CAT(iu_##testcase_##_x_##testname_##_Test, __LINE__)
+#define IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)	IIUT_PMZ_TEST_CLASS_NAME_I(IUTEST_TO_VARNAME_(testcase_), IUTEST_TO_VARNAME_(testname_))
+#define IIUT_PMZ_TEST_CLASS_NAME_I(testcase_, testname_)	IIUT_PMZ_TEST_CLASS_NAME_I_(testcase_, testname_)
+#define IIUT_PMZ_TEST_CLASS_NAME_I_(testcase_, testname_)	IUTEST_PP_CAT( IUTEST_PP_CAT(iu_##testcase_##_x_Test_, testname_), __LINE__)
 /**
  * @internal
- * @brief	p^CYeXg`}N
+ * @brief	パラメタライズテスト定義マクロ
 */
 #define IIUT_TEST_PMZ_(testcase_, testname_, method_, parent_class_, type_id_, ...)				\
 	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_);										\
-	class IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_) : public parent_class_ {			\
-		IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_));	\
+	class IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)	: public parent_class_ {			\
+	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_));		\
 		public:	IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)(void) {}						\
-		static ::std::string MakeTestName(void) { return ::iutest::detail::MakeIndexTestName(#testname_		\
-		, ::iutest::detail::GetTypeUniqueCounter<IUTEST_TEST_CLASS_NAME_(testcase_, testname_)>()); }		\
+		static ::std::string MakeTestName(void) { return ::iutest::detail::MakeIndexTestName(	\
+			IUTEST_TO_NAME_STR_(testname_), ::iutest::detail::GetTypeUniqueCounter<				\
+				IUTEST_TEST_CLASS_NAME_(testcase_, testname_)>()); }							\
 		protected: virtual void Body(void) { method_(__VA_ARGS__); }							\
 	};																							\
 	::iutest::detail::TestInstance<IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)>			\
-	IUTEST_PP_CAT(s_##testcase_##_##testname_, __LINE__)( IUTEST_CONCAT_PACKAGE_(testcase_)		\
-	, IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)::MakeTestName().c_str(), #__VA_ARGS__	\
-		, type_id_, parent_class_::SetUpTestCase, parent_class_::TearDownTestCase)
+	IUTEST_PP_CAT( IUTEST_TEST_INSTANCE_NAME_(testcase_, testname_), __LINE__)(					\
+		IUTEST_CONCAT_PACKAGE_(IUTEST_TO_NAME_(testcase_))										\
+		, IUTEST_PMZ_TEST_CLASS_NAME_(testcase_, testname_)::MakeTestName().c_str()				\
+		, #__VA_ARGS__, type_id_, parent_class_::SetUpTestCase, parent_class_::TearDownTestCase)
 
 #endif
 
 /**
  * @internal
- * @brief	ASSERTION bZ[W
+ * @brief	ASSERTION メッセージ処理
 */
 #define IUTEST_MESSAGE_AT(file_, line_, msg_, result_type_)	::iutest::AssertionHelper(file_, line_, msg_, result_type_) = ::iutest::AssertionHelper::Fixed()
 #define IUTEST_MESSAGE(msg_, result_type_)					IUTEST_MESSAGE_AT(__FILE__, __LINE__, msg_, result_type_)
 
 /**
  * @internal
- * @brief	ASSERT bZ[W
+ * @brief	ASSERT メッセージ処理
 */
 #define IUTEST_ASSERT_FAILURE(msg)					IUTEST_ASSERT_FAILURE_AT(msg, __FILE__, __LINE__)
 
-#define IUTEST_ASSERT_FAILURE_AT(msg, file, line)	return IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kFatalFailure)
+#if !defined(IUTEST_NO_VOID_RETURNS)
+#  define IUTEST_ASSERT_FAILURE_AT(msg, file, line)	return IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kFatalFailure)
+#else
+#  define IUTEST_ASSERT_FAILURE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kFatalFailure)
+#endif
 
 /**
  * @internal
- * @brief	EXPECT bZ[W
+ * @brief	EXPECT メッセージ処理
 */
 #define IUTEST_EXPECT_FAILURE(msg)					IUTEST_EXPECT_FAILURE_AT(msg, __FILE__, __LINE__)
 
-#define IUTEST_EXPECT_FAILURE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kNotFatalFailure)
+#define IUTEST_EXPECT_FAILURE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kNonFatalFailure)
 
 /**
  * @internal
- * @brief	INFORM bZ[W
+ * @brief	INFORM メッセージ処理
 */
 #define IUTEST_INFORM_FAILURE(msg)					IUTEST_INFORM_FAILURE_AT(msg, __FILE__, __LINE__)
 
 #define IUTEST_INFORM_FAILURE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kWarning)
 
+/**
+ * @internal
+ * @brief	ASSUME メッセージ処理
+*/
+#define IUTEST_ASSUME_FAILURE(msg)					IUTEST_ASSUME_FAILURE_AT(msg, __FILE__, __LINE__)
+
+#if !defined(IUTEST_NO_VOID_RETURNS)
+#  define IUTEST_ASSUME_FAILURE_AT(msg, file, line)	return IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kAssumeFailure)
+#else
+#  define IUTEST_ASSUME_FAILURE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kAssumeFailure)
+#endif
+
+/**
+* @internal
+* @brief	SKIP メッセージ処理
+*/
+#define IUTEST_SKIP_MESSAGE(msg)					IUTEST_SKIP_MESSAGE_AT(msg, __FILE__, __LINE__)
+
+#if !defined(IUTEST_NO_VOID_RETURNS)
+#  define IUTEST_SKIP_MESSAGE_AT(msg, file, line)	return IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kSkip)
+#else
+#  define IUTEST_SKIP_MESSAGE_AT(msg, file, line)	IUTEST_MESSAGE_AT(file, line, msg, ::iutest::TestPartResult::kSkip)
+#endif
 
 #ifndef IUTEST_MAKE_ASSERTIONRESULT_
 #  define IUTEST_MAKE_ASSERTIONRESULT_(ar)	ar
@@ -107,12 +208,11 @@
 
 /**
  * @internal
- * @biref	r؃}N
+ * @biref	比較検証マクロ
 */
 #define IUTEST_TEST_ASSERT_(expression, on_failure)	\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_					\
-	if( ::iutest::detail::add_revalue_reference<	\
-		const ::iutest::AssertionResult>::type iutest_ar = IUTEST_MAKE_ASSERTIONRESULT_(expression) )	\
+	if( const ::iutest::AssertionResult iutest_ar = IUTEST_MAKE_ASSERTIONRESULT_(expression) )	\
 		;											\
 	else											\
 		on_failure(iutest_ar.message())
@@ -120,7 +220,7 @@
 #if IUTEST_HAS_EXCEPTIONS
 /**
  * @internal
- * @brief	throw eXgp}N
+ * @brief	throw テスト用マクロ
 */
 #define IUTEST_TEST_THROW_(statement, expected_exception, on_failure)		\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
@@ -142,7 +242,7 @@
 
 /**
  * @internal
- * @brief	throw eXgp}N
+ * @brief	throw テスト用マクロ
 */
 #define IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, pred_formatter)	\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_														\
@@ -153,8 +253,8 @@
 				#expected_exception ".\n  Actual: it throws nothing.";					\
 			goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);						\
 		} catch( expected_exception const& e) {											\
-			if( ::iutest::detail::add_revalue_reference<const ::iutest::AssertionResult>::type 				\
-				ar = pred_formatter("e", #expected_exception_value, e, expected_exception_value) ) {		\
+			if( const ::iutest::AssertionResult	ar										\
+				= pred_formatter("e", #expected_exception_value, e, expected_exception_value) ) {			\
 			} else {																	\
 				iutest_ar << "\nExpected: " #statement " throws an exception of value\n" << ar.message();	\
 				goto IUTEST_PP_CAT(iutest_label_throw_value, __LINE__);					\
@@ -179,7 +279,7 @@
 
 /**
  * @internal
- * @brief	any throw eXgp}N
+ * @brief	any throw テスト用マクロ
 */
 #define IUTEST_TEST_ANY_THROW_(statement, on_failure)						\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
@@ -195,7 +295,7 @@
 
 /**
  * @internal
- * @brief	no throw eXgp}N
+ * @brief	no throw テスト用マクロ
 */
 #define IUTEST_TEST_NO_THROW_(statement, on_failure)						\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
@@ -222,8 +322,7 @@
 
 #define IUTEST_TEST_BOOLEAN_(expression, text, actual, expected, on_failure)	\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_												\
-	if( ::iutest::detail::add_revalue_reference<const ::iutest::AssertionResult>::type	\
-		iutest_ar = ::iutest::AssertionResult((expression) ? true : false) )	\
+	if( const ::iutest::AssertionResult iutest_ar = ::iutest::AssertionResult((expression) ? true : false) )	\
 		;																		\
 	else																		\
 		on_failure(::iutest::internal::GetBooleanAssertionFailureMessage(		\
@@ -231,8 +330,13 @@
 
 /**
  * @internal
- * @brief	IȎs
+ * @brief	明示的な失敗
 */
+#define IUTEST_ASSERT(cond)					do { if( !(cond) ) {												\
+												IUTEST_MESSAGE(#cond, ::iutest::TestPartResult::kFatalFailure);	\
+												exit(1);														\
+											} } while(::iutest::detail::AlwaysFalse())
+
 #define IIUT_SUCCEED()						IUTEST_MESSAGE("Succeeded.\n", ::iutest::TestPartResult::kSuccess)
 #define IIUT_FAIL()							IUTEST_ASSERT_FAILURE("Failed.\n")
 #define IIUT_ADD_FAILURE()					IUTEST_EXPECT_FAILURE("Failed.\n")
@@ -240,15 +344,36 @@
 
 /**
  * @internal
- * @brief	bZ[WMO
+ * @brief	メッセージロギング
 */
 #define IIUT_SCOPED_MESSAGE(msg_)			\
-	const ::iutest::AssertionHelper::ScopedMessage IUTEST_PP_CAT(scoped_message_, __LINE__) = ::iutest::detail::iuCodeMessage(__FILE__, __LINE__, ::iutest::Message() << (msg_))
-
+	const ::iutest::AssertionHelper::ScopedMessage IUTEST_PP_CAT(scoped_message_, IUTEST_PP_COUNTER) = ::iutest::detail::iuCodeMessage(__FILE__, __LINE__, ::iutest::Message() << (msg_))
 
 /**
  * @internal
- * @brief	eXg}N
+ * @brief	IUTEST_ANALYSIS_ASSUME_ を通す
+*/
+#if defined(_MSC_VER) && _MSC_VER >= 1500
+
+#define IUTEST_THROUGH_ANALYSIS_ASSUME_(expr, todo)					\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_									\
+	if( bool b = true ) {											\
+		IUTEST_UNUSED_VAR(b);										\
+		__analysis_assume(expr);									\
+		goto IUTEST_PP_CAT(iutest_label_analysis_assume, __LINE__);	\
+	} else															\
+		IUTEST_PP_CAT(iutest_label_analysis_assume, __LINE__):		\
+		todo
+
+#else
+
+#define IUTEST_THROUGH_ANALYSIS_ASSUME_(expr, todo)	todo
+
+#endif
+
+/**
+ * @internal
+ * @brief	テストマクロ
  * @{
 */
 #define	IUTEST_TEST_EQ(expected, actual, on_failure)	IUTEST_PRED_FORMAT2_( ::iutest::internal::EqHelper<IUTEST_IS_NULLLITERAL(expected)>::Compare, expected, actual, on_failure )
@@ -259,8 +384,6 @@
 #define	IUTEST_TEST_GE(v1, v2, on_failure)				IUTEST_PRED_FORMAT2_( ::iutest::internal::CmpHelperGE, v1, v2, on_failure )
 #define	IUTEST_TEST_GT(v1, v2, on_failure)				IUTEST_PRED_FORMAT2_( ::iutest::internal::CmpHelperGT, v1, v2, on_failure )
 
-#define IUTEST_TEST_EQ_COLLECTIONS(b1, e1, b2, e2, on_failure) IUTEST_PRED_FORMAT4_( ::iutest::internal::CmpHelperEqCollections, b1, e1, b2, e2, on_failure)
-
 #define IUTEST_TEST_TRUE(expr, text, on_failure)		IUTEST_TEST_BOOLEAN_( expr, text, false, true, on_failure)
 #define IUTEST_TEST_FALSE(expr, text, on_failure)		IUTEST_TEST_BOOLEAN_( !(expr), text, true, false, on_failure)
 
@@ -277,34 +400,48 @@
 #define IUTEST_TEST_HRESULT_SUCCEEDED(hr, on_failure)	IUTEST_PRED_FORMAT1_( ::iutest::internal::IsHRESULTSuccess, hr, on_failure )
 #define IUTEST_TEST_HRESULT_FAILED(hr, on_failure)		IUTEST_PRED_FORMAT1_( ::iutest::internal::IsHRESULTFailure, hr, on_failure )
 
-#define IUTEST_TEST_NULL(v, on_failure)					IUTEST_PRED_FORMAT1_( ::iutest::internal::CmpHelperNull, v, on_failure )
-#define IUTEST_TEST_NOTNULL(v, on_failure)				IUTEST_PRED_FORMAT1_( ::iutest::internal::CmpHelperNotNull, v, on_failure )
+#define IUTEST_TEST_NULL(v, on_failure)					IUTEST_THROUGH_ANALYSIS_ASSUME_(v==NULL, IUTEST_PRED_FORMAT1_( ::iutest::internal::NullHelper<IUTEST_IS_NULLLITERAL(v)>::CompareEq, v, on_failure ))
+#define IUTEST_TEST_NOTNULL(v, on_failure)				IUTEST_THROUGH_ANALYSIS_ASSUME_(v!=NULL, IUTEST_PRED_FORMAT1_( ::iutest::internal::NullHelper<IUTEST_IS_NULLLITERAL(v)>::CompareNe, v, on_failure ))
 
 #define IUTEST_TEST_SAME(v1, v2, on_failure)			IUTEST_PRED_FORMAT2_( ::iutest::internal::CmpHelperSame, v1, v2, on_failure )
 
+#define IUTEST_TEST_NO_FAILURE_(statement, on_failure)				\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
+	if( ::iutest::detail::AlwaysTrue() ) {									\
+		::iutest::detail::NewTestPartResultCheckHelper::Counter<			\
+			::iutest::detail::NewTestPartResultCheckHelper::CondGt<			\
+			::iutest::TestPartResult::kSuccess> >	iutest_failure_checker;	\
+		IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING( { (void)0; statement; } )	\
+		if( iutest_failure_checker.count() > 0 ) {							\
+			goto IUTEST_PP_CAT(iutest_label_test_no_failure_, __LINE__);	\
+		}																	\
+	} else																	\
+		IUTEST_PP_CAT(iutest_label_test_no_failure_, __LINE__):			\
+		on_failure("\nExpected: " #statement " doesn't generate new failure.\n  Actual: it does.")
+
 #define IUTEST_TEST_NO_FATAL_FAILURE_(statement, on_failure)				\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_											\
 	if( ::iutest::detail::AlwaysTrue() ) {									\
-		::iutest::detail::NewTestPartResultCheckHelper::Reporter<			\
-			::iutest::detail::NewTestPartResultCheckHelper::CondNe<			\
-			::iutest::TestPartResult::kSuccess> >	iutest_failure_checker;	\
+		::iutest::detail::NewTestPartResultCheckHelper::Counter<			\
+			::iutest::detail::NewTestPartResultCheckHelper::CondEq<			\
+			::iutest::TestPartResult::kFatalFailure> >	iutest_failure_checker;	\
 		IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING( { (void)0; statement; } )	\
 		if( iutest_failure_checker.count() > 0 ) {							\
-			goto IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__);		\
+			goto IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__);	\
 		}																	\
 	} else																	\
 		IUTEST_PP_CAT(iutest_label_test_no_fatalfailure_, __LINE__):		\
-		on_failure("\nExpected: " #statement " doesn't generate new failure.\n  Actual: it does.")
+		on_failure("\nExpected: " #statement " doesn't generate new fatal failure.\n  Actual: it does.")
 
-#define IUTEST_TEST_SKIP()		\
+#define IUTEST_TEST_SKIP()					\
 	IUTEST_AMBIGUOUS_ELSE_BLOCKER_			\
-	if( ::iutest::Test::HasFailure() )		\
-		return;								\
-	else									\
-		return ::iutest::UnitTest::SkipTest()
+	if( !::iutest::Test::HasFailure() )		\
+		::iutest::UnitTest::SkipTest();		\
+	if( ::iutest::detail::AlwaysTrue() )	\
+		IUTEST_SKIP_MESSAGE(::iutest::Test::HasFailure() ? "Skipped. but already failed. " : "Skipped. ")
 
 /**
  * @}
 */
 
-#endif
+#endif	// INCG_IRIS_IUTEST_INTERNAL_HPP_A5BD9FBB_B57A_4C1D_B205_0ADB7798DBF9_
