@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_option_message.hpp
- * @brief		iris unit test R}hCbZ[W t@C
+ * @brief		iris unit test コマンドラインメッセージ ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_option_message_HPP_00EB9B17_0615_4678_9AD0_1F5B295B404F_
-#define INCG_IRIS_iutest_option_message_HPP_00EB9B17_0615_4678_9AD0_1F5B295B404F_
+#ifndef INCG_IRIS_IUTEST_OPTION_MESSAGE_HPP_00EB9B17_0615_4678_9AD0_1F5B295B404F_
+#define INCG_IRIS_IUTEST_OPTION_MESSAGE_HPP_00EB9B17_0615_4678_9AD0_1F5B295B404F_
 
 //======================================================================
 // include
@@ -31,15 +31,15 @@ class iuOptionMessage
 {
 public:
 	/**
-	 * @brief	wv̏o
+	 * @brief	ヘルプの出力
 	*/
 	static void	ShowHelp(void);
 	/**
-	 * @brief	o[Wo
+	 * @brief	バージョン出力
 	*/
 	static void	ShowVersion(void);
 	/**
-	 * @brief	@\o
+	 * @brief	機能出力
 	*/
 	static void ShowFeature(void);
 };
@@ -97,11 +97,13 @@ inline void	iuOptionMessage::ShowVersion(void)
 inline void iuOptionMessage::ShowFeature(void)
 {
 #define SHOW_MACRO(macro)	detail::iuConsole::output("#define %s  %s\n", #macro, IUTEST_PP_TOSTRING(macro))
+	SHOW_MACRO(IUTEST_HAS_ANY_PARAM_TEST);
 	SHOW_MACRO(IUTEST_HAS_ASSERTION_RETURN);
 	SHOW_MACRO(IUTEST_HAS_CHAR16_T);
 	SHOW_MACRO(IUTEST_HAS_CHAR32_T);
 	SHOW_MACRO(IUTEST_HAS_CLOCK);
 	SHOW_MACRO(IUTEST_HAS_COMBINE);
+	SHOW_MACRO(IUTEST_HAS_CONCAT);
 	SHOW_MACRO(IUTEST_HAS_CONSTEXPR);
 	SHOW_MACRO(IUTEST_HAS_CTIME);
 	SHOW_MACRO(IUTEST_HAS_CXX11);
@@ -109,7 +111,9 @@ inline void iuOptionMessage::ShowFeature(void)
 	SHOW_MACRO(IUTEST_HAS_EXCEPTIONS);
 	SHOW_MACRO(IUTEST_HAS_GENRAND);
 	SHOW_MACRO(IUTEST_HAS_GETTIMEOFDAY);
+	SHOW_MACRO(IUTEST_HAS_IF_EXISTS);
 	SHOW_MACRO(IUTEST_HAS_IGNORE_TEST);
+	SHOW_MACRO(IUTEST_HAS_INITIALIZER_LIST);
 	SHOW_MACRO(IUTEST_HAS_LIB);
 	SHOW_MACRO(IUTEST_HAS_MINIDUMP);
 	SHOW_MACRO(IUTEST_HAS_NULLPTR);
@@ -131,6 +135,7 @@ inline void iuOptionMessage::ShowFeature(void)
 	SHOW_MACRO(IUTEST_HAS_STATIC_ASSERT_TYPEEQ);
 	SHOW_MACRO(IUTEST_HAS_STREAM_RESULT);
 	SHOW_MACRO(IUTEST_HAS_TESTNAME_ALIAS);
+	SHOW_MACRO(IUTEST_HAS_TESTNAME_ALIAS_JP);
 	SHOW_MACRO(IUTEST_HAS_TUPLE);
 	SHOW_MACRO(IUTEST_HAS_TYPED_TEST);
 	SHOW_MACRO(IUTEST_HAS_TYPED_TEST_P);
@@ -142,7 +147,15 @@ inline void iuOptionMessage::ShowFeature(void)
 	SHOW_MACRO(IUTEST_HAS_VARIADIC_VALUES);
 	SHOW_MACRO(IUTEST_PLATFORM);
 	SHOW_MACRO(IUTEST_REPORT_SKIPPED);
-	SHOW_MACRO(IUTEST_USE_THROW_ON_ASSERT_FAILURE);
+	SHOW_MACRO(IUTEST_USE_THROW_ON_ASSERTION_FAILURE);
+
+#ifdef _IUTEST_DEBUG
+
+#ifdef _MSC_FULL_VER
+	SHOW_MACRO(_MSC_FULL_VER);
+#endif
+
+#endif
 
 #undef SHOW_MACRO
 }
@@ -150,4 +163,4 @@ inline void iuOptionMessage::ShowFeature(void)
 }	// end of namespace detail
 }	// end of namespace iutest
 
-#endif
+#endif	// INCG_IRIS_IUTEST_OPTION_MESSAGE_HPP_00EB9B17_0615_4678_9AD0_1F5B295B404F_
