@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_port.hpp
- * @brief		iris unit test ˑ֐ t@C
+ * @brief		iris unit test 依存関数 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_port_HPP_7893F685_A1A9_477a_82E8_BF06237697FF_
-#define INCG_IRIS_iutest_port_HPP_7893F685_A1A9_477a_82E8_BF06237697FF_
+#ifndef INCG_IRIS_IUTEST_PORT_HPP_7893F685_A1A9_477A_82E8_BF06237697FF_
+#define INCG_IRIS_IUTEST_PORT_HPP_7893F685_A1A9_477A_82E8_BF06237697FF_
 
 //======================================================================
 // include
@@ -25,7 +25,7 @@
 
 #include "iutest_internal_defs.hpp"
 
-#if defined(IUTEST_OS_LINUX)
+#if defined(IUTEST_OS_LINUX) || defined(IUTEST_OS_CYGWIN)
 #  include <unistd.h>
 #  include <locale.h>
 #endif
@@ -57,6 +57,12 @@ const char* GetCWD(char* buf, size_t length);
 
 void SleepMillisec(unsigned int millisec);
 
+#if defined(IUTEST_OS_WINDOWS_MOBILE)
+void Abort(void);
+#else
+inline void Abort(void) { abort(); }
+#endif
+
 }	// end of namespace posix
 
 inline void SleepMilliseconds(int n)	{ posix::SleepMillisec(static_cast<unsigned int>(n)); }
@@ -69,16 +75,16 @@ namespace detail
 namespace posix = internal::posix;
 
 /**
- * @brief	ϐ̐ݒ
+ * @brief	環境変数の設定
 */
 bool SetEnvironmentVariable(const char* name, const char* value);
 
 
 /**
- * @brief	ϐ̎擾
- * @param [in]	name	= ϐ
- * @param [out]	buf		= o̓obt@
- * @return	
+ * @brief	環境変数の取得
+ * @param [in]	name	= 環境変数名
+ * @param [out]	buf		= 出力バッファ
+ * @return	成否
 */
 bool GetEnvironmentVariable(const char* name, char* buf, size_t size);
 
@@ -93,18 +99,18 @@ inline bool GetEnvironmentVariable(const char* name, char (&buf)[SIZE])
 #endif
 
 /**
- * @brief	ϐ̎擾
- * @param [in]	name	= ϐ
- * @param [out]	var		= o͕
- * @return	
+ * @brief	環境変数の取得
+ * @param [in]	name	= 環境変数名
+ * @param [out]	var		= 出力文字列
+ * @return	成否
 */
 bool IUTEST_ATTRIBUTE_UNUSED_ GetEnvironmentVariable(const char* name, ::std::string& var);
 
 /**
- * @brief	ϐ̎擾
- * @param [in]	name	= ϐ
- * @param [out]	var		= o͐l
- * @return	
+ * @brief	環境変数の取得
+ * @param [in]	name	= 環境変数名
+ * @param [out]	var		= 出力数値
+ * @return	成否
 */
 bool IUTEST_ATTRIBUTE_UNUSED_ GetEnvironmentInt(const char* name, int& var);
 
@@ -113,20 +119,56 @@ namespace win
 {
 
 /**
- * @brief	ϊ
+ * @brief	文字列変換
 */
 ::std::string IUTEST_ATTRIBUTE_UNUSED_ WideStringToMultiByteString(const wchar_t* wide_c_str);
 
 /**
- * @brief	HRESULT ̃G[擾
- * @param [in]	hr	= G[l
- * @return	
+ * @brief	HRESULT のエラー文字列を取得
+ * @param [in]	hr	= エラー値
+ * @return	文字列
 */
 ::std::string IUTEST_ATTRIBUTE_UNUSED_ GetHResultString(HRESULT hr);
 
 }	// end of namespace win
 #endif
 
+/**
+ * @brief	ログ
+*/
+class IUTestLog
+{
+public:
+	enum Level
+	{
+		LOG_INFO
+		, LOG_WARNING
+		, LOG_ERROR
+		, LOG_FATAL
+	};
+public:
+	IUTestLog(Level level, const char* file, int line);
+
+	~IUTestLog(void);
+
+public:
+	iuStringStream::type& GetStream(void) { return m_stream; }
+private:
+	const Level kLevel;
+	iuStringStream::type m_stream;
+
+	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTestLog);
+};
+
+#define IUTEST_LOG_(level)	::iutest::detail::IUTestLog(::iutest::detail::IUTestLog::LOG_##level, __FILE__, __LINE__).GetStream()
+#define IUTEST_CHECK_(condition)	\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_	\
+	if( ::iutest::detail::IsTrue(condition) )	\
+		;										\
+	else										\
+		IUTEST_LOG_(FATAL) << "Condition " #condition " failed. "
+
+
 }	// end of namespace detail
 }	// end of namespace iutest
 
@@ -134,4 +176,4 @@ namespace win
 #  include "../impl/iutest_port.ipp"
 #endif
 
-#endif
+#endif	// INCG_IRIS_IUTEST_PORT_HPP_7893F685_A1A9_477A_82E8_BF06237697FF_
