@@ -1,30 +1,27 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_pragma.hpp
- * @brief		iris unit test pragma ˑ̋z t@C
+ * @brief		iris unit test pragma 依存の吸収 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_pragma_HPP_FBC5A1DE_3D0C_443e_84B1_5F0618DF9A6B_
-#define INCG_IRIS_iutest_pragma_HPP_FBC5A1DE_3D0C_443e_84B1_5F0618DF9A6B_
-
-//======================================================================
-// include
+#ifndef INCG_IRIS_IUTEST_PRAGMA_HPP_FBC5A1DE_3D0C_443E_84B1_5F0618DF9A6B_
+#define INCG_IRIS_IUTEST_PRAGMA_HPP_FBC5A1DE_3D0C_443E_84B1_5F0618DF9A6B_
 
 //======================================================================
 // define
 
 // pragma
-#if		defined(_MSC_VER)
+#if		defined(_MSC_VER) && _MSC_VER >= 1310
 #  define IUTEST_PRAGMA(x)	__pragma(x)
 #elif	defined(__GNUC__)
 #  define IUTEST_PRAGMA(x)	_Pragma(#x)
@@ -122,6 +119,25 @@
 #  define IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()
 #endif
 
+#if defined(_MSC_VER) && _MSC_VER < 1700
+#  define IUTEST_PRAGMA_EXTERN_TEMPLATE_WARN_DISABLE_BEGIN()	IUTEST_PRAGMA_MSC_WARN_PUSH()	\
+																IUTEST_PRAGMA_MSC_WARN_DISABLE(4231)
+#  define IUTEST_PRAGMA_EXTERN_TEMPLATE_WARN_DISABLE_END()		IUTEST_PRAGMA_MSC_WARN_POP()
+#else
+#  define IUTEST_PRAGMA_EXTERN_TEMPLATE_WARN_DISABLE_BEGIN()
+#  define IUTEST_PRAGMA_EXTERN_TEMPLATE_WARN_DISABLE_END()
+#endif
+
+#if defined(_MSC_VER) && IUTEST_HAS_CONSTEXPR
+#  define IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()	IUTEST_PRAGMA_MSC_WARN_PUSH()	\
+																			IUTEST_PRAGMA_MSC_WARN_DISABLE(4592)
+#  define IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()		IUTEST_PRAGMA_MSC_WARN_POP()
+#else
+#  define IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
+#  define IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
+#endif
+
+
 #if		defined(_MSC_VER)
 #  define IUTEST_PRAGMA_WARN_DISABLE_SIGN_COMPARE()	IUTEST_PRAGMA(warning (disable:4389))
 #elif	defined(__clang__)
@@ -142,4 +158,4 @@
 #  define IUTEST_PRAGMA_WARN_DISABLE_EMPTY_BODY()
 #endif
 
-#endif
+#endif	// INCG_IRIS_IUTEST_PRAGMA_HPP_FBC5A1DE_3D0C_443E_84B1_5F0618DF9A6B_
