@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_regex.hpp
- * @brief		iris unit test p regex t@C
+ * @brief		iris unit test 用 regex ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_regex_HPP_1575CB44_189A_4248_B305_DB4882E3BFC2_
-#define INCG_IRIS_iutest_regex_HPP_1575CB44_189A_4248_B305_DB4882E3BFC2_
+#ifndef INCG_IRIS_IUTEST_REGEX_HPP_1575CB44_189A_4248_B305_DB4882E3BFC2_
+#define INCG_IRIS_IUTEST_REGEX_HPP_1575CB44_189A_4248_B305_DB4882E3BFC2_
 
 //======================================================================
 // include
@@ -25,7 +25,7 @@ namespace detail
 {
 
 /**
- * @brief	regex NX
+ * @brief	regex クラス
 */
 class iuRegex
 {
@@ -41,4 +41,4 @@ public:
 #  include "../impl/iutest_regex.ipp"
 #endif
 
-#endif
+#endif	// INCG_IRIS_IUTEST_REGEX_HPP_1575CB44_189A_4248_B305_DB4882E3BFC2_
