@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_result_reporter.hpp
- * @brief		iris unit test TestPartResult |[^[ t@C
+ * @brief		iris unit test TestPartResult リポーター ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_result_reporter_HPP_803FD1F7_1FD2_4d1e_9AFC_A5851284316F_
-#define INCG_IRIS_iutest_result_reporter_HPP_803FD1F7_1FD2_4d1e_9AFC_A5851284316F_
+#ifndef INCG_IRIS_IUTEST_RESULT_REPORTER_HPP_803FD1F7_1FD2_4D1E_9AFC_A5851284316F_
+#define INCG_IRIS_IUTEST_RESULT_REPORTER_HPP_803FD1F7_1FD2_4D1E_9AFC_A5851284316F_
 
 //======================================================================
 // include
@@ -28,7 +28,7 @@ namespace detail
 //======================================================================
 // class
 /**
- * @brief	ftHg TestPartResult |[^[
+ * @brief	デフォルト TestPartResult リポーター
 */
 class DefaultGlobalTestPartResultReporter : public TestPartResultReporterInterface
 {
@@ -42,7 +42,7 @@ public:
 };
 
 /**
- * @brief	TestPartResult ̏Wwp[
+ * @brief	TestPartResult の情報収集ヘルパー
 */
 class NewTestPartResultCheckHelper
 {
@@ -64,6 +64,15 @@ public:
 			return result.type() != Type;
 		}
 	};
+
+	template<TestPartResult::Type Type>
+	struct CondGt
+	{
+		bool operator ()(const TestPartResult& result)
+		{
+			return result.type() > Type;
+		}
+	};
 public:
 	template<typename REPORTER>
 	class Reporter : public REPORTER
@@ -91,7 +100,7 @@ public:
 		Counter(void) : m_count(0)
 		{
 		}
-		virtual void ReportTestPartResult(const TestPartResult& result)
+		virtual void ReportTestPartResult(const TestPartResult& result) IUTEST_CXX_OVERRIDE
 		{
 			if( m_cond(result) )
 			{
@@ -113,7 +122,7 @@ public:
 		typedef REPORTER	_Mybase;
 		typedef ::std::vector<TestPartResult>	TestPartResults;
 	public:
-		virtual void ReportTestPartResult(const TestPartResult& result)
+		virtual void ReportTestPartResult(const TestPartResult& result) IUTEST_CXX_OVERRIDE
 		{
 			m_results.push_back(result);
 			_Mybase::ReportTestPartResult(result);
@@ -134,7 +143,7 @@ namespace iutest_report_result
 {
 
 /**
-	* @brief	TestPartResult |[^[
+	* @brief	TestPartResult リポーター
 */
 inline void ReportTestPartResult(const ::iutest::TestPartResult& test_part_result)
 {
@@ -143,5 +152,4 @@ inline void ReportTestPartResult(const ::iutest::TestPartResult& test_part_resul
 
 }
 
-
-#endif
+#endif	// INCG_IRIS_IUTEST_RESULT_REPORTER_HPP_803FD1F7_1FD2_4D1E_9AFC_A5851284316F_
