@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_assertion.hpp
- * @brief		iris unit test assertion ` t@C
+ * @brief		iris unit test assertion 定義 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_assertion_HPP_E6AF3476_DA81_46f7_A961_ACCEF7363932_
-#define INCG_IRIS_iutest_assertion_HPP_E6AF3476_DA81_46f7_A961_ACCEF7363932_
+#ifndef INCG_IRIS_IUTEST_ASSERTION_HPP_E6AF3476_DA81_46F7_A961_ACCEF7363932_
+#define INCG_IRIS_IUTEST_ASSERTION_HPP_E6AF3476_DA81_46F7_A961_ACCEF7363932_
 
 //======================================================================
 // include
@@ -25,76 +25,78 @@
 
 namespace iutest_report_result
 {
-	//! TestPartResultReporter Ȃꍇ̏֐
+	//! TestPartResultReporter がない場合の処理関数
 	void ReportTestPartResult(const ::iutest::TestPartResult& test_part_result);
 }
 
 namespace iutest
 {
 
-//! Message NX
-typedef detail::iuMessage	Message;
+//! Message クラス
+typedef detail::iuStreamMessage	Message;
 
 //======================================================================
 // class
 /**
- * @brief	eXg
+ * @brief	テスト結果
 */
 class AssertionResult
 {
 public:
 	/**
-	 * @brief	RXgN^
-	 * @param [in] result = eXgʐ^Ul
+	 * @brief	コンストラクタ
+	 * @param [in] result = テスト結果真偽値
 	*/
 	AssertionResult(bool result) : m_result(result) {}
-	//! Rs[RXgN^
+	//! コピーコンストラクタ
 	AssertionResult(const AssertionResult& rhs) : m_message(rhs.m_message), m_result(rhs.m_result) {}
 
 	/**
-	 * @brief	
+	 * @brief	成否
 	*/
-	bool	failed(void)	const	{ return !m_result; }
+	bool	failed(void) const IUTEST_CXX_NOEXCEPT_SPEC { return !m_result; }
 
 	/**
-	 * @brief	bZ[W̎擾
+	 * @brief	メッセージの取得
 	*/
-	const char*		message(void)	const	{ return m_message.message(); }
+	const char* message(void) const { return m_message.c_str(); }
 
 	/**
-	 * @brief	bZ[W̎擾
+	 * @brief	メッセージの取得
 	 * @deprecated please use message() instead.
 	*/
 	const char* failure_message(void) const { return message(); }
 
 	/** @private */
-	IUTEST_CXX_EXPLICIT_CONVERSION operator bool (void)	const	{ return m_result; }
+	IUTEST_CXX_EXPLICIT_CONVERSION operator bool (void)	const { return m_result; }
 
 public:
 	/**
-	 * @brief	bZ[Wǉ
+	 * @brief	メッセージ追加
 	*/
 	template<typename T>
-	AssertionResult&		operator << (T value)
+	AssertionResult& operator << (T value)
 	{
-		m_message << (value);
+		Message msg;
+		msg << value;
+		m_message += msg.GetString();
 		return *this;
 	}
 
 public:
 	/**
-	 * @brief	ʂ̍쐬
+	 * @brief	成功結果の作成
 	*/
-	static AssertionResult	Success(void)	{ return AssertionResult(true); }
+	static AssertionResult	Success(void) { return AssertionResult(true); }
 	/**
-	 * @brief	sʂ̍쐬
+	 * @brief	失敗結果の作成
 	*/
-	static AssertionResult	Failure(void)	{ return AssertionResult(false); }
+	static AssertionResult	Failure(void) { return AssertionResult(false); }
 
 private:
 	IUTEST_PP_DISALLOW_ASSIGN(AssertionResult);
 
-	Message m_message;
+	::std::string m_message;
 	bool	m_result;
 };
 
@@ -103,21 +105,40 @@ private:
  * @brief	Assetion Return Type
 */
 template<typename R>
-struct AssertionReturn
+struct AssertionReturnType
 {
-	R value;	//!< ߂l
-	//! RXgN^
-	AssertionReturn() {}
+	R value;	//!< 戻り値
+	//! コンストラクタ
+	AssertionReturnType() {}
 	/**
-	 * @brief	RXgN^
-	 * @param [in]	v : ߂l̒l
+	 * @brief	コンストラクタ
+	 * @param [in]	v : 戻り値の値
 	*/
-	AssertionReturn(const R& v) : value(v) {}
+	AssertionReturnType(const R& v) : value(v) {}
 };
+/**
+ * @brief	Assetion Return Type (void)
+*/
+template<>
+struct AssertionReturnType<void>
+{
+	//! コンストラクタ
+	AssertionReturnType() {}
+};
+
+/**
+ * @brief	Assetion Return 設定
+*/
+template<typename T>
+inline AssertionReturnType<T> AssertionReturn(const T& ret) { return AssertionReturnType<T>(ret); }
+
+/** @overload */
+inline AssertionReturnType<void> AssertionReturn(void) { return AssertionReturnType<void>(); }
+
 #endif
 
 /**
- * @brief	Assertion \zNX
+ * @brief	Assertion 構築クラス
 */
 class AssertionHelper
 {
@@ -162,14 +183,26 @@ public:
 	class Fixed : public Message {
 	public:
 		template<typename T>
-		Fixed&		operator << (T value)
+		Fixed& operator << (T val)
 		{
-			Message::operator << (value);
+			Message::operator << (val);
 			return *this;
 		}
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+		Fixed& operator << (iu_basic_iomanip val)
+		{
+			Message::operator << (val);
+			return *this;
+		}
+#endif
+
 #if IUTEST_HAS_ASSERTION_RETURN
+		Fixed& operator << (const AssertionReturnType<void>&)
+		{
+			return *this;
+		}
 		template<typename R>
-		ReturnTypedFixed<R> operator << (const AssertionReturn<R>& ret)
+		ReturnTypedFixed<R> operator << (const AssertionReturnType<R>& ret)
 		{
 			return ReturnTypedFixed<R>(*this, ret);
 		}
@@ -181,28 +214,28 @@ private:
 	template<typename R>
 	struct ReturnTypedFixed {
 		Fixed fixed;
-		AssertionReturn<R> ret;
-		ReturnTypedFixed(const Fixed& f, const AssertionReturn<R>& r) : fixed(f), ret(r) {}
+		AssertionReturnType<R> ret;
+		ReturnTypedFixed(const Fixed& f, const AssertionReturnType<R>& r) : fixed(f), ret(r) {}
 	};
 #endif
 
 public:
 	/**
-	 * @brief	RXgN^
-	 * @param [in]	file	= t@C
-	 * @param [in]	line	= sԍ
-	 * @param [in]	message	= bZ[W
-	 * @param [in]	type	= eXgʂ̃^Cv
+	 * @brief	コンストラクタ
+	 * @param [in]	file	= ファイル名
+	 * @param [in]	line	= 行番号
+	 * @param [in]	message	= メッセージ
+	 * @param [in]	type	= テスト結果のタイプ
 	*/
 	AssertionHelper(const char* file, int line, const char* message, TestPartResult::Type type)
 		: m_part_result(file, line, message, type)
 	{}
 	/**
-	 * @brief	RXgN^
-	 * @param [in]	file	= t@C
-	 * @param [in]	line	= sԍ
-	 * @param [in]	message	= bZ[W
-	 * @param [in]	type	= eXgʂ̃^Cv
+	 * @brief	コンストラクタ
+	 * @param [in]	file	= ファイル名
+	 * @param [in]	line	= 行番号
+	 * @param [in]	message	= メッセージ
+	 * @param [in]	type	= テスト結果のタイプ
 	*/
 	AssertionHelper(const char* file, int line, const ::std::string& message, TestPartResult::Type type)
 		: m_part_result(file, line, message.c_str(), type)
@@ -218,12 +251,20 @@ private:
 
 public:
 	/** @private */
-	void	operator = (const Fixed& fixed)
+	void operator = (const Fixed& fixed)
 	{
 		OnFixed(fixed);
-#if IUTEST_HAS_EXCEPTIONS && IUTEST_USE_THROW_ON_ASSERT_FAILURE
+#if IUTEST_HAS_EXCEPTIONS && IUTEST_USE_THROW_ON_ASSERTION_FAILURE
 		{
-			if( m_part_result.type() == TestPartResult::kFatalFailure ) throw TestPartResult::kFatalFailure;
+			switch( m_part_result.type() )
+			{
+			case TestPartResult::kSkip:
+			case TestPartResult::kAssumeFailure:
+			case TestPartResult::kFatalFailure:
+				throw m_part_result.type();
+			default:
+				break;
+			}
 		}
 #endif
 	}
@@ -238,18 +279,18 @@ public:
 #endif
 
 private:
-	void	OnFixed(const Fixed& fixed) throw()
+	void OnFixed(const Fixed& fixed)
 	{
-		// OnFixed  throw ȂƁIeXg̗OLb`ɂȂȂ
+		// OnFixed で throw しないこと！テスト側の例外キャッチにかからなくなる
 
-		m_part_result.add_message(fixed.message());
+		m_part_result.add_message(fixed.GetString());
 		if( MessageList::s_scoped_message.count() )
 		{
 			m_part_result.add_message("\niutest trace:");
 			for( msg_list::iterator it = MessageList::s_scoped_message.begin(), end=MessageList::s_scoped_message.end(); it != end; ++it )
 			{
-				// TODO : ǉbZ[WƂĕۑׂ
-				// ̓eXgʂ̃bZ[WɒǉĂB
+				// TODO : 追加メッセージとして保存するべき
+				// 現状はテスト結果のメッセージに追加している。
 				m_part_result.add_message("\n");
 				m_part_result.add_message(it->make_message().c_str());
 			}
@@ -265,12 +306,10 @@ private:
 			ReportTestPartResult(m_part_result);
 		}
 
-		if( m_part_result.type() != TestPartResult::kSuccess )
+		if( m_part_result.type() != TestPartResult::kSuccess
+			&& TestFlag::IsEnableFlag(iutest::TestFlag::BREAK_ON_FAILURE) )
 		{
-			if( TestFlag::IsEnableFlag(iutest::TestFlag::BREAK_ON_FAILURE) )
-			{
-				IUTEST_BREAK();
-			}
+			IUTEST_BREAK();
 		}
 	}
 
@@ -290,19 +329,19 @@ namespace iutest
 //======================================================================
 // function
 /**
- * @brief	eXg AssertionResult IuWFNg̎擾
+ * @brief	テスト成功を示す AssertionResult オブジェクトの取得
 */
-inline AssertionResult	AssertionSuccess(void)	{ return AssertionResult::Success(); }
+inline AssertionResult AssertionSuccess(void) { return AssertionResult::Success(); }
 /**
- * @brief	eXgs AssertionResult IuWFNg̎擾
+ * @brief	テスト失敗を示す AssertionResult オブジェクトの取得
 */
-inline AssertionResult	AssertionFailure(void)	{ return AssertionResult::Failure(); }
+inline AssertionResult AssertionFailure(void) { return AssertionResult::Failure(); }
 
 namespace internal
 {
 
 /**
- * @brief	reXg̒l𕶎ɃtH[}bg
+ * @brief	比較テストの値を文字列にフォーマット
 */
 template<typename T1, typename T2>
 inline ::std::string FormatForComparisonFailureMessage(const T1& value, const T2& /*other_operand*/)
@@ -311,7 +350,7 @@ inline ::std::string FormatForComparisonFailureMessage(const T1& value, const T2
 }
 
 /**
- * @brief	boolean eXg̎sbZ[W̏o
+ * @brief	boolean テストの失敗メッセージの出力
 */
 inline ::std::string GetBooleanAssertionFailureMessage(const AssertionResult& ar, const char* expr, const char* actual, const char* expected)
 {
@@ -331,7 +370,7 @@ inline ::std::string GetBooleanAssertionFailureMessage(const AssertionResult& ar
 }
 
 /**
- * @brief	Eq nAT[V
+ * @brief	Eq 系アサーション
 */
 inline AssertionResult EqFailure(const char* expected_expression, const char* actual_expression, const char* expected, const char* actual, bool ignoring_case=false)
 {
@@ -339,8 +378,14 @@ inline AssertionResult EqFailure(const char* expected_expression, const char* ac
 	strm << "error: Value of " << actual_expression
 		<< "\n  Actual: " << actual
 		<< "\nExpected: " << expected_expression;
-	if( ignoring_case ) strm << " (ignoring case)";
-	if( !detail::IsStringEqual(expected_expression, expected) ) strm << "\nWhich is: " << expected;
+	if( ignoring_case )
+	{
+		strm << " (ignoring case)";
+	}
+	if( !detail::IsStringEqual(expected_expression, expected) )
+	{
+		strm << "\nWhich is: " << expected;
+	}
 	return AssertionFailure() << strm.str();
 }
 
@@ -351,8 +396,8 @@ inline AssertionResult EqFailure(const char* expected_expression, const char* ac
 #define DECL_COMPARE_HELPER_I_(op_name, op, type1, type2)									\
 	inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelper##op_name(						\
 			const char* expr1, const char* expr2, type1 val1, type2 val2) {					\
-	if( val1 op val2 ) return AssertionSuccess();											\
-	else {																					\
+	if( val1 op val2 ) { return AssertionSuccess();											\
+	} else {																				\
 	return AssertionFailure() << "error: Expected: " << expr1 << " " #op " " << expr2		\
 		<< "\n  Actual: " << FormatForComparisonFailureMessage(val1, val2)					\
 		<< " vs " << FormatForComparisonFailureMessage(val2, val1);							\
@@ -387,30 +432,65 @@ DECL_COMPARE_HELPER_(GT, > )
  * @}
 */
 
-template<typename T>
-inline AssertionResult	CmpHelperNull(const char* expr, const T* val)
+/**
+* @brief	Null Helper
+* @tparam	IsNullLiteral	= val が NULL リテラルかどうか
+*/
+template<bool IsNullLiteral>
+class NullHelper
 {
-	if( NULL == val ) return AssertionSuccess();
+public:
+	template<typename T>
+	static AssertionResult CompareEq(const char* expr, const T* val)
+	{
+		if( NULL == val )
+		{
+			return AssertionSuccess();
+		}
 
-	return AssertionFailure() << "error: Value of " << expr
-		<< "\n  Actual: " << val
-		<< "\nExpected: NULL";
-}
+		return AssertionFailure() << "error: Value of " << expr
+			<< "\n  Actual: " << val
+			<< "\nExpected: NULL";
+	}
+	template<typename T>
+	static AssertionResult	CompareNe(const char* expr, const T* val)
+	{
+		if( NULL != val )
+		{
+			return AssertionSuccess();
+		}
 
-template<typename T>
-inline AssertionResult	CmpHelperNotNull(const char* expr, const T* val)
+		return AssertionFailure() << "error: Value of " << expr
+			<< "\n  Actual: NULL\nExpected: not NULL";
+	}
+};
+
+/**
+* @brief	NullHelper 特殊化
+*/
+template<>
+class NullHelper<true>
 {
-	if( NULL != val ) return AssertionSuccess();
-
-	return AssertionFailure() << "error: Value of " << expr
-		<< "\n  Actual: NULL\nExpected: not NULL";
-}
+public:
+	static AssertionResult CompareEq(const char*, void*)
+	{
+		return AssertionSuccess();
+	}
+	static AssertionResult CompareNe(const char* expr, void*)
+	{
+		return AssertionFailure() << "error: Value of " << expr
+			<< "\n  Actual: NULL\nExpected: not NULL";
+	}
+};
 
 template<typename T1, typename T2>
 inline AssertionResult	CmpHelperSame(const char* expected_str, const char* actual_str
 									  , const T1& expected, const T2& actual)
 {
-	if( &expected == &actual ) return AssertionSuccess();
+	if( &expected == &actual )
+	{
+		return AssertionSuccess();
+	}
 
 	return AssertionFailure() << "error: Expected: &(" << expected_str << ") == &(" << actual_str
 		<< ")\n  Actual: " << FormatForComparisonFailureMessage(&expected, &actual)
@@ -426,7 +506,10 @@ inline AssertionResult CmpHelperEQ(const char* expected_str, const char* actual_
 IUTEST_PARGMA_WARN_PUSH()
 IUTEST_PRAGMA_WARN_DISABLE_SIGN_COMPARE()
 
-	if( actual == expected ) return AssertionSuccess();
+	if( actual == expected )
+	{
+		return AssertionSuccess();
+	}
 
 	return EqFailure(expected_str, actual_str
 		, FormatForComparisonFailureMessage(expected, actual).c_str()
@@ -438,7 +521,7 @@ IUTEST_PARGMA_WARN_POP()
 
 /**
  * @brief	Equal Helper
- * @tparam	IsNullLiteral	= val1  NULL eǂ
+ * @tparam	IsNullLiteral	= val1 が NULL リテラルかどうか
 */
 template<bool IsNullLiteral>
 class EqHelper
@@ -452,7 +535,7 @@ public:
 };
 
 /**
- * @brief	EqHelper ꉻ
+ * @brief	EqHelper 特殊化
 */
 template<>
 class EqHelper<true>
@@ -480,53 +563,9 @@ public:
 #endif
 };
 
-/**
- * @brief	Equal Collection Helper
-*/
-template<typename T1, typename T2>
-AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperEqCollections(const char* expr1b, const char* expr1e, const char* expr2b, const char* expr2e
-							   , T1 b1, T1 e1, T2 b2, T2 e2)
-{
-	int elem=0;
-	bool result = true;
-	Message ar;
-	for( elem=0; b1 != e1 && b2 != e2; ++b1, ++b2, ++elem )
-	{
-		if( !EqHelper<false>::Compare("", "", *b1, *b2) )
-		{
-			result = false;
-			ar << "\nMismatch in a position " << elem << ": "
-				<< FormatForComparisonFailureMessage(*b1, *b2)
-				<< " vs " << FormatForComparisonFailureMessage(*b2, *b1);
-		}
-	}
-	if( b1 != e1 )
-	{
-		int elem1 = elem;
-		for( ; b1 != e1; ++b1, ++elem1 )
-			;
-		result = false;
-		ar << "\nMismatch element : " << elem1 << " vs " << elem;
-	}
-	if( b2 != e2 )
-	{
-		int elem2 = elem;
-		for( ; b2 != e2; ++b2, ++elem2 )
-			;
-		result = false;
-		ar << "\nMismatch element : " << elem << " vs " << elem2;
-	}
-	if( !result )
-	{
-		return AssertionFailure() << "error: Expected: { " << expr1b << ", " << expr1e << " } == { "
-			<< expr2b << ", " << expr2e << " }\n  Actual:" << ar;
-	}
-	return AssertionSuccess();
-}
-
 /**
  * @brief	Not Equal Helper
- * @tparam	IsNullLiteral	= val1  NULL eǂ
+ * @tparam	IsNullLiteral	= val1 が NULL リテラルかどうか
 */
 template<bool IsNullLiteral>
 class NeHelper
@@ -540,7 +579,7 @@ public:
 };
 
 /**
- * @brief	NeHelper ꉻ
+ * @brief	NeHelper 特殊化
 */
 template<>
 class NeHelper<true>
@@ -573,9 +612,15 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNearFloatingPoint(const
 													, RawType val1, RawType val2, RawType abs_v)
 {
 	RawType diff = val1 > val2 ? val1 - val2 : val2 - val1;
-	if( diff < abs_v ) return AssertionSuccess();
+	if( diff < abs_v )
+	{
+		return AssertionSuccess();
+	}
 	floating_point<RawType> f1(diff), f2(abs_v);
-	if( f1.AlmostEquals(f2) ) return AssertionSuccess();
+	if( f1.AlmostEquals(f2) )
+	{
+		return AssertionSuccess();
+	}
 	return AssertionFailure() << "error: Value of: abs(" << expr1 << " - " << expr2 << ") <= " << absc
 		<< "\n  Actual: abs(" << val1 << " - " << val2 << ") : " << diff
 		<< "\nExpected: " << FormatForComparisonFailureMessage(abs_v, diff) ;
@@ -591,7 +636,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(const char* expr1,
 													, const T& val1, const T& val2, const A& abs_v)
 {
 	T diff = val1 > val2 ? val1 - val2 : val2 - val1;
-	if( diff <= abs_v ) return AssertionSuccess();
+	if( diff <= abs_v )
+	{
+		return AssertionSuccess();
+	}
 	return AssertionFailure() << "error: Value of: abs(" << expr1 << " - " << expr2 << ") <= " << absc
 		<< "\n  Actual: abs(" << val1 << " - " << val2 << ") : " << diff << "\nExpected: " << FormatForComparisonFailureMessage(abs_v, diff) ;
 }
@@ -614,12 +662,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 == val2 ) return AssertionSuccess();
+		if( val1 == val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( strcmp(val1, val2) == 0 )
 	{
-		if( strcmp(val1, val2) == 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
@@ -629,12 +681,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 == val2 ) return AssertionSuccess();
+		if( val1 == val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( wcscmp(val1, val2) == 0 )
 	{
-		if( wcscmp(val1, val2) == 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
@@ -644,7 +700,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 																   , const ::std::basic_string<Elem, Traits, Ax>& val1
 																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
-	if( val1 == val2 ) return AssertionSuccess();
+	if( val1 == val2 )
+	{
+		return AssertionSuccess();
+	}
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
@@ -654,7 +713,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 																   , const Elem* val1
 																   , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
-	if( val2 == val1 ) return AssertionSuccess();
+	if( val2 == val1 )
+	{
+		return AssertionSuccess();
+	}
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
@@ -664,7 +726,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 																   , const ::std::basic_string<Elem, Traits, Ax>& val1
 																   , const Elem* val2)
 {
-	if( val1 == val2 ) return AssertionSuccess();
+	if( val1 == val2 )
+	{
+		return AssertionSuccess();
+	}
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
@@ -673,9 +738,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
 															   , const char16_t* val1, const char16_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL && val2 == NULL ) 
 	{
-		if( val1 == val2 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
 	::std::u16string v1 = val1;
 	return CmpHelperSTREQ(expr1, expr2, v1, val2);
@@ -685,9 +750,9 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTREQ(const char* expr1, const char* expr2
 															   , const char32_t* val1, const char32_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( val1 == NULL && val2 == NULL ) 
 	{
-		if( val1 == val2 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
 	::std::u32string v1 = val1;
 	return CmpHelperSTREQ(expr1, expr2, v1, val2);
@@ -699,12 +764,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 != val2 ) return AssertionSuccess();
+		if( val1 != val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( strcmp(val1, val2) != 0 )
 	{
-		if( strcmp(val1, val2) != 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
 		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
@@ -714,12 +783,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 != val2 ) return AssertionSuccess();
+		if( val1 != val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( wcscmp(val1, val2) != 0 )
 	{
-		if( wcscmp(val1, val2) != 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
 		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
@@ -729,7 +802,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 															   , const ::std::basic_string<Elem, Traits, Ax>& val1
 															   , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
-	if( val1 != val2 ) return AssertionSuccess();
+	if( val1 != val2 )
+	{
+		return AssertionSuccess();
+	}
 	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
 		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
@@ -739,7 +815,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 															   , const Elem* val1
 															   , const ::std::basic_string<Elem, Traits, Ax>& val2)
 {
-	if( val2 != val1 ) return AssertionSuccess();
+	if( val2 != val1 )
+	{
+		return AssertionSuccess();
+	}
 	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
 		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
@@ -749,7 +828,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 															   , const ::std::basic_string<Elem, Traits, Ax>& val1
 															   , const Elem* val2)
 {
-	if( val1 != val2 ) return AssertionSuccess();
+	if( val1 != val2 )
+	{
+		return AssertionSuccess();
+	}
 	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2
 		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
@@ -758,9 +840,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
 															   , const char16_t* val1, const char16_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( (val1 == NULL || val2 == NULL)
+		&& val1 != val2 )
 	{
-		if( val1 != val2 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
 	::std::u16string v1 = val1;
 	return CmpHelperSTRNE(expr1, expr2, v1, val2);
@@ -770,9 +853,10 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNE(const char* expr1, const char* expr2
 															   , const char32_t* val1, const char32_t* val2)
 {
-	if( val1 == NULL || val2 == NULL ) 
+	if( (val1 == NULL || val2 == NULL)
+		&& val1 != val2 )
 	{
-		if( val1 != val2 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
 	::std::u32string v1 = val1;
 	return CmpHelperSTRNE(expr1, expr2, v1, val2);
@@ -784,12 +868,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* e
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 == val2 ) return AssertionSuccess();
+		if( val1 == val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( detail::iu_stricmp(val1, val2) == 0 )
 	{
-		if( detail::iu_stricmp(val1, val2) == 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str()
@@ -800,12 +888,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASEEQ(const char* e
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 == val2 ) return AssertionSuccess();
+		if( val1 == val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( detail::iu_wcsicmp(val1, val2) == 0 )
 	{
-		if( detail::iu_wcsicmp(val1, val2) == 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str()
@@ -837,12 +929,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* e
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 != val2 ) return AssertionSuccess();
+		if( val1 != val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( detail::iu_stricmp(val1, val2) != 0 )
 	{
-		if( detail::iu_stricmp(val1, val2) != 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2 << " (ignoring case)"
 		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
@@ -852,12 +948,16 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRCASENE(const char* e
 {
 	if( val1 == NULL || val2 == NULL ) 
 	{
-		if( val1 != val2 ) return AssertionSuccess();
+		if( val1 != val2 )
+		{
+			return AssertionSuccess();
+		}
 	}
-	else
+	else if( detail::iu_wcsicmp(val1, val2) != 0 )
 	{
-		if( detail::iu_wcsicmp(val1, val2) != 0 ) return AssertionSuccess();
+		return AssertionSuccess();
 	}
+
 	return AssertionFailure() << "error: Expected: " << expr1 << " != " << expr2 << " (ignoring case)"
 		<< "\n  Actual: " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1))
 		<< " vs " << detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2));
@@ -890,7 +990,10 @@ static AssertionResult CmpHelperFloatingPointEQ(const char* expr1, const char* e
 							   , RawType val1, RawType val2)
 {
 	floating_point<RawType> f1(val1), f2(val2);
-	if( f1.AlmostEquals(f2) ) return AssertionSuccess();
+	if( f1.AlmostEquals(f2) )
+	{
+		return AssertionSuccess();
+	}
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
@@ -900,9 +1003,15 @@ template<typename RawType>
 static AssertionResult	CmpHelperFloatingPointLE(const char* expr1, const char* expr2
 							   , RawType val1, RawType val2)
 {
-	if( val1 < val2 ) return AssertionSuccess();
+	if( val1 < val2 )
+	{
+		return AssertionSuccess();
+	}
 	floating_point<RawType> f1(val1), f2(val2);
-	if( f1.AlmostEquals(f2) ) return AssertionSuccess();
+	if( f1.AlmostEquals(f2) )
+	{
+		return AssertionSuccess();
+	}
 	return EqFailure(expr1, expr2
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val1, val2)).c_str()
 		, detail::ShowStringQuoted(FormatForComparisonFailureMessage(val2, val1)).c_str() );
@@ -924,13 +1033,19 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleLE(const char* expr1, cons
 
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ IsHRESULTSuccess(const char* expr, HRESULT hr)
 {
-	if( SUCCEEDED(hr) ) return AssertionSuccess();
+	if( SUCCEEDED(hr) )
+	{
+		return AssertionSuccess();
+	}
 	return AssertionFailure() << "error: Expected: SUCCEEDED(" << expr << ")"
 		<< "\n  Actual: " << hr << ": " << detail::win::GetHResultString(hr);
 }
 inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ IsHRESULTFailure(const char* expr, HRESULT hr)
 {
-	if( FAILED(hr) ) return AssertionSuccess();
+	if( FAILED(hr) )
+	{
+		return AssertionSuccess();
+	}
 	return AssertionFailure() << "error: Expected : FAILED(" << expr << ")"
 		<< "\n  Actual: " << hr;
 }
@@ -941,4 +1056,4 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ IsHRESULTFailure(const char* exp
 
 }	// end of namespace iutest
 
-#endif
+#endif	// INCG_IRIS_IUTEST_ASSERTION_HPP_E6AF3476_DA81_46F7_A961_ACCEF7363932_
