@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_body.hpp
- * @brief		iris unit test eXgP̃NX t@C
+ * @brief		iris unit test テスト単体クラス ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_body_HPP_3EEA6706_9954_4330_B292_129667FA6B96_
-#define INCG_IRIS_iutest_body_HPP_3EEA6706_9954_4330_B292_129667FA6B96_
+#ifndef INCG_IRIS_IUTEST_BODY_HPP_3EEA6706_9954_4330_B292_129667FA6B96_
+#define INCG_IRIS_IUTEST_BODY_HPP_3EEA6706_9954_4330_B292_129667FA6B96_
 
 //======================================================================
 // include
@@ -35,7 +35,7 @@ template<typename T>class TestWithParam;
 //======================================================================
 // class
 /**
- * @brief	eXgx[X
+ * @brief	テストベース
 */
 class Test
 {
@@ -57,19 +57,27 @@ public:
 
 public:
 	/**
-	 * @brief	s TestInfo ̎擾
+	 * @brief	実行中の TestInfo の取得
 	*/
-	static const TestInfo*	GetCurrentTestInfo(void)		{ return CurrentTestObserver::GetCurrentTestInfo(); }
+	static const TestInfo*	GetCurrentTestInfo(void)
+	{
+		const Test* curr = GetCurrentTest();
+		if( curr == NULL || curr->m_test_info == NULL )
+		{
+			return NULL;
+		}
+		return curr->m_test_info->ptr();
+	}
 
 	/**
-	 * @brief	s Test ̎擾
+	 * @brief	実行中の Test の取得
 	*/
-	static Test*			GetCurrentTest(void)			{ return CurrentTestObserver::GetCurrentTest(); }
+	static Test* GetCurrentTest(void) { return CurrentTestObserver::GetCurrentTest(); }
 
 
 	/**
-	 * @brief	vIȃG[oǂ
-	 * @return	^Ul
+	 * @brief	致命的なエラーが出たかどうか
+	 * @return	真偽値
 	*/
 	static bool	HasFatalFailure(void)
 	{
@@ -77,8 +85,8 @@ public:
 	}
 
 	/**
-	 * @brief	vIł͂ȂG[oǂ
-	 * @return	^Ul
+	 * @brief	致命的ではないエラーが出たかどうか
+	 * @return	真偽値
 	*/
 	static bool	HasNonfatalFailure(void)
 	{
@@ -86,8 +94,8 @@ public:
 	}
 
 	/**
-	 * @brief	G[oǂ
-	 * @return	^Ul
+	 * @brief	エラーが出たかどうか
+	 * @return	真偽値
 	*/
 	static bool	HasFailure(void)
 	{
@@ -95,45 +103,54 @@ public:
 	}
 
 	/**
-	 * @brief	eXgʂ̏ǉ
-	 * @param [in]	key		= vpeB̃L[
-	 * @param [in]	value	= l
+	 * @brief	テスト結果の情報追加
+	 * @param [in]	key		= プロパティのキー
+	 * @param [in]	value	= 値
 	*/
-	static void RecordProperty(const char* key, const char* value);
+	static void RecordProperty(const ::std::string& key, const ::std::string& value);
 
 	/**
-	 * @brief	eXgʂ̏ǉ
-	 * @param [in]	key		= vpeB̃L[
-	 * @param [in]	value	= l
+	 * @brief	テスト結果の情報追加
+	 * @param [in]	key		= プロパティのキー
+	 * @param [in]	value	= 値
 	*/
 	template<typename T>
-	static void RecordProperty(const char* key, const T& value)
+	static void RecordProperty(const ::std::string& key, const T& value)
 	{
-		RecordProperty(key, PrintToString(value).c_str());
+		RecordProperty(key, PrintToString(value));
 	}
 
 #if IUTEST_HAS_GENRAND
 
 	/**
-	 * @brief	̐
-	 * @note	V[h --iutest_random_seed Ŏw肵lɂȂ܂B
-	 *			w肵Ȃꍇ͎sɌ肵܂B
+	 * @brief	乱数の生成
+	 * @note	乱数シードは --iutest_random_seed で指定した値になります。
+	 *			指定しなかった場合は実行時に決定します。
 	*/
 	unsigned int	genrand(void)				{ return m_random.genrand(); }
 	/**
 	 * @overload
-	 * @param [in]	max	= [0,max) ̗𐶐
+	 * @param [in]	max	= 上限値
+	 * @return		[0,max) の乱数を生成
 	*/
 	unsigned int	genrand(unsigned int max)	{ return m_random.genrand(max); }
-	/** V[h̎擾 */
-	unsigned int	random_seed(void)			{ return m_random_seed; }
+	/**
+	 * @overload
+	 * @return		max	= [0,1] の乱数を生成
+	*/
+	float			genrandf(void)				{ return m_random.genrandf(); }
+	/** 乱数シードの取得 */
+	unsigned int	random_seed(void) const IUTEST_CXX_NOEXCEPT_SPEC { return m_random_seed; }
+
+	/** 乱数生成器の取得 */
+	detail::iuRandom& random_engine(void)		{ return m_random; }
 
 #endif
 
 protected:
-	virtual	void	SetUp(void)		{}	//!< sO
-	virtual void	Body(void)	= 0;	//!< eXg
-	virtual void	TearDown(void)	{}	//!< s㏈
+	virtual	void	SetUp(void)		{}	//!< 実行前処理
+	virtual void	Body(void)	= 0;	//!< テスト実装部
+	virtual void	TearDown(void)	{}	//!< 実行後処理
 
 public:
 	static	void	SetUpTestCase(void)		{}	//!< test case setup
@@ -141,25 +158,30 @@ public:
 
 private:
 	/**
-	 * @brief	eXg̎s
+	 * @brief	テストの実行
 	*/
 	void Run(detail::iuITestInfoMediator* test_info);
 
 private:
-	template<typename DMY=void>
+	template<typename DMY>
 	class Observer
 	{
 	public:
-		static Test*	s_current;
+		static Test* s_current;
 	public:
-		static		 Test*		GetCurrentTest(void)		{ return s_current; }
-		static const TestInfo*	GetCurrentTestInfo(void)	{ if( s_current == NULL || s_current->m_test_info == NULL ) return NULL; return s_current->m_test_info->ptr(); }
+		static Test* GetCurrentTest(void) IUTEST_CXX_NOEXCEPT_SPEC { return s_current; }
 	};
 
 	typedef Observer<void>	CurrentTestObserver;
 
+private:
+	class TestRecordPropertyHelper
+	{
+	public:
+		static void RecordProperty(const TestProperty& prop);
+	};
 protected:
-	const TestInfo* test_info_;	//!< eXgɊȒPɃANZX\Ȃ悤
+	const TestInfo* test_info_;	//!< テスト中に簡単にアクセス可能なように
 
 private:
 	friend class UnitTest;
@@ -173,29 +195,33 @@ private:
 #endif
 };
 
-template<typename DMY>
-Test*	Test::Observer<DMY>::s_current = NULL;
-
 /**
- * @brief	p[^eXgC^[tF[X
- * @tparam	T = p[^^
+ * @brief	パラメータテストインターフェース
+ * @tparam	T = パラメータ型
 */
 template<typename T>
 class WithParamInterface
 {
 public:
-	typedef T	ParamType;	//!< p[^^
+	typedef T	ParamType;	//!< パラメータ型
 protected:
 	virtual ~WithParamInterface(void)	{}
 
 public:
 	/**
-	 * @brief	p[^̎擾
+	 * @brief	パラメータの取得
 	*/
-	static const ParamType&	GetParam(void)						{ return *s_params; }
+	static const ParamType&	GetParam(void)
+	{
+		IUTEST_CHECK_(s_params != NULL) << "GetParam() can only use the value-parameterized test";
+#if defined(_MSC_VER) && _MSC_VER >= 1500
+		__analysis_assume(s_params != NULL);
+#endif
+		return *s_params;
+	}
 
 	/** @private */
-	static void				SetParam(const ParamType* params)	{ s_params = params; }
+	static void SetParam(const ParamType* params) IUTEST_CXX_NOEXCEPT_SPEC { s_params = params; }
 
 private:
 	static const ParamType*	s_params;
@@ -205,56 +231,21 @@ template<typename T>
 const T* WithParamInterface<T>::s_params = NULL;
 
 /**
- * @brief	p[^eXgx[X
- * @tparam	T = p[^^
+ * @brief	パラメータテストベース
+ * @tparam	T = パラメータ型
 */
 template<typename T>
 class TestWithParam : public Test, public WithParamInterface<T>
 {
 };
 
-inline void Test::RecordProperty(const char* key, const char* value)
-{
-	// sȃL[̃`FbN
-	const char* ban[] = { "name", "status", "time", "classname", "type_param", "value_param" };
-	::std::string key_ = key;
-	for( int i=0, n=sizeof(ban)/sizeof(ban[0]); i < n; ++i )
-	{
-		if( key_ == ban[i] )
-		{
-			key_ += "_";
-			break;
-		}
-	}
-	TestProperty prop(key_.c_str(), value);
-	if( GetCurrentTest() != NULL && GetCurrentTest()->m_test_info != NULL )
-	{
-		GetCurrentTest()->m_test_info->RecordProperty(prop);
-	}
-	
-	TestEnv::event_listeners().OnTestRecordProperty(prop);
-};
-
-inline 	void Test::Run(detail::iuITestInfoMediator* test_info)
-{
-	m_test_info = test_info;
-	test_info_ = test_info->ptr();
-	unsigned int seed = TestEnv::get_random_seed();
-	if( seed == 0 )
-	{
-		seed = detail::GetIndefiniteValue();
-	}
-	m_random_seed = seed;
-	m_random.init(seed);
-
-	SetUp();
-	Body();
-	TearDown();
-
-	test_info_ = NULL;
-	m_test_info = NULL;
-}
-
 }	// end of namespace iutest
 
+template<typename DMY>
+::iutest::Test*	::iutest::Test::Observer<DMY>::s_current = NULL;
+
+#if !IUTEST_HAS_LIB
+#  include "impl/iutest_body.ipp"
 #endif
+
+#endif	// INCG_IRIS_IUTEST_BODY_HPP_3EEA6706_9954_4330_B292_129667FA6B96_
