@@ -1,25 +1,26 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_param_tests.hpp
- * @brief		iris unit test parameter ` t@C
+ * @brief		iris unit test parameter 定義 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_param_tests_HPP_3DBBF55E_A076_4207_B49E_34734EE333EE_
-#define INCG_IRIS_iutest_param_tests_HPP_3DBBF55E_A076_4207_B49E_34734EE333EE_
+#ifndef INCG_IRIS_IUTEST_PARAM_TESTS_HPP_3DBBF55E_A076_4207_B49E_34734EE333EE_
+#define INCG_IRIS_IUTEST_PARAM_TESTS_HPP_3DBBF55E_A076_4207_B49E_34734EE333EE_
 
 //======================================================================
 // include
 #include "iutest_core.hpp"
+#include "iutest_any.hpp"
 
 #if IUTEST_HAS_PARAM_TEST
 #include "internal/iutest_pool.hpp"
@@ -29,26 +30,56 @@
 /**
  * @ingroup	TESTDEF
  * @def		IUTEST_INSTANTIATE_TEST_CASE_P
- * @brief	p[^eXgCX^X}N
- * @param	prefix_		= CX^X
- * @param	testcase_	= eXgP[X
- * @param	generator_	= Range, Bool, Values, ValuesIn, Combine, Pairwise ...
+ * @brief	パラメータテストインスタンス化マクロ
+ * @param	prefix_			= インスタンス名
+ * @param	testfixture_	= テストフィクスチャ
+ * @param	generator_		= Range, Bool, Values, ValuesIn, Combine, Pairwise ...
 */
-#define IUTEST_INSTANTIATE_TEST_CASE_P(prefix_, testcase_, generator_)	\
-													IIUT_INSTANTIATE_TEST_CASE_P_(prefix_, testcase_, generator_)
+#define IUTEST_INSTANTIATE_TEST_CASE_P(prefix_, testfixture_, generator_)	\
+	IIUT_INSTANTIATE_TEST_CASE_P_(prefix_, testfixture_, generator_)
 
 /**
  * @ingroup	TESTDEF
- * @def		IUTEST_P(testcase_, testname_)
- * @brief	p[^[U[weXg֐`}N
- * @param	testcase_	= eXgP[X
- * @param	testname_	= eXg
+ * @def		IUTEST_P(testfixture_, testname_)
+ * @brief	パラメータユーザー指定テスト関数定義マクロ
+ * @param	testfixture_	= テストフィクスチャ
+ * @param	testname_		= テスト名
  * @note	
  *	class TestCaseName : public ::iutest::TestWithParam<int> {};\n
  *  IUTEST_P(TestCaseName, TestName) {}\n
  *  IUTEST_INSTANTIATE_TEST_CASE_P(InstantiateName, TestCaseName, ParamGenerator);\n
 */
-#define IUTEST_P(testcase_, testname_)				IIUT_TEST_P_(testcase_, testname_)
+#define IUTEST_P(testfixture_, testname_)		IIUT_TEST_P_(testfixture_, testname_)
+
+
+#if IUTEST_HAS_ANY_PARAM_TEST
+
+/**
+ * @ingroup	TESTDEF
+ * @def		IUTEST_INSTANTIATE_TEST_CASE_AP
+ * @brief	パラメータテストインスタンス化マクロ
+ * @param	prefix_		= インスタンス名
+ * @param	testcase_	= テストケース名
+ * @param	generator_	= Range, Bool, Values, ValuesIn, Combine, Pairwise ...
+*/
+#define IUTEST_INSTANTIATE_TEST_CASE_AP(prefix_, testcase_, generator_)	\
+	IIUT_INSTANTIATE_TEST_CASE_P_(prefix_, IUTEST_ALIAS_TESTNAME_F(iuTestWithAny, testcase_), generator_)
+
+/**
+ * @ingroup	TESTDEF
+ * @def		IUTEST_AP(testcase_, testname_)
+ * @brief	パラメータユーザー指定テスト関数定義マクロ
+ * @param	testcase_	= テストケース名
+ * @param	testname_	= テスト名
+ * @note	
+ *  IUTEST_AP(TestCaseName, TestName) {}\n
+ *  IUTEST_INSTANTIATE_TEST_CASE_AP(InstantiateName, TestCaseName, ParamGenerator);\n
+*/
+#define IUTEST_AP(testcase_, testname_)			IIUT_TEST_P_(IUTEST_ALIAS_TESTNAME_F(iuTestWithAny, testcase_), testname_)
+
+
+#endif
+
 
 /**
  * @private
@@ -56,38 +87,48 @@
 */
 
 #if !defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
-#  define IIUT_GetTestCasePatternHolder(T, testcase_)	\
-	::iutest::UnitTest::GetInstance()->parameterized_test_registry().GetTestCasePatternHolder<T>(testcase_)
+#  define IIUT_GETTESTCASEPATTERNHOLDER(T, testcase_, package_)	\
+	::iutest::UnitTest::GetInstance()->parameterized_test_registry().GetTestCasePatternHolder<T>(testcase_, package_)
 #else
-#  define IIUT_GetTestCasePatternHolder(T, testcase_)	\
-	::iutest::UnitTest::GetInstance()->parameterized_test_registry().GetTestCasePatternHolder(testcase_, &::iutest::detail::type<T>())
+#  define IIUT_GETTESTCASEPATTERNHOLDER(T, testcase_, package_)	\
+	::iutest::UnitTest::GetInstance()->parameterized_test_registry().GetTestCasePatternHolder(testcase_, package_, &::iutest::detail::type<T>())
+#endif
+
+#if IUTEST_HAS_IF_EXISTS
+#define IIUT_TEST_P_FIXTURE_DECL_(testcase_)	IIUT_TEST_P_FIXTURE_DECL_I(IUTEST_TO_VARNAME_(testcase_))
+#define IIUT_TEST_P_FIXTURE_DECL_I(testcase_)	IUTEST_IF_NOT_EXISTS(testcase_, typedef ::iutest::TestWithAny testcase_;)
+#else
+#define IIUT_TEST_P_FIXTURE_DECL_(testcase_)
 #endif
 
-/**
- * @brief	p[^eXgo^
-*/
-#define IIUT_INSTANTIATE_TEST_CASE_P_(prefix_, testcase_, generator_)						\
-	static ::iutest::detail::iuIParamGenerator<testcase_::ParamType>*						\
-		s_##prefix_##_##testcase_##_EvalGenerator_(void) { return generator_; }				\
-		int prefix_##_##testcase_##_TestCaseInstantiationRegister(void) {					\
-			::iutest::ParamTestCaseInfo<testcase_>* p =										\
-				IIUT_GetTestCasePatternHolder(testcase_, IUTEST_CONCAT_PACKAGE_(testcase_));			\
-			return p->AddTestCaseInstantiation(#prefix_, s_##prefix_##_##testcase_##_EvalGenerator_);	\
-		} int s_##prefix_##_##testcase_##_dummy = prefix_##_##testcase_##_TestCaseInstantiationRegister()
-				
 
 /**
- * @brief	p[^eXgNX`
+ * @brief	パラメータテスト登録
+*/
+#define IIUT_INSTANTIATE_TEST_CASE_P_(prefix_, testcase_, generator_)						\
+	IIUT_TEST_P_FIXTURE_DECL_(testcase_)													\
+	static ::iutest::detail::iuIParamGenerator< IUTEST_TO_VARNAME_(testcase_)::ParamType >*	\
+		IUTEST_TEST_P_EVALGENERATOR_NAME_(prefix_, testcase_)(void) { return generator_; }	\
+		int IUTEST_TEST_P_INSTANTIATIONREGISTER_NAME_(prefix_, testcase_)(void) {			\
+			::iutest::ParamTestCaseInfo< IUTEST_TO_VARNAME_(testcase_) >* p =				\
+				IIUT_GETTESTCASEPATTERNHOLDER( IUTEST_TO_VARNAME_(testcase_)				\
+					, IUTEST_TO_NAME_STR_(testcase_), IUTEST_GET_PACKAGENAME_());			\
+			return p->AddTestCaseInstantiation(#prefix_, IUTEST_TEST_P_EVALGENERATOR_NAME_(prefix_, testcase_));	\
+		} IUTEST_TEST_P_INSTANTIATIONREGISTER_(prefix_, testcase_)
+
+/**
+ * @brief	パラメータテストクラス定義
 */
 #define IIUT_TEST_P_(testcase_, testname_)															\
+	IIUT_TEST_P_FIXTURE_DECL_(testcase_)															\
 	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public IUTEST_TO_VARNAME_(testcase_) {	\
 		public: IUTEST_TEST_CLASS_NAME_(testcase_, testname_)(void) {}								\
 		protected: virtual void Body(void);															\
 		private: static int	AddRegister(void) {														\
 			static ::iutest::detail::ParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_			\
 				, testname_) > testinfo(IUTEST_TO_NAME_STR_(testname_));							\
-			IIUT_GetTestCasePatternHolder(IUTEST_TO_VARNAME_(testcase_), IUTEST_CONCAT_PACKAGE_(IUTEST_TO_NAME_(testcase_)))	\
-				->AddTestPattern(&testinfo); return 0;												\
+			IIUT_GETTESTCASEPATTERNHOLDER(IUTEST_TO_VARNAME_(testcase_), IUTEST_TO_NAME_STR_(testcase_)	\
+					, IUTEST_GET_PACKAGENAME_())->AddTestPattern(&testinfo); return 0;				\
 		}																							\
 		static int dummy_;																			\
 		IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTEST_TEST_CLASS_NAME_(testcase_, testname_));			\
@@ -104,8 +145,8 @@
 		private: static int	AddRegister(void) {														\
 			static ::iutest::detail::ParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_			\
 				, testname_) > testinfo(IUTEST_TO_NAME_STR_(testname_));							\
-			IIUT_GetTestCasePatternHolder(IUTEST_TO_VARNAME_(testcase_), IUTEST_CONCAT_PACKAGE_(IUTEST_TO_NAME_(testcase_)))	\
-				->AddTestPattern(&testinfo); return 0;												\
+			IIUT_GETTESTCASEPATTERNHOLDER(IUTEST_TO_VARNAME_(testcase_), IUTEST_TO_NAME_STR_(testcase_)	\
+				, IUTEST_GET_PACKAGENAME_())->AddTestPattern(&testinfo); return 0;					\
 		}																							\
 		static int dummy_;																			\
 		IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(IUTEST_TEST_CLASS_NAME_(testcase_, testname_));			\
@@ -114,18 +155,30 @@
 		= IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::AddRegister();								\
 	template<typename T>void IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::Body(void)
 
+#define IUTEST_TEST_P_EVALGENERATOR_NAME_(prefix_, testcase_)	IIUT_TEST_P_EVALGENERATOR_NAME_I(prefix_, IUTEST_TO_VARNAME_(testcase_))
+#define IIUT_TEST_P_EVALGENERATOR_NAME_I(prefix_, testcase_)	IIUT_TEST_P_EVALGENERATOR_NAME_I_(prefix_, testcase_)
+#define IIUT_TEST_P_EVALGENERATOR_NAME_I_(prefix_, testcase_)	s_##prefix_##_##testcase_##_EvalGenerator_
+
+#define IUTEST_TEST_P_INSTANTIATIONREGISTER_NAME_(prefix_, testcase_)	IIUT_TEST_P_INSTANTIATIONREGISTER_NAME_I(prefix_, IUTEST_TO_VARNAME_(testcase_))
+#define IIUT_TEST_P_INSTANTIATIONREGISTER_NAME_I(prefix_, testcase_)	IIUT_TEST_P_INSTANTIATIONREGISTER_NAME_I_(prefix_, testcase_)
+#define IIUT_TEST_P_INSTANTIATIONREGISTER_NAME_I_(prefix_, testcase_)	prefix_##_##testcase_##_TestCaseInstantiationRegister
+
+#define IUTEST_TEST_P_INSTANTIATIONREGISTER_(prefix_, testcase_)			IIUT_TEST_P_INSTANTIATIONREGISTER_I(prefix_, IUTEST_TO_VARNAME_(testcase_), IUTEST_TEST_P_INSTANTIATIONREGISTER_NAME_(prefix_, testcase_))
+#define IIUT_TEST_P_INSTANTIATIONREGISTER_I(prefix_, testcase_, register_)	IIUT_TEST_P_INSTANTIATIONREGISTER_I_(prefix_, testcase_, register_)
+#define IIUT_TEST_P_INSTANTIATIONREGISTER_I_(prefix_, testcase_, register_)	int s_##prefix_##_##testcase_##_dummy = register_()
+
 /**
  * @}
 */
 
-//======================================================================
-// class
 namespace iutest {
 namespace detail
 {
 
+//======================================================================
+// class
 /**
- * @brief	p[^P̃eXg TestInfo CX^X
+ * @brief	パラメータ単体テスト TestInfo 情報インスタンス
 */
 template<typename T>
 class ParamTestInstance : public IParamTestInfoData<typename T::ParamType>
@@ -135,7 +188,7 @@ class ParamTestInstance : public IParamTestInfoData<typename T::ParamType>
 	typedef detail::iuParamTestFactory<T>	Factory;
 	typedef IParamTestInfoData<ParamType>	_Mybase;
 
-	// eeXg̃CX^X
+	// 各テストのインスタンス
 	class EachTest
 	{
 	public:
@@ -156,7 +209,7 @@ public:
 	ParamTestInstance(const char* testcase_name) : _Mybase(testcase_name) {}
 
 private:
-	// eXgP[X̍쐬
+	// テストケースの作成
 	virtual TestCase*	MakeTestCase(const char* testcase_name, TestTypeId id, SetUpMethod setup, TearDownMethod teardown) const IUTEST_CXX_OVERRIDE
 	{
 #if !defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
@@ -166,30 +219,51 @@ private:
 #endif
 	}
 
-	// eXg̍쐬o^
+	// テストの作成登録
 	virtual	void	RegisterTest(TestCase* testcase, ParamType param, int index) const IUTEST_CXX_OVERRIDE
 	{
 		EachTest* test = new EachTest(testcase, detail::MakeIndexTestName(this->m_name.c_str(), index).c_str(), param);
-		// new IuWFNgǗĂ炤
+		// new オブジェクトを管理してもらう
 		detail::iuPool<EachTest>::GetInstance().push(test);
 	}
 };
 
-}	// end of namespace
+}	// end of namespace detail
 
 /**
- * @brief	͈̓p[^
+ * @brief	any パラメータテストフィクスチャ
+*/
+class TestWithAny : public Test, public WithParamInterface<any>
+{
+public:
+	/**
+	 * @brief	パラメータの取得
+	*/
+	static const ParamType&	GetParam(void) { return WithParamInterface<any>::GetParam(); }
+
+	/**
+	 * @brief	パラメータの取得
+	*/
+	template<typename T>
+	static T GetParam(void) { return unsafe_any_cast<T>(WithParamInterface<any>::GetParam()); }
+};
+
+//======================================================================
+// function
+
+/**
+ * @brief	範囲パラメータ
 */
 template<typename T>
-detail::iuIParamGenerator<T>*	Range(T begin, T end, T step=1)
+detail::iuParamGenerator<T> IUTEST_ATTRIBUTE_UNUSED_ Range(T begin, T end, T step=1)
 {
 	return new detail::iuRangeParamsGenerator<T>(begin, end, step);
 }
 
 /**
- * @brief	^Ulp[^
+ * @brief	真偽値パラメータ
 */
-inline detail::iuIParamGenerator<bool>* IUTEST_ATTRIBUTE_UNUSED_ Bool(void)
+inline detail::iuParamGenerator<bool> IUTEST_ATTRIBUTE_UNUSED_ Bool(void)
 {
 	return new detail::iuBoolParamsGenerator<bool>();
 }
@@ -197,7 +271,7 @@ inline detail::iuIParamGenerator<bool>* IUTEST_ATTRIBUTE_UNUSED_ Bool(void)
 #if IUTEST_HAS_VALUESGEN
 
 /**
- * @brief	lzp[^
+ * @brief	値配列パラメータ
 */
 template<typename Generator>
 inline detail::iuValuesParamsGeneratorHolder<Generator> IUTEST_ATTRIBUTE_UNUSED_ ValuesGen(size_t num, const Generator& gen)
@@ -206,7 +280,7 @@ inline detail::iuValuesParamsGeneratorHolder<Generator> IUTEST_ATTRIBUTE_UNUSED_
 }
 
 /**
- * @brief	WFl[^
+ * @brief	乱数ジェネレータ
 */
 template<typename T, typename F>
 inline detail::iuRandomFilterParamGenerator<T, F> IUTEST_ATTRIBUTE_UNUSED_ RandomGenerator(const F& fn, unsigned int seed=0)
@@ -222,7 +296,7 @@ inline detail::iuRandomFilterParamGenerator<T, F> IUTEST_ATTRIBUTE_UNUSED_ Rando
 
 #if IUTEST_HAS_RANDOMVALUES
 /**
- * @brief	lp[^
+ * @brief	乱数値パラメータ
 */
 inline detail::iuRandomParamsHolder IUTEST_ATTRIBUTE_UNUSED_ RandomValues(size_t num, unsigned int seed=0)
 {
@@ -231,10 +305,10 @@ inline detail::iuRandomParamsHolder IUTEST_ATTRIBUTE_UNUSED_ RandomValues(size_t
 #endif
 
 /**
- * @brief	lzp[^
+ * @brief	値配列パラメータ
 */
 template<typename Container>
-inline detail::iuIParamGenerator< typename Container::value_type >* ValuesIn(Container containor)
+inline detail::iuParamGenerator< typename Container::value_type > IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(Container containor)
 {
 	return new detail::iuValuesInParamsGenerator< typename Container::value_type >(containor);
 }
@@ -242,20 +316,20 @@ inline detail::iuIParamGenerator< typename Container::value_type >* ValuesIn(Con
 #if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
 /** @overload */
 template<typename T, size_t SIZE>
-inline detail::iuIParamGenerator<T>* ValuesIn(const T (&v)[SIZE])
+inline detail::iuParamGenerator<T> IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(const T (&v)[SIZE])
 {
 	return new detail::iuValuesInParamsGenerator<T>(v, v+SIZE);
 }
 /** @overload */
 template<typename Ite>
-inline detail::iuIParamGenerator< typename detail::IteratorTraits<Ite>::type >* ValuesIn(Ite begin, Ite end)
+inline detail::iuParamGenerator< typename detail::IteratorTraits<Ite>::type > IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(Ite begin, Ite end)
 {
 	return new detail::iuValuesInParamsGenerator< typename detail::IteratorTraits<Ite>::type >(begin, end);
 }
 #if IUTEST_HAS_INITIALIZER_LIST
 /** @overload */
 template<typename T>
-inline detail::iuIParamGenerator<T>* ValuesIn(::std::initializer_list<T> l)
+inline detail::iuParamGenerator<T> IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(::std::initializer_list<T> l)
 {
 	return new detail::iuValuesInParamsGenerator<T>(l);
 }
@@ -265,7 +339,7 @@ inline detail::iuIParamGenerator<T>* ValuesIn(::std::initializer_list<T> l)
 
 #if IUTEST_HAS_VARIADIC_VALUES
 /**
- * @brief	lzp[^
+ * @brief	値配列パラメータ
 */
 template<typename ...Args>
 inline detail::iuValueArray<Args...> IUTEST_ATTRIBUTE_UNUSED_ Values(Args... args)
@@ -282,8 +356,8 @@ inline detail::iuValueArray<Args...> IUTEST_ATTRIBUTE_UNUSED_ Values(Args... arg
 	}
 
 /**
- * @brief	lzp[^
- * @note	50܂Ŏgp\
+ * @brief	値配列パラメータ
+ * @note	50引数まで使用可能
 */
 IIUT_DECL_VALUES_(1)
 IIUT_DECL_VALUES_(2)
@@ -340,11 +414,22 @@ IIUT_DECL_VALUES_(50)
 
 #endif
 
+#if IUTEST_HAS_CONCAT
+/**
+ * @brief	パラメータの結合
+*/
+template<typename G1, typename G2>
+detail::iuConcatParamHolder<G1, G2> Concat(const G1& g1, const G2& g2)
+{
+	return detail::iuConcatParamHolder<G1, G2>(g1, g2);
+}
+#endif
+
 #if IUTEST_HAS_COMBINE
 
 #if IUTEST_HAS_VARIADIC_COMBINE
 /**
- * @brief	p[^
+ * @brief	複合条件パラメータ化
 */
 template<typename ...Generator>
 detail::iuCartesianProductHolder<Generator...> Combine(const Generator&... generators)
@@ -362,8 +447,8 @@ detail::iuCartesianProductHolder<Generator...> Combine(const Generator&... gener
 	}
 
 /**
- * @brief	p[^
- * @note	9܂Ŏgp\
+ * @brief	複合条件パラメータ化
+ * @note	9引数まで使用可能
 */
 IIUT_DECL_COMBINE_(2)
 IIUT_DECL_COMBINE_(3)
@@ -385,7 +470,7 @@ IIUT_DECL_COMBINE_(9)
 #if IUTEST_HAS_VARIADIC_PAIRWISE
 
 /**
- * @brief	p[^(I[yA@)
+ * @brief	複合条件パラメータ化(オールペア法)
 */
 template<typename ...Generator>
 detail::iuPairwiseHolder<Generator...> Pairwise(const Generator&... generators)
@@ -403,8 +488,8 @@ detail::iuPairwiseHolder<Generator...> Pairwise(const Generator&... generators)
 	}
 
 /**
- * @brief	p[^(I[yA@)
- * @note	9܂Ŏgp\
+ * @brief	複合条件パラメータ化(オールペア法)
+ * @note	9引数まで使用可能
 */
 IIUT_DECL_PAIRWISE_(2)
 IIUT_DECL_PAIRWISE_(3)
@@ -423,6 +508,11 @@ IIUT_DECL_PAIRWISE_(9)
 
 }	// end of namespace iutest
 
+#if IUTEST_HAS_ANY_PARAM_TEST
+/** any param test fixture */
+typedef ::iutest::TestWithAny	iuTestWithAny;
+#endif
+
 #endif	// IUTEST_HAS_PARAM_TEST
 
-#endif
+#endif	// INCG_IRIS_IUTEST_PARAM_TESTS_HPP_3DBBF55E_A076_4207_B49E_34734EE333EE_
