@@ -1,26 +1,26 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_prod.hpp
- * @brief		iris unit test production code Ήp t@C
+ * @brief		iris unit test production code 対応用 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_prod_HPP_7A316C18_042D_4e48_BC31_E6AE8B6C2E28_
-#define INCG_IRIS_iutest_prod_HPP_7A316C18_042D_4e48_BC31_E6AE8B6C2E28_
+#ifndef INCG_IRIS_IUTEST_PROD_HPP_7A316C18_042D_4E48_BC31_E6AE8B6C2E28_
+#define INCG_IRIS_IUTEST_PROD_HPP_7A316C18_042D_4E48_BC31_E6AE8B6C2E28_
 
 //======================================================================
 // define
 /**
- * @brief	eXg猩悤 fried o^
+ * @brief	テストから見えるように fried 登録
 */
 #define IUTEST_FRIEND_TEST(test_case_name, test_name)	\
 	friend class IUTEST_TEST_CLASS_NAME_(test_case_name, test_name)
@@ -30,7 +30,7 @@
 #if !defined(_MSC_VER) || _MSC_VER > 1200
 
 /**
- * @brief	eXg猩悤 fried o^(IUTEST_TYPED_TESTp)
+ * @brief	テストから見えるように fried 登録(IUTEST_TYPED_TEST用)
 */
 #define IUTEST_FRIEND_TYPED_TEST(test_case_name, test_name)	\
 	template<typename T>IUTEST_FRIEND_TEST(test_case_name, test_name)
@@ -39,14 +39,69 @@
 
 #endif
 
+/**
+ * @brief	private メンバーへのアクセス権を作成
+ * @param	member_type	= 型
+ * @param	class_name	= クラス
+ * @param	member_name	= メンバー名
+*/
+#define IUTEST_MAKE_PEEP(member_type, class_name, member_name)		\
+	IUTEST_MAKE_PEEP_TAG_(member_type, class_name, member_name)
+
+/**
+ * @brief	private	メンバーへのアクセス
+ * @param	v			= オブジェクトインスタンス
+ * @param	class_name	= クラス名
+ * @param	member_name	= メンバー名
+*/
+#define IUTEST_PEEP_GET(v, class_name, member_name)		(v.*::iutest::detail::peep_tag< IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> >::value)
+
+/**
+ * @brief	static private	メンバーへのアクセス
+ * @param	class_name	= クラス名
+ * @param	member_name	= メンバー名
+*/
+#define IUTEST_PEEP_STATIC_GET(class_name, member_name)	(*::iutest::detail::peep_tag< IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> >::value)
+
+/**
+ * @brief	private メンバーへのアクセスクラス宣言
+ * @param	class_name	= クラス名
+ * @param	member_name	= メンバー名
+*/
+#define IUTEST_PEEP(class_name, member_name)	::iutest::Peep< class_name, IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> >::type
+
+
+/**
+ * @private
+ * @{
+*/
+#define IUTEST_MAKE_PEEP_TAG_(member_type, class_name, member_name)															\
+	template<typename T>struct IUTEST_PEEP_TAG_NAME_(class_name, member_name);												\
+	template<>struct IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> { typedef member_type type; };				\
+	template<typename T, typename Tag, typename Tag::type X>struct IUTEST_PEEP_SETTER_NAME_(class_name, member_name) {		\
+	IUTEST_PEEP_SETTER_NAME_(class_name, member_name)(void) { ::iutest::detail::peep_tag<Tag>::value = X; }					\
+	static IUTEST_PEEP_SETTER_NAME_(class_name, member_name)	instance;													\
+	};																														\
+	template<typename T, typename Tag, typename Tag::type X>IUTEST_PEEP_SETTER_NAME_(class_name, member_name)<T, Tag, X>	\
+	IUTEST_PEEP_SETTER_NAME_(class_name, member_name)<T, Tag, X>::instance;													\
+	template struct IUTEST_PEEP_SETTER_NAME_(class_name, member_name)<class_name											\
+		, IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name>, &class_name::member_name>
+
+#define IUTEST_PEEP_TAG_NAME_(class_name, member_name)			iu_peep_tag_##member_name
+#define IUTEST_PEEP_SETTER_NAME_(class_name, member_name)		IUTEST_PP_CAT(IUTEST_PP_CAT(iu_peep_set_, member_name), __LINE__)
+
+/**
+ * @}
+*/
+
 namespace iutest {
-namespace detail
-{
 
 //======================================================================
 // struct
-/** 
- * @brief	private o[ێ\
+namespace detail
+{
+/**
+* @brief	private メンバー保持構造体
 */
 template<typename Tag>
 struct peep_tag
@@ -58,84 +113,10 @@ typename Tag::type peep_tag<Tag>::value;
 
 }	// end of namespace detail
 
-//======================================================================
-// define
-/**
- * @brief	private o[ւ̃ANZX쐬
- * @param	member_type	= ^
- * @param	class_name	= NX
- * @param	member_name	= o[
-*/
-#define IUTEST_MAKE_PEEP(member_type, class_name, member_name)		\
-	IUTEST_MAKE_PEEP_TAG_(member_type, class_name, member_name);	\
-	template struct IUTEST_PEEP_SETTER_NAME_(class_name, member_name)<	\
-		IUTEST_PEEP_TAG_NAME_(class_name, member_name), &class_name::member_name>
-
-/**
- * @brief	private o[ւ̃ANZX쐬
- * @param	member_type	= ^
- * @param	scope_name	= XR[v
- * @param	class_name	= NX
- * @param	member_name	= o[
-*/
-#define IUTEST_MAKE_SCOPED_PEEP(member_type, scope_name, class_name, member_name)		\
-	IUTEST_MAKE_PEEP_TAG_(member_type, class_name, member_name);	\
-	template struct IUTEST_PEEP_SETTER_NAME_(class_name, member_name)<	\
-		IUTEST_PEEP_TAG_NAME_(class_name, member_name), &scope_name::class_name::member_name>
-
-/**
- * @brief	private	o[ւ̃ANZX
- * @param	v			= IuWFNgCX^X
- * @param	class_name	= NX
- * @param	member_name	= o[
-*/
-#define IUTEST_PEEP_GET(v, class_name, member_name)		(v.*::iutest::detail::peep_tag< IUTEST_PEEP_TAG_NAME_(class_name, member_name) >::value)
-
-/**
- * @brief	static private	o[ւ̃ANZX
- * @param	class_name	= NX
- * @param	member_name	= o[
-*/
-#define IUTEST_PEEP_STATIC_GET(class_name, member_name)	(*::iutest::detail::peep_tag< IUTEST_PEEP_TAG_NAME_(class_name, member_name) >::value)
-
-/**
- * @brief	private o[ւ̃ANZXNX錾
- * @param	class_name	= NX
- * @param	member_name	= o[
-*/
-#define IUTEST_PEEP(class_name, member_name)	::iutest::Peep< class_name, IUTEST_PEEP_TAG_NAME_(class_name, member_name) >::type
-
-/**
- * @brief	private o[ւ̃ANZXNX錾
- * @param	scope_name	= XR[v
- * @param	class_name	= NX
- * @param	member_name	= o[
-*/
-#define IUTEST_SCOPED_PEEP(scope_name, class_name, member_name)	::iutest::Peep< scope_name::class_name, IUTEST_PEEP_TAG_NAME_(class_name, member_name) >::type
-
-/**
- * @private
- * @{
-*/
-#define IUTEST_MAKE_PEEP_TAG_(member_type, class_name, member_name)	\
-struct IUTEST_PEEP_TAG_NAME_(class_name, member_name) { typedef member_type type; };	\
-	template<typename Tag, typename Tag::type X>struct IUTEST_PEEP_SETTER_NAME_(class_name, member_name) {	\
-	IUTEST_PEEP_SETTER_NAME_(class_name, member_name)(void) { ::iutest::detail::peep_tag<Tag>::value = X; }		\
-	static IUTEST_PEEP_SETTER_NAME_(class_name, member_name)	instance;									\
-	};	\
-	template<typename Tag, typename Tag::type X>IUTEST_PEEP_SETTER_NAME_(class_name, member_name)<Tag, X>	\
-	IUTEST_PEEP_SETTER_NAME_(class_name, member_name)<Tag, X>::instance
-
-#define IUTEST_PEEP_TAG_NAME_(class_name, member_name)		iu_peep_tag_##class_name##_##member_name
-#define IUTEST_PEEP_SETTER_NAME_(class_name, member_name)	iu_peep_set_##class_name##_##member_name
-/**
- * @}
-*/
-
 #if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
 
 /**
- * @brief	private	o[ANZXIuWFNg
+ * @brief	private	メンバーアクセスオブジェクト
 */
 template<typename T, typename Tag>
 class Peep
@@ -154,7 +135,7 @@ private:
 	private:
 		U*	m_ptr;
 	public:
-		peep_member_function_impl(U* ptr) : m_ptr(ptr) {}
+		explicit peep_member_function_impl(U* ptr) : m_ptr(ptr) {}
 
 #if IUTEST_HAS_VARIADIC_TEMPLATES
 	public:
@@ -201,7 +182,7 @@ private:
 	private:
 		U*	m_ptr;
 	public:
-		peep_member_object_impl(U* ptr) : m_ptr(ptr) {}
+		explicit peep_member_object_impl(U* ptr) : m_ptr(ptr) {}
 	public:
 		operator value_type (void) const { return (*m_ptr).*detail::peep_tag<peep_tag>::value; }
 	};
@@ -213,7 +194,7 @@ private:
 	private:
 		U*	m_ptr;
 	public:
-		peep_member_object_impl(U* ptr) : m_ptr(ptr) {}
+		explicit peep_member_object_impl(U* ptr) : m_ptr(ptr) {}
 	public:
 		operator value_type (void) const { return (*m_ptr).*detail::peep_tag<peep_tag>::value; }
 		operator value_type& (void) { return (*m_ptr).*detail::peep_tag<peep_tag>::value; }
@@ -237,7 +218,11 @@ private:
 	class peep_static_impl
 	{
 		typedef peep_static_impl<U, Type, Func>	_Myt;
-		typedef typename type_traits::remove_ptr<Type>::type value_type;
+		typedef typename type_traits::remove_pointer<Type>::type value_type;
+	public:
+		peep_static_impl(void) {}
+		peep_static_impl(const value_type& value) { *detail::peep_tag<peep_tag>::value = value; }
+		peep_static_impl(const _Myt&) {}
 	public:
 		operator value_type (void) const { return *detail::peep_tag<peep_tag>::value; }
 		operator value_type& (void) { return *detail::peep_tag<peep_tag>::value; }
@@ -262,11 +247,11 @@ private:
 		typedef typename peep_member_impl<U, Type, type_traits::is_member_function_pointer<Type>::value >::type type;
 	};
 public:
-	typedef typename peep_impl<T, peep_type, type_traits::is_member_pointer<peep_type>::value >::type	type;	//!< private o[ANZXIuWFNg^
+	typedef typename peep_impl<T, peep_type, type_traits::is_member_pointer<peep_type>::value >::type	type;	//!< private メンバーアクセスオブジェクト型
 };
 
 #endif
 
 }	// end of namespace iutest
 
-#endif
+#endif	// INCG_IRIS_IUTEST_PROD_HPP_7A316C18_042D_4E48_BC31_E6AE8B6C2E28_
