@@ -1,31 +1,33 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_static_assertion.hpp
- * @brief		iris unit test static assertion ` t@C
+ * @brief		iris unit test static assertion 定義 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_static_assertion_HPP_53842FD6_9E5D_40a6_905D_EC6DEBE5ED6A_
-#define INCG_IRIS_iutest_static_assertion_HPP_53842FD6_9E5D_40a6_905D_EC6DEBE5ED6A_
+#ifndef INCG_IRIS_IUTEST_STATIC_ASSERTION_HPP_53842FD6_9E5D_40A6_905D_EC6DEBE5ED6A_
+#define INCG_IRIS_IUTEST_STATIC_ASSERTION_HPP_53842FD6_9E5D_40A6_905D_EC6DEBE5ED6A_
 
 //======================================================================
 // include
 
 //======================================================================
 // 
+#if IUTEST_HAS_STATIC_ASSERT_TYPEEQ
+
 #if 0
 /**
  * @ingroup	IUTEST_UTIL
- * @brief	^AT[V
+ * @brief	型アサーション
 */
 template<typename T1, typename T2>
 static bool	StaticAssertTypeEq(void)
@@ -37,12 +39,16 @@ static bool	StaticAssertTypeEq(void)
 
 /**
  * @ingroup	IUTEST_UTIL
- * @brief	^AT[V
- * @note	}No[W
- *			G[Ăяoʒuɏo
+ * @brief	型アサーション
+ * @note	マクロバージョン
+ *			エラーが呼び出し位置に出る
 */
 #define StaticAssertTypeEq	detail::StaticAssertTypeEqHelper
 
+#endif
+
+#endif
+
 /**
  * @brief	static_assert
 */
@@ -50,7 +56,7 @@ static bool	StaticAssertTypeEq(void)
 #  define IUTEST_STATIC_ASSERT_MSG(B, Msg)	static_assert(B, Msg)
 #else
 #  define IUTEST_STATIC_ASSERT_MSG(B, Msg)	\
-	typedef ::iutest::detail::StaticAssertionTest< sizeof(::iutest::detail::StaticAssertionFailure< (bool)B >) > IUTEST_PP_CAT(iutest_static_assert_typedef_, __LINE__)
+	typedef ::iutest::detail::StaticAssertionTest< sizeof(::iutest::detail::StaticAssertionFailure< (bool)B >) > IUTEST_PP_CAT(iutest_static_assert_typedef_, IUTEST_PP_COUNTER)
 #endif
 
 /**
@@ -64,6 +70,28 @@ static bool	StaticAssertTypeEq(void)
 #  endif
 #endif
 
+/**
+ * @brief	static assert if exists
+*/
+#ifndef IUTEST_STATIC_ASSERT_IF_EXISTS
+#  if IUTEST_HAS_IF_EXISTS
+#    define IUTEST_STATIC_ASSERT_IF_EXISTS(identifier, msg)	\
+		IUTEST_STATIC_ASSERT_MSG( IUTEST_IF_EXISTS(identifier, true) IUTEST_IF_NOT_EXISTS(identifier,false), msg)
+#  else
+#    define IUTEST_STATIC_ASSERT_IF_EXISTS(identifier, msg)
+#  endif
+#endif
+
+/**
+* @brief	static assert if not exists
+*/
+#ifndef IUTEST_STATIC_ASSERT_IF_NOT_EXISTS
+#  if IUTEST_HAS_IF_EXISTS
+#    define IUTEST_STATIC_ASSERT_IF_NOT_EXISTS(identifier, msg)	\
+		IUTEST_STATIC_ASSERT_MSG(IUTEST_IF_NOT_EXISTS(identifier, true) IUTEST_IF_EXISTS(identifier, false), msg)
+#  else
+#    define IUTEST_STATIC_ASSERT_IF_NOT_EXISTS(identifier, msg)
+#  endif
 #endif
 
 //======================================================================
@@ -78,13 +106,23 @@ namespace detail
 template<typename T1, typename T2>
 struct StaticAssertTypeEqHelper;
 
-/** @private */
-template<typename T>
-struct StaticAssertTypeEqHelper<T, T>
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+namespace helper
 {
-	operator bool (void) const { return true; }
-};
 
+/** @private */
+template<bool b>struct static_assert_typeeq;
+/** @overload */
+template<>struct static_assert_typeeq<true> { operator bool (void) const { return true; } };
+
+}
+
+/** @private */
+template<typename T1, typename T2>
+struct StaticAssertTypeEqHelper
+	: public helper::static_assert_typeeq< iutest_type_traits::is_same<T1, T2>::value > {};
+
+#endif
 
 /** @private */
 template<bool b>struct StaticAssertionFailure;
@@ -97,4 +135,4 @@ template<int x>struct StaticAssertionTest {};
 }	// end of namespace detail
 }	// end of namespace iutest
 
-#endif
+#endif	// INCG_IRIS_IUTEST_STATIC_ASSERTION_HPP_53842FD6_9E5D_40A6_905D_EC6DEBE5ED6A_
