@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_typed_tests.hpp
- * @brief		iris unit test typed test t@C
+ * @brief		iris unit test typed test ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_typed_tests_HPP_DA9562C6_8CAB_4242_9E9E_22FFB490DE30_
-#define INCG_IRIS_iutest_typed_tests_HPP_DA9562C6_8CAB_4242_9E9E_22FFB490DE30_
+#ifndef INCG_IRIS_IUTEST_TYPED_TESTS_HPP_DA9562C6_8CAB_4242_9E9E_22FFB490DE30_
+#define INCG_IRIS_IUTEST_TYPED_TESTS_HPP_DA9562C6_8CAB_4242_9E9E_22FFB490DE30_
 
 //======================================================================
 // include
@@ -33,53 +33,77 @@
 /**
  * @ingroup	TESTDEF
  * @def		IUTEST_TYPED_TEST_CASE(testcase_, types_)
- * @brief	^teXgP[X̓o^
- * @param	testcase_	= eXgP[X
- * @param	types_		= ^CvXg
+ * @brief	型付けテストケースの登録
+ * @param	testcase_	= テストケース名
+ * @param	types_		= タイプリスト
 */
-#define IUTEST_TYPED_TEST_CASE(testcase_, types_)	IIUT_TYPED_TEST_CASE_(testcase_, types_)
+#if !defined(IUTEST_NO_VARIADIC_MACROS)
+#  define IUTEST_TYPED_TEST_CASE(testcase_, ...)	IIUT_TYPED_TEST_CASE_(testcase_, __VA_ARGS__)
+#else
+#  define IUTEST_TYPED_TEST_CASE(testcase_, types_)	IIUT_TYPED_TEST_CASE_(testcase_, types_)
+#endif
 
 /**
  * @ingroup	TESTDEF
  * @def		IUTEST_TYPED_TEST(testcase_, testname_)
- * @brief	^teXg֐`}N
- * @param	testcase_	= eXgP[X
- * @param	testname_	= eXg
+ * @brief	型付けテスト関数定義マクロ
+ * @param	testcase_	= テストケース名
+ * @param	testname_	= テスト名
 */
 #define IUTEST_TYPED_TEST(testcase_, testname_)		IIUT_TYPED_TEST_(testcase_, testname_)
 
+/**
+ * @ingroup	TESTDEF
+ * @def		IUTEST_T(testcase_, testname_)
+ * @brief	型付けテスト関数定義マクロ
+ * @param	testcase_	= テストケース名
+ * @param	testname_	= テスト名
+*/
+#define IUTEST_T(testcase_, testname_)				IIUT_TYPED_TEST_(testcase_, testname_)
+
 
 /**
  * @private
  * @{
 */
-#define IUTEST_TYPED_TEST_PARAMS_(testcase_)			iutest_types_params_##testcase_
+#define IUTEST_TYPED_TEST_PARAMS_(testcase_)		IIUT_TYPED_TEST_PARAMS_I(IUTEST_TO_VARNAME_(testcase_))
+#define IIUT_TYPED_TEST_PARAMS_I(testcase_)			IIUT_TYPED_TEST_PARAMS_I_(testcase_)
+#define IIUT_TYPED_TEST_PARAMS_I_(testcase_)		iutest_types_params_##testcase_
 
-#define IIUT_TYPED_TEST_CASE_(testcase_, types_)		\
+#if !defined(IUTEST_NO_VARIADIC_MACROS)
+#  define IIUT_TYPED_TEST_CASE_(testcase_, ...)		\
+	typedef ::iutest::detail::TypeList< __VA_ARGS__ >::type	IUTEST_TYPED_TEST_PARAMS_(testcase_)
+#else
+#  define IIUT_TYPED_TEST_CASE_(testcase_, types_)		\
 	typedef ::iutest::detail::TypeList< types_ >::type	IUTEST_TYPED_TEST_PARAMS_(testcase_)
+#endif
 
 #define IIUT_TYPED_TEST_(testcase_, testname_)										\
 	template<typename iutest_TypeParam>												\
-	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public testcase_<iutest_TypeParam> {		\
-		typedef testcase_<iutest_TypeParam> TestFixture;							\
+	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_)								\
+	: public IUTEST_TO_VARNAME_(testcase_)<iutest_TypeParam> {						\
+		typedef IUTEST_TO_VARNAME_(testcase_)<iutest_TypeParam> TestFixture;		\
 		typedef iutest_TypeParam	TypeParam;										\
 		protected: virtual void Body(void);											\
 	};																				\
-	::iutest::detail::TypeParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_, testname_), IUTEST_TYPED_TEST_PARAMS_(testcase_) >	\
-	s_##testcase_##_##testname_( IUTEST_CONCAT_PACKAGE_(testcase_), #testname_);	\
+	::iutest::detail::TypeParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_, testname_)			\
+		, IUTEST_TYPED_TEST_PARAMS_(testcase_) > IUTEST_TEST_INSTANCE_NAME_(testcase_, testname_)(	\
+		IUTEST_CONCAT_PACKAGE_(IUTEST_TO_NAME_(testcase_)), IUTEST_TO_NAME_STR_(testname_));		\
 	template<typename iutest_TypeParam>												\
 	void IUTEST_TEST_CLASS_NAME_(testcase_, testname_)<iutest_TypeParam>::Body(void)
 
 #define IIUT_TYPED_TEST_IGNORE_(testcase_, testname_)								\
 	template<typename iutest_TypeParam>												\
-	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public testcase_<iutest_TypeParam> {		\
-		typedef testcase_<iutest_TypeParam> TestFixture;							\
+	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_)								\
+	: public IUTEST_TO_VARNAME_(testcase_)<iutest_TypeParam> {						\
+		typedef IUTEST_TO_VARNAME_(testcase_)<iutest_TypeParam> TestFixture;		\
 		typedef iutest_TypeParam	TypeParam;										\
 		protected: virtual void Body(void) { IUTEST_SKIP() << "ignored test..."; }	\
 		template<typename T>void Body(void);										\
 	};																				\
-	::iutest::detail::TypeParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_, testname_), IUTEST_TYPED_TEST_PARAMS_(testcase_) >	\
-	s_##testcase_##_##testname_( IUTEST_CONCAT_PACKAGE_(testcase_), #testname_);	\
+	::iutest::detail::TypeParamTestInstance< IUTEST_TEST_CLASS_NAME_(testcase_, testname_)			\
+		, IUTEST_TYPED_TEST_PARAMS_(testcase_) > IUTEST_TEST_INSTANCE_NAME_(testcase_, testname_)(	\
+		IUTEST_CONCAT_PACKAGE_(IUTEST_TO_NAME_(testcase_)), IUTEST_TO_NAME_STR_(testname_) );		\
 	template<typename iutest_TypeParam>												\
 	template<typename T>void IUTEST_TEST_CLASS_NAME_(testcase_, testname_)<iutest_TypeParam>::Body(void)
 
@@ -94,37 +118,46 @@
 /**
  * @ingroup	TESTDEF
  * @def		IUTEST_TYPED_TEST_CASE_P(testcase_)
- * @brief	^p[^eXgP[X̓o^
- * @param	testcase_	= eXgP[X
+ * @brief	型パラメータテストケースの登録
+ * @param	testcase_	= テストケース名
 */
-#define IUTEST_TYPED_TEST_CASE_P(testcase_)				IUTEST_TYPED_TEST_CASE_P_(testcase_)
+#define IUTEST_TYPED_TEST_CASE_P(testcase_)				IIUT_TYPED_TEST_CASE_P_(testcase_)
 
 /**
  * @ingroup	TESTDEF
  * @def		IUTEST_TYPED_TEST_P(testcase_, testname_)
- * @brief	^p[^eXg֐`}N
- * @param	testcase_	= eXgP[X
- * @param	testname_	= eXg
+ * @brief	型パラメータテスト関数定義マクロ
+ * @param	testcase_	= テストケース名
+ * @param	testname_	= テスト名
 */
-#define IUTEST_TYPED_TEST_P(testcase_, testname_)		IUTEST_TYPED_TEST_P_(testcase_, testname_)
+#define IUTEST_TYPED_TEST_P(testcase_, testname_)		IIUT_TYPED_TEST_P_(testcase_, testname_)
+
+/**
+ * @ingroup	TESTDEF
+ * @def		IUTEST_TP(testcase_, testname_)
+ * @brief	型パラメータテスト関数定義マクロ
+ * @param	testcase_	= テストケース名
+ * @param	testname_	= テスト名
+*/
+#define IUTEST_TP(testcase_, testname_)					IIUT_TYPED_TEST_P_(testcase_, testname_)
 
 /**
  * @ingroup	TESTDEF
  * @def		IUTEST_REGISTER_TYPED_TEST_CASE_P(testcase_, ...)
- * @brief	^p[^eXg֐o^}N
- * @param	testcase_	= eXgP[X
+ * @brief	型パラメータテスト関数登録マクロ
+ * @param	testcase_	= テストケース名
 */
-#define IUTEST_REGISTER_TYPED_TEST_CASE_P(testcase_, ...)	IUTEST_REGISTER_TYPED_TEST_CASE_P_(testcase_, __VA_ARGS__)
+#define IUTEST_REGISTER_TYPED_TEST_CASE_P(testcase_, ...)	IIUT_REGISTER_TYPED_TEST_CASE_P_(testcase_, __VA_ARGS__)
 
 /**
  * @ingroup	TESTDEF
  * @def		IUTEST_INSTANTIATE_TYPED_TEST_CASE_P(prefix_, testcase_, types_)
- * @brief	^p[^eXgo^}N
- * @param	prefix_		= CX^X
- * @param	testcase_	= eXgP[X
- * @param	types_		= ^CvXg
+ * @brief	型パラメータテスト登録マクロ
+ * @param	prefix_		= インスタンス名
+ * @param	testcase_	= テストケース名
+ * @param	...			= タイプリスト
 */
-#define IUTEST_INSTANTIATE_TYPED_TEST_CASE_P(prefix_, testcase_, types_)	IUTEST_INSTANTIATE_TYPED_TEST_CASE_P_(prefix_, testcase_, types_)
+#define IUTEST_INSTANTIATE_TYPED_TEST_CASE_P(prefix_, testcase_, ...)	IIUT_INSTANTIATE_TYPED_TEST_CASE_P_(prefix_, testcase_, __VA_ARGS__)
 
 
 /**
@@ -135,10 +168,10 @@
 #define IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_)	s_iutest_typed_test_case_p_state_##testcase_##_
 #define IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_)		iutest_typed_test_case_p_name_##testcase_##_
 
-#define IUTEST_TYPED_TEST_CASE_P_(testcase_)		\
+#define IIUT_TYPED_TEST_CASE_P_(testcase_)		\
 	static ::iutest::detail::TypedTestCasePState	IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_)
 
-#define IUTEST_TYPED_TEST_P_(testcase_, testname_)				\
+#define IIUT_TYPED_TEST_P_(testcase_, testname_)				\
 	namespace IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_) {		\
 	template<typename iutest_TypeParam>							\
 	class testname_ : public testcase_<iutest_TypeParam> {		\
@@ -152,7 +185,7 @@
 	template<typename iutest_TypeParam>							\
 	void IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_)::testname_<iutest_TypeParam>::Body(void)
 
-#define IUTEST_TYPED_TEST_P_IGNORE_(testcase_, testname_)		\
+#define IIUT_TYPED_TEST_P_IGNORE_(testcase_, testname_)			\
 	namespace IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_) {		\
 	template<typename iutest_TypeParam>							\
 	class testname_ : public testcase_<iutest_TypeParam> {		\
@@ -167,18 +200,19 @@
 	template<typename iutest_TypeParam>template<typename T>		\
 	void IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_)::testname_<iutest_TypeParam>::Body(void)
 
-#define IUTEST_REGISTER_TYPED_TEST_CASE_P_(testcase_, ...)								\
+#define IIUT_REGISTER_TYPED_TEST_CASE_P_(testcase_, ...)								\
 	namespace IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_) {								\
 		typedef ::iutest::detail::Templates< __VA_ARGS__ >::type	iutest_AllTests_;	\
 	}																					\
 	static const bool s_iutest_##testcase_##_register_dummy_ IUTEST_ATTRIBUTE_UNUSED_ =	\
 	IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_).VerifyTestNames(__FILE__, __LINE__, #__VA_ARGS__)
 
-#define IUTEST_INSTANTIATE_TYPED_TEST_CASE_P_(prefix_, testcase_, types_)	\
+#define IIUT_INSTANTIATE_TYPED_TEST_CASE_P_(prefix_, testcase_, ...)		\
 	const bool iutest_##prefix_##_##testcase_ IUTEST_ATTRIBUTE_UNUSED_ =	\
 		::iutest::detail::TypeParameterizedTestCase< testcase_				\
 		, IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_)::iutest_AllTests_		\
-		, ::iutest::detail::TypeList< types_ >::type >::Register(#prefix_, IUTEST_CONCAT_PACKAGE_(testcase_)	\
+		, ::iutest::detail::TypeList< __VA_ARGS__ >::type >::Register(		\
+			#prefix_, IUTEST_TO_NAME_STR_(testcase_), IUTEST_GET_PACKAGENAME_()	\
 		, IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_).names())
 
 /**
@@ -199,15 +233,15 @@ namespace detail
 /**
  * @private
  * @internal
- * @brief	Typep[^P̃eXgCX^X
- * @tparam	Tester		= eXgNX
- * @tparam	TypeParams	= ^
+ * @brief	Typeパラメータ単体テストインスタンス
+ * @tparam	Tester		= テストクラス
+ * @tparam	TypeParams	= 型
 */
 template<template <typename T> class Tester, typename TypeParams>
 class TypeParamTestInstance
 {
 	/**
-	 * @brief	eeXg̃CX^X
+	 * @brief	各テストのインスタンス
 	*/
 	template<typename TT, typename DMY>
 	class EachTest
@@ -216,12 +250,12 @@ class TypeParamTestInstance
 		typedef Tester<TypeParam>			TestBody;
 		typedef TypedTestCase<TypeParam>	_MyTestCase;
 	public:
-		// RXgN^
+		// コンストラクタ
 		EachTest(const char* testcase, const char* name, int index)
 			: m_mediator(UnitTest::instance().AddTestCase<_MyTestCase>(
 				detail::MakeIndexTestName(testcase, index).c_str()
-				//detail::MakeTypedTestName<TypeParam>(testcase, index).c_str()
-				, internal::GetTypeId<detail::None>()	// TypeId 𓝈ꂷ邽߃_~[n
+				//detail::MakeIndexTypedTestName<TypeParam>(testcase, index).c_str()
+				, internal::GetTypeId<detail::None>()	// TypeId を統一するためダミー引数を渡す
 				, TestBody::SetUpTestCase
 				, TestBody::TearDownTestCase))
 			, m_info(&m_mediator, name, &m_factory)
@@ -229,10 +263,10 @@ class TypeParamTestInstance
 		{
 		}
 	public:
-		// eXg̓o^
+		// テストの登録
 		void	AddTest(void)
 		{
-			// ԒʂɂȂ悤ɑOo^
+			// 順番通りになるように前から登録
 			UnitTest::instance().AddTestInfo(m_mediator.ptr(), &m_info);
 			m_next.AddTest();
 		}
@@ -244,7 +278,7 @@ class TypeParamTestInstance
 		EachTest<typename TT::Tail, void>	m_next;
 	};
 
-	// I[
+	// 終端
 	template<typename DMY>
 	class EachTest<detail::TypeList0, DMY>
 	{
@@ -254,7 +288,7 @@ class TypeParamTestInstance
 	};
 
 public:
-	// RXgN^
+	// コンストラクタ
 	TypeParamTestInstance(const char* testcase, const char* name)
 		: m_tests(testcase, name, 0)
 	{
@@ -274,7 +308,7 @@ private:
 /**
  * @private
  * @internal
- * @brief	Typed TestCase ݒێ 
+ * @brief	Typed TestCase 設定保持 
 */
 class TypedTestCasePState
 {
@@ -308,21 +342,33 @@ public:
 private:
 	bool	Verify(const char* names)
 	{
+		IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
 #if IUTEST_TYPED_TEST_P_STRICT
-		if( names == NULL ) return true;
+		if( names == NULL )
+		{
+			return true;
+		}
 		const char* comma = FindComma(names);
 		::std::string name;
-		if( comma == NULL ) name = names;
+		if( comma == NULL )
+		{
+			name = names;
+		}
 		else
 		{
 			name.append(names, comma - names);
 			++comma;
 		}
-		if( m_list.find(name.c_str()) == m_list.end() ) return false;
+		if( m_list.find(name.c_str()) == m_list.end() )
+		{
+			return false;
+		}
 		return Verify(SkipSpace(comma));
 #else
+		IUTEST_UNUSED_VAR(names);
 		return true;
 #endif
+		IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
 	}
 
 private:
@@ -337,7 +383,7 @@ private:
 
 /**
  * @private
- * @brief	^p[^eXg̃CX^XNX
+ * @brief	型パラメータテストのインスタンス化クラス
 */
 template<IUTEST_TEMPLATE_TPARAM1 Fixture, typename Tests, typename Types>
 class TypeParameterizedTestCase
@@ -363,9 +409,10 @@ class TypeParameterizedTestCase
 			UnitTest::instance().AddTestInfo(testcase, &m_info);
 		}
 	public:
-		// eXg̓o^
+		// テストの登録
 		static void Register(TestCase* testcase, const char* test_names)
 		{
+IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
 			const char* str = detail::SkipSpace(test_names);
 			const char* comma = strchr(str, ',');
 			::std::string test_name;
@@ -379,10 +426,11 @@ class TypeParameterizedTestCase
 				++comma;
 			}
 			_Myt* test = new EachTest(testcase, test_name.c_str());
-			// new IuWFNgǗĂ炤
+			// new オブジェクトを管理してもらう
 			detail::iuPool<IEachTest>::GetInstance().push(test);
 
 			EachTest<TypeParam, typename TestsList::Tail>::Register(testcase, detail::SkipSpace(comma));
+IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
 		}
 	private:
 		TestCaseMediator	m_mediator;
@@ -399,36 +447,36 @@ class TypeParameterizedTestCase
 
 public:
 	/**
-	 * @brief	eXg̓o^
+	 * @brief	テストの登録
 	*/
-	static bool Register(const char* prefix, const char* testcase_name, const char* names, int index=0)
+	static bool Register(const char* prefix, const char* testcase_name, const::std::string& package_name, const char* names, int index=0)
 	{
 		typedef typename Types::Head	TypeParam;
 		typedef typename Tests::Head	Head;
 		typedef Fixture<Head>			FixtureClass;
 		typedef TypedTestCase<TypeParam>	_MyTestCase;
 		TestCase* testcase = UnitTest::instance().AddTestCase<_MyTestCase>(
-			detail::MakePrefixedIndexTestName(prefix, testcase_name, index).c_str()
+			(package_name + detail::MakePrefixedIndexTestName(prefix, testcase_name, index)).c_str()
 			//detail::MakePrefixedIndexTypedTestName<TypeParam>(prefix, testcase_name, index).c_str()
 			, internal::GetTypeId<FixtureClass>()
 			, FixtureClass::SetUpTestCase, FixtureClass::TearDownTestCase);
 
 		EachTest<TypeParam, Tests>::Register(testcase, names);
 
-		return TypeParameterizedTestCase<Fixture, Tests, typename Types::Tail>::Register(prefix, testcase_name, names, index+1);
+		return TypeParameterizedTestCase<Fixture, Tests, typename Types::Tail>::Register(prefix, testcase_name, package_name, names, index + 1);
 	}
 };
 
 /**
  * @private
- * @brief	^p[^eXg̃CX^XNX
- *			I[ꉻ
+ * @brief	型パラメータテストのインスタンス化クラス
+ *			終端特殊化
 */
 template<IUTEST_TEMPLATE_TPARAM1 Fixture, typename Tests>
 class TypeParameterizedTestCase<Fixture, Tests, detail::TypeList0>
 {
 public:
-	static bool Register(const char* /*prefix*/, const char* /*testcase_name*/, const char* /*names*/, int index=0)
+	static bool Register(const char* /*prefix*/, const char* /*testcase_name*/, const ::std::string& /*package_name*/, const char* /*names*/, int index=0)
 	{
 		IUTEST_UNUSED_VAR(index);
 		return true;
@@ -440,4 +488,4 @@ public:
 }	// end of namespace detail
 }	// end of namespace iutest
 
-#endif
+#endif	// INCG_IRIS_IUTEST_TYPED_TESTS_HPP_DA9562C6_8CAB_4242_9E9E_22FFB490DE30_
