@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_default_xml_generator.hpp
- * @brief		iris unit test xml o̓CxgXi[ t@C
+ * @brief		iris unit test xml 出力イベントリスナー ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_default_xml_generator_HPP_791DCB98_05CC_49ba_8518_0EC9CA2B5450_
-#define INCG_IRIS_iutest_default_xml_generator_HPP_791DCB98_05CC_49ba_8518_0EC9CA2B5450_
+#ifndef INCG_IRIS_IUTEST_DEFAULT_XML_GENERATOR_HPP_791DCB98_05CC_49BA_8518_0EC9CA2B5450_
+#define INCG_IRIS_IUTEST_DEFAULT_XML_GENERATOR_HPP_791DCB98_05CC_49BA_8518_0EC9CA2B5450_
 
 //======================================================================
 // include
@@ -27,7 +27,7 @@ namespace iutest
 //======================================================================
 // class
 /**
- * @brief	xmlo̓CxgXi[
+ * @brief	xml出力イベントリスナー
 */
 class DefaultXmlGeneratorListener : public EmptyTestEventListener
 {
@@ -35,10 +35,10 @@ class DefaultXmlGeneratorListener : public EmptyTestEventListener
 	IFile*	m_fp;
 public:
 	/**
-	 * @brief	RXgN^
-	 * @param [in] path = o̓pX
+	 * @brief	コンストラクタ
+	 * @param [in] path = 出力パス
 	*/
-	DefaultXmlGeneratorListener(const char* path=NULL)
+	DefaultXmlGeneratorListener(const ::std::string& path)
 		: m_fp(NULL)
 	{
 		SetFilePath(path);
@@ -50,24 +50,29 @@ public:
 	}
 public:
 	/**
-	 * @brief	o̓t@C̐ݒ
+	 * @brief	出力ファイルの設定
 	*/
-	void	SetFilePath(const char* path)
+	void	SetFilePath(const ::std::string& path)
 	{
-		if( path == NULL || *path == '\0' )
+		if( path.empty() )
 		{
 			m_output_path = detail::kStrings::DefaultXmlReportFileName;
 		}
 		else
 		{
 			m_output_path = path;
-			if( strchr(path, '.') == NULL )
+			if( path.find('.') == ::std::string::npos )
 			{
 				m_output_path += "\\";
 				m_output_path += detail::kStrings::DefaultXmlReportFileName;
 			}
 		}
 	}
+	/**
+	 * @brief	出力ファイルパスの取得
+	*/
+	const ::std::string& GetFilePath(void) const { return m_output_path; }
+
 public:
 	virtual void OnTestProgramStart(const UnitTest& test) IUTEST_CXX_OVERRIDE;
 	virtual void OnTestProgramEnd(const UnitTest& test) IUTEST_CXX_OVERRIDE;
@@ -75,6 +80,9 @@ public:
 private:
 	static void OnReportTestCase(IFile* file, const TestCase& test_case);
 	static void OnReportTestInfo(IFile* file, const TestInfo& test_info);
+	static void OnReportTestProperty(IFile* file, const TestResult& test_result
+		, bool (*pfnValidate)(const ::std::string&));
+	static void OnReportTestSkipped(IFile* file, const TestInfo& test_info);
 
 private:
 	bool FileOpen(const char* path);
@@ -94,25 +102,44 @@ private:
 		return EscapeXml(str, false);
 	}
 	/**
-	 * @brief	xml ŎgȂu
+	 * @brief	xml で使えない文字を置き換え
 	*/
 	static ::std::string EscapeXml(const char* str, bool is_attribute);
 
 	/**
-	 * @brief	󔒂ǂ
-	 * @return	^Ul
+	 * @brief	空白かどうか
+	 * @return	真偽値
 	*/
 	static IUTEST_CXX_CONSTEXPR bool IsWhitespace(char c)
 	{
 		return c == 0x9 || c == 0xA || c == 0xD;
 	}
 	/**
-	 * @brief	xml ɗp\ȕǂ
-	 * @return	^Ul
+	 * @brief	xml に利用可能な文字かどうか
+	 * @return	真偽値
 	*/
 	static IUTEST_CXX_CONSTEXPR bool IsValidXmlCharacter(char c)
 	{
+IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
 		return IsWhitespace(c) || c >= 0x20;
+IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
+	}
+
+public:
+	/** @private */
+	static void SetUp(void)
+	{
+		::std::string xmlpath = TestEnv::get_report_xml_filepath();
+		if(!xmlpath.empty())
+		{
+			DefaultXmlGeneratorListener* listener = reinterpret_cast<DefaultXmlGeneratorListener*>(TestEnv::event_listeners().default_xml_generator());
+			if(listener == NULL)
+			{
+				TestEnv::event_listeners().set_default_xml_generator(new DefaultXmlGeneratorListener(xmlpath));
+				return;
+			}
+			listener->SetFilePath(xmlpath);
+		}
 	}
 };
 
@@ -122,4 +149,4 @@ private:
 #  include "../impl/iutest_default_xml_generator.ipp"
 #endif
 
-#endif
+#endif	// INCG_IRIS_IUTEST_DEFAULT_XML_GENERATOR_HPP_791DCB98_05CC_49BA_8518_0EC9CA2B5450_
