@@ -1,21 +1,22 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_vc_unittest.hpp
- * @brief		iris unit test, visual studio 11 C++ Unit Test Framework Ή t@C
+ * @brief		iris unit test, visual studio 11 C++ Unit Test Framework 対応 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_vc_unittest_HPP_5CA7C30C_2D2A_40a1_A9DE_83EAB4527787_
-#define INCG_IRIS_iutest_vc_unittest_HPP_5CA7C30C_2D2A_40a1_A9DE_83EAB4527787_
+#ifndef INCG_IRIS_IUTEST_VC_UNITTEST_HPP_5CA7C30C_2D2A_40A1_A9DE_83EAB4527787_
+#define INCG_IRIS_IUTEST_VC_UNITTEST_HPP_5CA7C30C_2D2A_40A1_A9DE_83EAB4527787_
+
 
 //======================================================================
 // include
@@ -40,15 +41,24 @@
 											, iutest::internal::GetTypeId<testcase_>()	\
 											, testcase_##testname_##_class, testcase_##_##testname_)
 
+#define IUTEST_VCUNIT_CHECK_DISABLED(testcase_, testname_)				\
+	if( const char* p = #testcase_)			\
+		if(strstr(p, "DISABLED_") == p)		\
+			return;							\
+	if( const char* p = #testname_ )		\
+		if(strstr(p, "DISABLED_") == p)		\
+			return
 
 #define IUTEST_VCUNIT(testcase_, testname_, parent_, type_id_, className, methodName)		\
 	IUTEST_TEST_(testcase_, testname_, parent_, type_id_) {}								\
 	IUTEST_VCUNIT_I(testcase_, testname_, className, methodName)
 
-#define IUTEST_VCUNIT_I(testcase_, testname_, className, methodName)						\
-	IUTEST_VC_TEST_CLASS(className), public IUTEST_TEST_CLASS_NAME_(testcase_, testname_) { \
-	public: TEST_METHOD(methodName) { OnTestStart(#testcase_, #testname_); SetUp();			\
-										Body(); TearDown(); OnTestEnd(#testcase_, #testname_); }			\
+#define IUTEST_VCUNIT_I(testcase_, testname_, className, methodName)		\
+	IUTEST_VC_TEST_CLASS(className), public IUTEST_TEST_CLASS_NAME_(testcase_, testname_) {	\
+	public: TEST_METHOD(methodName) {										\
+		IUTEST_VCUNIT_CHECK_DISABLED(testcase_, testname_);					\
+		OnTestStart(#testcase_, #testname_); SetUp();						\
+		Body(); TearDown(); OnTestEnd(#testcase_, #testname_); }			\
 	TEST_CLASS_INITIALIZE(iuSetUp) { IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::SetUpTestCase(); }		\
 	TEST_CLASS_CLEANUP(iuTearDown) { IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::TearDownTestCase(); }	\
 	virtual void	Body(void);				\
@@ -61,7 +71,7 @@
 #  undef IUTEST_P
 #endif
 
-IUTEST_MAKE_SCOPED_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*, iutest, TestInfo, m_factory);
+IUTEST_MAKE_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*, ::iutest::TestInfo, m_factory);
 
 #define IUTEST_P(testcase_, testname_)														\
 	class IUTEST_TEST_CLASS_NAME_(testcase_, testname_) : public testcase_ {				\
@@ -74,29 +84,30 @@ IUTEST_MAKE_SCOPED_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*,
 #define IUTEST_P_VCUNIT_I(testcase_, testname_, className, methodName)						\
 	IUTEST_VC_TEST_CLASS(className), public IUTEST_TEST_CLASS_NAME_(testcase_, testname_) { \
 	public: TEST_METHOD(methodName) {														\
+		IUTEST_VCUNIT_CHECK_DISABLED(testcase_, testname_);									\
 		const ::iutest::TestCase* testcase = ::iuutil::FindParamTestCase(#testcase_);		\
 		::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(testcase);		\
 		while( testcase != NULL ) {															\
 			const char* testcase_name = testcase->name();									\
-			::std::string name(#testname_);	name += "/";								\
-			int testinfo_count = testcase->total_test_count();							\
-			for( int i=0; i < testinfo_count; ++i ) {									\
-				const ::iutest::TestInfo* testinfo = testcase->GetTestInfo(i);			\
+			::std::string name(#testname_);	name += "/";									\
+			int testinfo_count = testcase->total_test_count();								\
+			for( int i=0; i < testinfo_count; ++i ) {										\
+				const ::iutest::TestInfo* testinfo = testcase->GetTestInfo(i);				\
 				::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(testinfo);	\
-				const char* testinfo_name = testinfo->name();							\
-				if( strstr(testinfo_name, name.c_str()) == testinfo_name ) {			\
-					::iutest::detail::iuParamTestFactory<className>* factory =			\
-						(::iutest::detail::iuParamTestFactory<className>*)(				\
-							IUTEST_PEEP_GET(*testinfo, TestInfo, m_factory));			\
+				const char* testinfo_name = testinfo->name();								\
+				if( strstr(testinfo_name, name.c_str()) == testinfo_name ) {				\
+					::iutest::detail::iuParamTestFactory<className>* factory =				\
+						static_cast< ::iutest::detail::iuParamTestFactory<className>*>(		\
+							IUTEST_PEEP_GET(*testinfo, ::iutest::TestInfo, m_factory));		\
 					::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(factory);	\
-					SetParam(&factory->GetParam());										\
-					OnTestStart(testcase_name, testinfo_name);							\
-					SetUp(); Body(); TearDown();										\
-					OnTestEnd(testcase_name, testinfo_name);							\
-				}																		\
-			}																			\
-			testcase = ::iuutil::FindParamTestCase(#testcase_, testcase);				\
-		}																				\
+					SetParam(&factory->GetParam());											\
+					OnTestStart(testcase_name, testinfo_name);								\
+					SetUp(); Body(); TearDown();											\
+					OnTestEnd(testcase_name, testinfo_name);								\
+				}																			\
+			}																				\
+			testcase = ::iuutil::FindParamTestCase(#testcase_, testcase);					\
+		}																					\
 	}																						\
 	TEST_CLASS_INITIALIZE(iuSetUp) { IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::SetUpTestCase(); }		\
 	TEST_CLASS_CLEANUP(iuTearDown) { IUTEST_TEST_CLASS_NAME_(testcase_, testname_)::TearDownTestCase(); }	\
@@ -104,8 +115,8 @@ IUTEST_MAKE_SCOPED_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*,
 	private: static int	AddRegister(void) {													\
 			static ::iutest::detail::ParamTestInstance< className > testinfo(#testname_);	\
 			::iutest::UnitTest::GetInstance()->parameterized_test_registry().				\
-			GetTestCasePatternHolder< testcase_ >(#testcase_)->AddTestPattern(&testinfo);	\
-			return 0;																		\
+			GetTestCasePatternHolder< testcase_ >(#testcase_, IUTEST_GET_PACKAGENAME_())	\
+				->AddTestPattern(&testinfo); return 0;										\
 		}																					\
 		static int dummy_;																	\
 	};																						\
@@ -125,6 +136,7 @@ IUTEST_MAKE_SCOPED_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*,
 #define IUTEST_TYPED_TEST_VCUNIT_I(testcase_, testname_, className, methodName)			\
 	IUTEST_VC_TEST_CLASS(className) {													\
 	public: TEST_METHOD(methodName) {													\
+		IUTEST_VCUNIT_CHECK_DISABLED(testcase_, testname_);								\
 		const ::iutest::TestCase* testcase = ::iuutil::FindTypedTestCase(#testcase_);	\
 		::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(testcase);	\
 		while( testcase != NULL ) {														\
@@ -132,10 +144,10 @@ IUTEST_MAKE_SCOPED_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*,
 			const ::iutest::TestInfo* testinfo = ::iuutil::FindTestInfo(testcase, #testname_);	\
 			::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(testinfo);	\
 			::iutest::detail::iuFactoryBase* factory =									\
-				IUTEST_PEEP_GET(*testinfo, TestInfo, m_factory);						\
+				IUTEST_PEEP_GET(*testinfo, ::iutest::TestInfo, m_factory);				\
 			::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(factory);	\
-			::iutest::detail::auto_ptr<::iutest::Test> p = factory->Create();			\
-			::iuutil::VisualStudio::Test* tester = static_cast<::iuutil::VisualStudio::Test*>(p.ptr());	\
+			::iutest::detail::auto_ptr< ::iutest::Test > p = factory->Create();			\
+			::iuutil::VisualStudio::Test* tester = static_cast< ::iuutil::VisualStudio::Test*>(p.ptr());	\
 			OnTestStart(testcase_name, #testname_);										\
 			tester->SetUp(); tester->Body(); tester->TearDown();						\
 			OnTestEnd(testcase_name, #testname_);										\
@@ -153,7 +165,7 @@ IUTEST_MAKE_SCOPED_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*,
 
 #define IUTEST_TYPED_TEST_P(testcase_, testname_)		\
 	IUTEST_TYPED_TEST_P_VCUNIT_I(testcase_, testname_, testcase_##testname_##_class, testcase_##_##testname_);	\
-	IUTEST_TYPED_TEST_P_(testcase_, testname_)
+	IIUT_TYPED_TEST_P_(testcase_, testname_)
 
 #define IUTEST_TYPED_TEST_P_VCUNIT_I(testcase_, testname_, className, methodName)			\
 	IUTEST_VC_TEST_CLASS(className) {														\
@@ -166,10 +178,10 @@ IUTEST_MAKE_SCOPED_PEEP(::iutest::detail::iuFactoryBase* ::iutest::TestInfo::*,
 			const ::iutest::TestInfo* testinfo = ::iuutil::FindTestInfo(testcase, #testname_);	\
 			::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(testinfo);	\
 			::iutest::detail::iuFactoryBase* factory =										\
-				IUTEST_PEEP_GET(*testinfo, TestInfo, m_factory);							\
+				IUTEST_PEEP_GET(*testinfo, ::iutest::TestInfo, m_factory);					\
 			::Microsoft::VisualStudio::CppUnitTestFramework::Assert::IsNotNull(factory);	\
-			::iutest::detail::auto_ptr<::iutest::Test> p = factory->Create();				\
-			::iuutil::VisualStudio::Test* tester = static_cast<::iuutil::VisualStudio::Test*>(p.ptr());	\
+			::iutest::detail::auto_ptr< ::iutest::Test > p = factory->Create();				\
+			::iuutil::VisualStudio::Test* tester = static_cast< ::iuutil::VisualStudio::Test*>(p.ptr());	\
 			OnTestStart(testcase_name, #testname_);										\
 			tester->SetUp(); tester->Body(); tester->TearDown();						\
 			OnTestEnd(testcase_name, #testname_);										\
@@ -194,7 +206,7 @@ namespace VisualStudio
 typedef ::testing::TestEventListener* (::testing::TestEventListeners::* pfnRepeater)(void);
 
 #define testing	iutest
-IUTEST_MAKE_SCOPED_PEEP(pfnRepeater, testing, TestEventListeners, repeater);
+IUTEST_MAKE_PEEP(pfnRepeater, ::testing::TestEventListeners, repeater);
 #undef testing
 
 #ifndef IUTEST_USE_GTEST
@@ -217,22 +229,28 @@ public:
 	void OnTestStart(const char* testcase_name, const char* testinfo_name)
 	{
 		const ::iutest::TestInfo* testinfo = iuutil::FindTestInfo(testcase_name, testinfo_name);
-		if( testinfo == NULL ) return;
+		if( testinfo == NULL )
+		{
+			return;
+		}
 		::iutest::TestEventListeners& listeners = ::iutest::UnitTest::GetInstance()->listeners();
 		::iutest::TestEventListener* repeator = 
 #define testing	iutest
-			IUTEST_PEEP_GET(listeners, TestEventListeners, repeater)();
+			IUTEST_PEEP_GET(listeners, ::testing::TestEventListeners, repeater)();
 #undef testing
 		repeator->OnTestStart(*testinfo);
 	}
 	void OnTestEnd(const char* testcase_name, const char* testinfo_name)
 	{
 		const ::iutest::TestInfo* testinfo = iuutil::FindTestInfo(testcase_name, testinfo_name);
-		if( testinfo == NULL ) return;
+		if( testinfo == NULL )
+		{
+			return;
+		}
 		::iutest::TestEventListeners& listeners = ::iutest::UnitTest::GetInstance()->listeners();
 		::iutest::TestEventListener* repeator = 
 #define testing	iutest
-			IUTEST_PEEP_GET(listeners, TestEventListeners, repeater)();
+			IUTEST_PEEP_GET(listeners, ::testing::TestEventListeners, repeater)();
 #undef testing
 		repeator->OnTestEnd(*testinfo);
 	}
@@ -248,7 +266,10 @@ public:
 	virtual void voutput(const char* fmt, va_list va)
 	{
 		int length = _vscprintf(fmt, va);
-		if( length <= 0 ) return;
+		if( length <= 0 )
+		{
+			return;
+		}
 		length += 1;
 		char* buf = new char [length];
 		vsprintf_s(buf, length, fmt, va);
@@ -267,7 +288,7 @@ private:
 };
 
 /**
- * @brief	Hook p|[^[
+ * @brief	Hook 用リポーター
 */
 class VCCppUnitTestPartResultReporter : public ::iutest::EmptyTestEventListener
 {
@@ -284,7 +305,7 @@ public:
 	}
 	virtual void OnTestPartResult(const ::iutest::TestPartResult& result)
 	{
-		// VC ɂ
+		// VC にも送る
 		if( result.failed() )
 		{
 			size_t size=0;
