@@ -1,21 +1,21 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_util_tests.hpp
- * @brief		iris unit test eXg utility t@C
+ * @brief		iris unit test テスト情報 utility ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
 //======================================================================
-#ifndef INCG_IRIS_iutest_util_tests_HPP_4095FF9B_D6B8_4cd3_BF86_43DFED1760EA_
-#define INCG_IRIS_iutest_util_tests_HPP_4095FF9B_D6B8_4cd3_BF86_43DFED1760EA_
+#ifndef INCG_IRIS_IUTEST_UTIL_TESTS_HPP_4095FF9B_D6B8_4CD3_BF86_43DFED1760EA_
+#define INCG_IRIS_IUTEST_UTIL_TESTS_HPP_4095FF9B_D6B8_4CD3_BF86_43DFED1760EA_
 
 //======================================================================
 // include
@@ -26,17 +26,31 @@ namespace iuutil
 // function
 
 /**
- * @brief	CfbNXeXg擾
+ * @brief	テスト名を取得
+*/
+inline ::std::string TestFullName(const ::iutest::TestInfo* test_info)
+{
+	::std::string fullname = test_info->test_case_name();
+	fullname += ".";
+	fullname += test_info->name();
+	return fullname;
+}
+
+/**
+ * @brief	インデックスを除いたテスト名を取得
 */
 inline ::std::string TestNameRemoveIndexName(const char* name)
 {
 	const char* const p = strrchr(name, '/');
-	if( p == NULL ) return name;
+	if( p == NULL )
+	{
+		return name;
+	}
 	return ::std::string(name, p);
 }
 
 /**
- * @brief	CfbNXeXgP[X擾
+ * @brief	インデックスを除いたテストケース名を取得
 */
 inline ::std::string TestCaseNameRemoveIndexName(const char* name)
 {
@@ -44,24 +58,37 @@ inline ::std::string TestCaseNameRemoveIndexName(const char* name)
 }
 
 /**
- * @brief	CX^XƃCfbNXeXgP[X擾
+ * @brief	インスタンス名とインデックスを除いたテストケース名を取得
 */
 inline ::std::string TestCaseNameRemoveInstantiateAndIndexName(const char* name)
 {
-	// 擪ɃCX^X
+	// パッケージ名があれば取得
+	const char* const pkg = strrchr(name, '.');
+	// 先頭にインスタンス名がある
 	const char* const p1 = strchr(name, '/');
-	if( p1 == NULL ) return name;
-	const char* const p2 = strrchr(p1+1, '/');
-	if( p2 == NULL ) return p1+1;
-	return ::std::string(p1+1, p2);
+	if( p1 == NULL )
+	{
+		return name;
+	}
+	if( pkg == NULL )
+	{
+		return TestCaseNameRemoveIndexName(p1 + 1);
+	}
+	else
+	{
+		return ::std::string(name, pkg + 1) + TestCaseNameRemoveIndexName(p1 + 1);
+	}
 }
 
 /**
- * @brief	TestCase ̌
+ * @brief	TestCase の検索
 */
 inline const ::iutest::TestCase* FindTestCase(const char* testcase_name)
 {
-	if( testcase_name == NULL ) return NULL;
+	if( testcase_name == NULL )
+	{
+		return NULL;
+	}
 	const int testcase_count = ::iutest::UnitTest::GetInstance()->total_test_case_count();
 	for( int i=0; i < testcase_count; ++i )
 	{
@@ -75,11 +102,14 @@ inline const ::iutest::TestCase* FindTestCase(const char* testcase_name)
 }
 
 /**
- * @brief	TestCase ̌
+ * @brief	TestCase の検索
 */
 inline const ::iutest::TestCase* FindParamTestCase(const char* testcase_name, const ::iutest::TestCase* begin=NULL)
 {
-	if( testcase_name == NULL ) return NULL;
+	if( testcase_name == NULL )
+	{
+		return NULL;
+	}
 	const int testcase_count = ::iutest::UnitTest::GetInstance()->total_test_case_count();
 	int i=0;
 	if( begin != NULL )
@@ -87,7 +117,10 @@ inline const ::iutest::TestCase* FindParamTestCase(const char* testcase_name, co
 		for( ; i < testcase_count; ++i )
 		{
 			const ::iutest::TestCase* testcase = ::iutest::UnitTest::GetInstance()->GetTestCase(i);
-			if( testcase == begin ) break; 
+			if( testcase == begin )
+			{
+				break;
+			}
 		}
 		++i;
 	}
@@ -107,11 +140,14 @@ inline const ::iutest::TestCase* FindParamTestCase(const char* testcase_name, co
 }
 
 /**
- * @brief	Typed Test  TestCase ̌
+ * @brief	Typed Test の TestCase の検索
 */
 inline const ::iutest::TestCase* FindTypedTestCase(const char* testcase_name, const ::iutest::TestCase* begin=NULL)
 {
-	if( testcase_name == NULL ) return NULL;
+	if( testcase_name == NULL )
+	{
+		return NULL;
+	}
 	const int testcase_count = ::iutest::UnitTest::GetInstance()->total_test_case_count();
 	int i=0;
 	if( begin != NULL )
@@ -119,7 +155,10 @@ inline const ::iutest::TestCase* FindTypedTestCase(const char* testcase_name, co
 		for( ; i < testcase_count; ++i )
 		{
 			const ::iutest::TestCase* testcase = ::iutest::UnitTest::GetInstance()->GetTestCase(i);
-			if( testcase == begin ) break; 
+			if( testcase == begin )
+			{
+				break;
+			}
 		}
 		++i;
 	}
@@ -141,11 +180,14 @@ inline const ::iutest::TestCase* FindTypedTestCase(const char* testcase_name, co
 }
 
 /**
- * @brief	Type Parameter Test  TestCase ̌
+ * @brief	Type Parameter Test の TestCase の検索
 */
 inline const ::iutest::TestCase* FindParamTypedTestCase(const char* testcase_name, const ::iutest::TestCase* begin=NULL)
 {
-	if( testcase_name == NULL ) return NULL;
+	if( testcase_name == NULL )
+	{
+		return NULL;
+	}
 	const int testcase_count = ::iutest::UnitTest::GetInstance()->total_test_case_count();
 	int i=0;
 	if( begin != NULL )
@@ -153,7 +195,10 @@ inline const ::iutest::TestCase* FindParamTypedTestCase(const char* testcase_nam
 		for( ; i < testcase_count; ++i )
 		{
 			const ::iutest::TestCase* testcase = ::iutest::UnitTest::GetInstance()->GetTestCase(i);
-			if( testcase == begin ) break; 
+			if( testcase == begin )
+			{
+				break;
+			}
 		}
 		++i;
 	}
@@ -175,11 +220,14 @@ inline const ::iutest::TestCase* FindParamTypedTestCase(const char* testcase_nam
 }
 
 /**
- * @brief	TestInfo ̌
+ * @brief	TestInfo の検索
 */
 inline const ::iutest::TestInfo* FindTestInfo(const ::iutest::TestCase* testcase, const char* testinfo_name)
 {
-	if( testcase == NULL || testinfo_name == NULL ) return NULL;
+	if( testcase == NULL || testinfo_name == NULL )
+	{
+		return NULL;
+	}
 
 	int testinfo_count = testcase->total_test_count();
 	for( int i=0; i < testinfo_count; ++i )
@@ -194,21 +242,27 @@ inline const ::iutest::TestInfo* FindTestInfo(const ::iutest::TestCase* testcase
 }
 
 /**
- * @brief	TestInfo ̌
+ * @brief	TestInfo の検索
 */
 inline const ::iutest::TestInfo* FindTestInfo(const char* testcase_name, const char* testinfo_name)
 {
-	if( testcase_name == NULL || testinfo_name == NULL ) return NULL;
+	if( testcase_name == NULL || testinfo_name == NULL )
+	{
+		return NULL;
+	}
 	const ::iutest::TestCase* testcase = FindTestCase(testcase_name);
 	return FindTestInfo(testcase, testinfo_name);
 }
 
 /**
- * @brief	TestInfo ̌
+ * @brief	TestInfo の検索
 */
 inline const ::iutest::TestInfo* FindParamTestInfo(const ::iutest::TestCase* testcase, const char* testinfo_name, const ::iutest::TestInfo* begin=NULL)
 {
-	if( testcase == NULL || testinfo_name == NULL ) return NULL;
+	if( testcase == NULL || testinfo_name == NULL )
+	{
+		return NULL;
+	}
 
 	const int testinfo_count = testcase->total_test_count();
 	int i=0;
@@ -244,4 +298,4 @@ inline const ::iutest::TestInfo* FindParamTestInfo(const ::iutest::TestCase* tes
 
 }	// end of namespace iuutil
 
-#endif
+#endif	// INCG_IRIS_IUTEST_UTIL_TESTS_HPP_4095FF9B_D6B8_4CD3_BF86_43DFED1760EA_
