@@ -1,15 +1,15 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		sub.cpp
- * @brief		sample sub t@C
+ * @brief		sample sub ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -28,7 +28,7 @@
 #if 1	// Success Tests
 
 /** --------------------------------------------------
- * pbP[W
+ * パッケージ
 *//*--------------------------------------------------*/
 IUTEST_PACKAGE(TestPackage)
 {
@@ -193,7 +193,7 @@ IUTEST_F(EnabledTestFixed, Count)
 #if 0
 #ifdef _MSC_VER
 // cppcheck-suppress syntaxError
-IUTEST(Japanese, eXg)
+IUTEST(Japanese, テスト)
 {
 	IUTEST_FAIL() << ::iutest::UnitTest::GetInstance()->current_test_info()->name();
 }
