@@ -1,15 +1,15 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_all.cpp
- * @brief		iris unit test  t@C
+ * @brief		iris unit test 実装 ファイル
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -32,6 +32,8 @@
 #include "../include/impl/iutest_listener.ipp"
 #include "../include/impl/iutest_message.ipp"
 #include "../include/impl/iutest_regex.ipp"
+#include "../include/impl/iutest_charcode.ipp"
+#include "../include/impl/iutest_time.ipp"
 
 #include "../include/impl/iutest_debug.ipp"
 #include "../include/impl/iutest_filepath.ipp"
