@@ -1,15 +1,15 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_combine_tests.cpp
- * @brief		Combine ΉeXg
+ * @brief		Combine 対応テスト
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -19,7 +19,7 @@
 // include
 #include "../include/iutest.hpp"
 
-#if IUTEST_HAS_COMBINE
+#if IUTEST_HAS_PARAM_TEST && IUTEST_HAS_COMBINE
 
 static const int tble[] = {0, 1};
 
@@ -31,6 +31,9 @@ public:
 
 	static int index;
 	static Tuple list[2*2*TABLE_SIZE];
+	
+public:
+	static void SetUpTestCase(void) { index = 0; }
 };
 
 int CombineTest::index = 0;
@@ -47,12 +50,43 @@ CombineTest::Tuple CombineTest::list[2*2*CombineTest::TABLE_SIZE] = {
 
 IUTEST_P(CombineTest, Num)
 {
-	EXPECT_EQ( 2*2*TABLE_SIZE, ::iutest::UnitTest::GetInstance()->current_test_case()->total_test_count() );
-	EXPECT_EQ( list[index++], GetParam() );
+	IUTEST_EXPECT_EQ( (2*2*TABLE_SIZE) * 2, ::iutest::UnitTest::GetInstance()->current_test_case()->total_test_count() );
+}
+
+IUTEST_P(CombineTest, Param)
+{
+	IUTEST_EXPECT_EQ( list[index++], GetParam() );
 }
 
 IUTEST_INSTANTIATE_TEST_CASE_P(A, CombineTest
 	, ::iutest::Combine(::iutest::Bool(), ::iutest::Values(1, 10), ::iutest::ValuesIn(tble)));
+#if IUTEST_HAS_CONCAT
+IUTEST_INSTANTIATE_TEST_CASE_P(B, CombineTest
+	, ::iutest::Concat(
+		::iutest::Combine(::iutest::Values(false), ::iutest::Values(1, 10), ::iutest::ValuesIn(tble))
+		, ::iutest::Combine(::iutest::Values(true), ::iutest::Values(1, 10), ::iutest::ValuesIn(tble))
+	)
+	);
+IUTEST_INSTANTIATE_TEST_CASE_P(C, CombineTest
+	, ::iutest::Combine(::iutest::Values(false), ::iutest::Values(1, 10), ::iutest::ValuesIn(tble))
+		+ ::iutest::Combine(::iutest::Values(true), ::iutest::Values(1, 10), ::iutest::ValuesIn(tble))
+	);
+#endif
+
+
+class CombineInTest : public ::iutest::TestWithParam< ::iutest::tuples::tuple< ::iutest::tuples::tuple<bool, int>, int > >
+{
+};
+
+IUTEST_P(CombineInTest, A)
+{
+}
+
+IUTEST_INSTANTIATE_TEST_CASE_P(A, CombineInTest
+	, ::iutest::Combine( ::iutest::Combine(::iutest::Bool(), ::iutest::Values(1, 10)), ::iutest::ValuesIn(tble)) );
+IUTEST_INSTANTIATE_TEST_CASE_P(B, CombineInTest
+	, ::iutest::Combine( ::iutest::Values( ::iutest::tuples::tuple<bool, int>(false, 1), ::iutest::tuples::tuple<bool, int>(true, 10) )
+		, ::iutest::ValuesIn(tble)) );
 
 
 #if IUTEST_HAS_VARIADIC_COMBINE
@@ -94,8 +128,8 @@ int VariadicCombineTest::count = 0;
 
 IUTEST_P(VariadicCombineTest, Num)
 {
-	EXPECT_EQ( num, ::iutest::UnitTest::GetInstance()->current_test_case()->total_test_count() );
-	EXPECT_EQ( count_to_tuple(count++), GetParam() );
+	IUTEST_EXPECT_EQ( num, ::iutest::UnitTest::GetInstance()->current_test_case()->total_test_count() );
+	IUTEST_EXPECT_EQ( count_to_tuple(count++), GetParam() );
 }
 
 IUTEST_INSTANTIATE_TEST_CASE_P(A, VariadicCombineTest
