@@ -1,15 +1,15 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_pairwise_tests.cpp
- * @brief		Pairwise ΉeXg
+ * @brief		Pairwise 対応テスト
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -62,6 +62,7 @@ class PairwiseTest : public ::iutest::TestWithParam< PairwiseTestTuple >
 
 IUTEST_P(PairwiseTest, Num)
 {
+#ifndef USE_PROGRESS
 	PairwiseTestTuple param = GetParam();
 	printf("%d %d %d %d %d %d %d %d %d\n"
 		, ::iutest::tuples::get<0>(param)
@@ -74,6 +75,7 @@ IUTEST_P(PairwiseTest, Num)
 		, ::iutest::tuples::get<7>(param)
 		, ::iutest::tuples::get<8>(param)
 	);
+#endif
 }
 
 IUTEST_INSTANTIATE_TEST_CASE_P(A, PairwiseTest
@@ -87,6 +89,53 @@ IUTEST_INSTANTIATE_TEST_CASE_P(A, PairwiseTest
 		, ::iutest::Range(0,2)
 		, ::iutest::Range(0,2)
 	));
+#if IUTEST_HAS_CONCAT
+IUTEST_INSTANTIATE_TEST_CASE_P(B, PairwiseTest
+	, ::iutest::Concat(
+		::iutest::Pairwise(::iutest::Range(0,1)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+		),
+		::iutest::Pairwise(::iutest::Range(1,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+			, ::iutest::Range(0,2)
+		)
+	)
+	);
+IUTEST_INSTANTIATE_TEST_CASE_P(C, PairwiseTest
+	, ::iutest::Pairwise(::iutest::Range(0,1)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+	) + ::iutest::Pairwise(::iutest::Range(1,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+		, ::iutest::Range(0,2)
+	)
+	);
+#endif
 
 #if IUTEST_HAS_VARIADIC_PAIRWISE
 
@@ -98,6 +147,7 @@ class VariadicPairwiseTest : public ::iutest::TestWithParam< VariadicPairwiseTes
 
 IUTEST_P(VariadicPairwiseTest, Num)
 {
+#ifndef USE_PROGRESS
 	VariadicPairwiseTestTuple param = GetParam();
 	printf("%d %d %d %d %d %d %d %d %d %d\n"
 		, ::iutest::tuples::get<0>(param)
@@ -111,6 +161,7 @@ IUTEST_P(VariadicPairwiseTest, Num)
 		, ::iutest::tuples::get<8>(param)
 		, ::iutest::tuples::get<9>(param)
 	);
+#endif
 }
 
 IUTEST_INSTANTIATE_TEST_CASE_P(A, VariadicPairwiseTest
