@@ -1,4 +1,4 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_param_test_tests.hpp
@@ -8,8 +8,8 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -34,13 +34,6 @@ public:
 	MultiInstantiateParamTest(void) : value(0) {}
 };
 
-IUTEST_P(MultiInstantiateParamTest, Test)
-{
-	int param = GetParam();
-	IUTEST_ASSERT_EQ(0, value);
-	IUTEST_ASSERT_EQ(param, param);
-}
-
 #endif
 
 #endif
