@@ -1,15 +1,15 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_progress_tests.cpp
- * @brief		vOX\ eXg
+ * @brief		プログレス表示 テスト
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -27,12 +27,16 @@ int main(int argc, char* argv[])
 #endif
 {
 	IUTEST_INIT(&argc, argv);
-	::iutest::SetUpProgressPrintListener();
+#if !defined(IUTEST_USE_GTEST)
+	::iutest::ProgressPrintListener::SetUp();
+#endif
 	return IUTEST_RUN_ALL_TESTS();
 }
 
+#if !defined(IUTEST_USE_GTEST)
+
 #define DECL_TEST(n)	IUTEST(Foo, Bar##n) {	\
-							::iutest::internal::posix::SleepMillisec(1000); }
+							::iutest::internal::SleepMilliseconds(100); }
 
 
 DECL_TEST(0)
@@ -56,3 +60,4 @@ DECL_TEST(17)
 DECL_TEST(18)
 DECL_TEST(19)
 
+#endif
