@@ -1,15 +1,15 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_throw_on_fialure_tests.cpp
- * @brief		throw_on_fialure ΉeXg
+ * @brief		throw_on_fialure 対応テスト
  *
  * @author		t.sirayanagi
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -19,8 +19,6 @@
 // include
 #include "../include/iutest.hpp"
 
-#include <assert.h>
-
 #if IUTEST_HAS_EXCEPTIONS
 
 IUTEST(Expect, Test)
@@ -52,24 +50,41 @@ int main(int argc, char* argv[])
 #endif
 {
 	::iutest::IUTEST_FLAG(throw_on_failure) = true;
+#if !defined(IUTEST_USE_GTEST)
+	::iutest::IUTEST_FLAG(catch_exceptions_global) = false;
+#endif
 	
 #if IUTEST_HAS_EXCEPTIONS
+	try
 	{
 		::iutest::IUTEST_FLAG(filter) = "*Expect*";
 		IUTEST_INIT(&argc, argv);
-		int ret = IUTEST_RUN_ALL_TESTS();	// run all
+#if defined(OUTPUTXML)
+		// 失敗テストを含むので xml 出力しない
+		::iutest::IUTEST_FLAG(output) = NULL;
+#endif
+		(void)IUTEST_RUN_ALL_TESTS();
 		
-		assert( ret != 0 );
-		assert( ::iutest::UnitTest::GetInstance()->failed_test_count() == 1 );
+		return 1;
+	}
+	catch(...)
+	{
 	}
 
+	try
 	{
 		::iutest::IUTEST_FLAG(filter) = "*Assert*";
 		IUTEST_INIT(&argc, argv);
-		int ret = IUTEST_RUN_ALL_TESTS();	// run all
+#if defined(OUTPUTXML)
+		// 失敗テストを含むので xml 出力しない
+		::iutest::IUTEST_FLAG(output) = NULL;
+#endif
+		(void)IUTEST_RUN_ALL_TESTS();
 		
-		assert( ret != 0 );
-		assert( ::iutest::UnitTest::GetInstance()->failed_test_count() == 1 );
+		return 1;
+	}
+	catch(...)
+	{
 	}
 #endif
 	printf("*** Successful ***\n");
